searchNodes=[{"type":"module","title":"Cldr","doc":"Cldr provides the core functions to retrieve and manage the CLDR data that supports formatting and localisation. This module provides the core functions to access formatted CLDR data, set and retrieve a current locale and validate certain core data types such as locales, currencies and territories. Cldr functionality is packaged into a several packages that each depend on this one. These additional modules are: Cldr.Number.to_string/2 for formatting numbers and Cldr.Currency.to_string/2 for formatting currencies. These functions are contained in the hex package ex_cldr_numbers . Cldr.List.to_string/2 for formatting lists. These function is contained in the hex package ex_cldr_lists . Cldr.Unit.to_string/2 for formatting SI units. These function is contained in the hex package ex_cldr_units . Cldr.DateTime.to_string/2 for formatting of dates, times and datetimes. This function is contained in the hex package ex_cldr_dates_times .","ref":"Cldr.html"},{"type":"function","title":"Cldr.all_locale_names/0","doc":"Returns a list of all the locale names defined in the CLDR repository. Note that not necessarily all of these locales are available since functions are only generated for configured locales which is most cases will be a subset of locales defined in CLDR. See also: requested_locales/1 and known_locales/1","ref":"Cldr.html#all_locale_names/0"},{"type":"function","title":"Cldr.available_locale_name?/1","doc":"Returns a boolean indicating if the specified locale is available in CLDR. The return value depends on whether the locale is defined in the CLDR repository. It does not necessarily mean the locale is configured for Cldr . See also Cldr.known_locale_name?/2 . Arguments locale is any valid locale name returned by Cldr.known_locale_names/1 Examples iex&gt; Cldr . available_locale_name? ( :&quot;en-AU&quot; ) true iex&gt; Cldr . available_locale_name? ( :&quot;en-SA&quot; ) false","ref":"Cldr.html#available_locale_name?/1"},{"type":"function","title":"Cldr.default_backend/0","doc":"","ref":"Cldr.html#default_backend/0"},{"type":"function","title":"Cldr.default_backend!/0","doc":"Returns the configured default backend module. The default backend can be set with Cldr.put_default_backend/1 . Alternatively the default backend may be configured in config.exs under the ex_cldr key as follows: config :ex_cldr , default_backend : &lt; backend_module &gt; Important Note If this function is called and no default backend is configured an exception will be raised.","ref":"Cldr.html#default_backend!/0"},{"type":"function","title":"Cldr.default_locale/0","doc":"Returns the configured global default locale . The default locale can be set with Cldr.put_default_locale/1 . Alternatively the default locale may be configured in config.exs under the ex_cldr key as follows: config :ex_cldr , default_locale : &lt; locale_name &gt; Returns The default locale or Raises an exception if no default backend is configured Notes Cldr.default_locale/0 returns the system-wide default locale. Example iex&gt; Cldr . default_locale % Cldr.LanguageTag { backend : TestBackend.Cldr , canonical_locale_name : &quot;en-001&quot; , cldr_locale_name : :&quot;en-001&quot; , language_subtags : [ ] , extensions : %{ } , gettext_locale_name : &quot;en&quot; , language : &quot;en&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :en , requested_locale_name : &quot;en-001&quot; , script : :Latn , territory : :&quot;001&quot; , transform : %{ } , language_variants : [ ] }","ref":"Cldr.html#default_locale/0"},{"type":"function","title":"Cldr.default_locale/1","doc":"Returns the global default locale for a given backend. Arguments backend is any module that includes use Cldr and therefore is a Cldr backend module. Returns The default locale for the backend. Example iex&gt; Cldr . default_locale ( TestBackend.Cldr ) % Cldr.LanguageTag { backend : TestBackend.Cldr , canonical_locale_name : &quot;en-001&quot; , cldr_locale_name : :&quot;en-001&quot; , language_subtags : [ ] , extensions : %{ } , gettext_locale_name : &quot;en&quot; , language : &quot;en&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :en , requested_locale_name : &quot;en-001&quot; , script : :Latn , territory : :&quot;001&quot; , transform : %{ } , language_variants : [ ] }","ref":"Cldr.html#default_locale/1"},{"type":"function","title":"Cldr.default_script/0","doc":"Returns the default script. Returns The default script which is Latn .","ref":"Cldr.html#default_script/0"},{"type":"function","title":"Cldr.default_territory/1","doc":"Returns the default territory when a locale does not specify one and none can be inferred. Arguments backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend/0 Returns The default territory or Raises if no argument is supplied and there is no default backend configured Example iex&gt; Cldr . default_territory ( TestBackend.Cldr ) :&quot;001&quot;","ref":"Cldr.html#default_territory/1"},{"type":"function","title":"Cldr.display_name/2","doc":"Return a localised string suitable for presentation purposes for structs that implement the Cldr.LanguageTag.DisplayName protocol. The Cldr.LanguageTag.DisplayName protocol is implemented in this library for t:Cldr.LanguageTag.t . Other CLDR-related libraries implement the protocol for the types they support such as t:Cldr.Unit and t:Cldr.Currency .","ref":"Cldr.html#display_name/2"},{"type":"function","title":"Cldr.ellipsis/3","doc":"Add locale-specific ellipsis to a string. Arguments string is any String.t or a 2-element list of String.t between which the ellipsis is inserted. backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend/0 . Note that Cldr.default_backend/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs . options is a keyword list of options. Options :locale is any valid locale name returned by Cldr.known_locale_names/1 . The default is Cldr.get_locale/0 :location determines where to place the ellipsis. The options are :after (the default for a single string argument), :between (the default and only valid location for an argument that is a list of two strings) and :before :format formats based upon whether the ellipsis is inserted between words or sentences. The valid options are :word or :sentence . The default is :sentence . Examples iex&gt; Cldr . ellipsis &quot;And furthermore&quot; &quot;And furthermore…&quot; iex&gt; Cldr . ellipsis [ &quot;And furthermore&quot; , &quot;there is much to be done&quot; ] , locale : &quot;ja&quot; &quot;And furthermore…there is much to be done&quot; iex&gt; Cldr . ellipsis &quot;And furthermore&quot; , format : :word &quot;And furthermore …&quot; iex&gt; Cldr . ellipsis [ &quot;And furthermore&quot; , &quot;there is much to be done&quot; ] , locale : &quot;ja&quot; , format : :word &quot;And furthermore … there is much to be done&quot;","ref":"Cldr.html#ellipsis/3"},{"type":"function","title":"Cldr.flag/1","doc":"Returns a unicode string representing a flag for a territory. Options territory is any valid territory code returned by Cldr.known_territories/0 or a Cldr.LanguageTag.t Returns A string representing a flag or An empty string if the territory is valid but no unicode grapheme is defined. This is true for territories that are aggregate areas such as &quot;the world&quot; which is :001 {:error, {Cldr.UnknownTerritoryError, message}} Notes If a Cldr.LanguageTag.t is provided, the territory is determined by Cldr.Locale.territory_from_locale/1 Examples iex&gt; Cldr . flag :AU &quot;🇦🇺&quot; iex&gt; Cldr . flag :US &quot;🇺🇸&quot; iex&gt; Cldr . flag &quot;UN&quot; &quot;🇺🇳&quot; iex&gt; Cldr . flag ( :UK ) &quot;🇬🇧&quot; iex&gt; Cldr . flag ( :GB ) &quot;🇬🇧&quot; iex&gt; Cldr . flag ( :UX ) { :error , { Cldr.UnknownTerritoryError , &quot;The territory :UX is unknown&quot; } }","ref":"Cldr.html#flag/1"},{"type":"function","title":"Cldr.get_locale/1","doc":"Return the Cldr locale for the current process. Note that the locale is set per-process. If the locale is not set for the given process then: Return the global default locale which is defined under the :ex_cldr key in config.exs Or the system-wide default locale which is &quot;en-001&quot; Note that if there is no locale set for the current process then an error is not returned - a default locale will be returned per the rules above. Example iex&gt; Cldr . put_locale ( TestBackend.Cldr.Locale . new! ( &quot;pl&quot; ) ) iex&gt; Cldr . get_locale ( ) % Cldr.LanguageTag { backend : TestBackend.Cldr , canonical_locale_name : &quot;pl&quot; , cldr_locale_name : :pl , extensions : %{ } , language : &quot;pl&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :pl , territory : :PL , requested_locale_name : &quot;pl&quot; , script : :Latn , transform : %{ } , language_variants : [ ] }","ref":"Cldr.html#get_locale/1"},{"type":"macro","title":"Cldr.is_locale_name/1","doc":"","ref":"Cldr.html#is_locale_name/1"},{"type":"function","title":"Cldr.known_calendars/0","doc":"Returns a list of strings representing the calendars known to Cldr . Example iex&gt; Cldr . known_calendars [ :buddhist , :chinese , :coptic , :dangi , :ethiopic , :ethiopic_amete_alem , :gregorian , :hebrew , :indian , :islamic , :islamic_civil , :islamic_rgsa , :islamic_tbla , :islamic_umalqura , :japanese , :persian , :roc ]","ref":"Cldr.html#known_calendars/0"},{"type":"function","title":"Cldr.known_currencies/0","doc":"Returns a list of strings representing the currencies known to Cldr . Example iex&gt; Cldr . known_currencies [ :ADP , :AED , :AFA , :AFN , :ALK , :ALL , :AMD , :ANG , :AOA , :AOK , :AON , :AOR , :ARA , :ARL , :ARM , :ARP , :ARS , :ATS , :AUD , :AWG , :AZM , :AZN , :BAD , :BAM , :BAN , :BBD , :BDT , :BEC , :BEF , :BEL , :BGL , :BGM , :BGN , :BGO , :BHD , :BIF , :BMD , :BND , :BOB , :BOL , :BOP , :BOV , :BRB , :BRC , :BRE , :BRL , :BRN , :BRR , :BRZ , :BSD , :BTN , :BUK , :BWP , :BYB , :BYN , :BYR , :BZD , :CAD , :CDF , :CHE , :CHF , :CHW , :CLE , :CLF , :CLP , :CNH , :CNX , :CNY , :COP , :COU , :CRC , :CSD , :CSK , :CUC , :CUP , :CVE , :CYP , :CZK , :DDM , :DEM , :DJF , :DKK , :DOP , :DZD , :ECS , :ECV , :EEK , :EGP , :ERN , :ESA , :ESB , :ESP , :ETB , :EUR , :FIM , :FJD , :FKP , :FRF , :GBP , :GEK , :GEL , :GHC , :GHS , :GIP , :GMD , :GNF , :GNS , :GQE , :GRD , :GTQ , :GWE , :GWP , :GYD , :HKD , :HNL , :HRD , :HRK , :HTG , :HUF , :IDR , :IEP , :ILP , :ILR , :ILS , :INR , :IQD , :IRR , :ISJ , :ISK , :ITL , :JMD , :JOD , :JPY , :KES , :KGS , :KHR , :KMF , :KPW , :KRH , :KRO , :KRW , :KWD , :KYD , :KZT , :LAK , :LBP , :LKR , :LRD , :LSL , :LTL , :LTT , :LUC , :LUF , :LUL , :LVL , :LVR , :LYD , :MAD , :MAF , :MCF , :MDC , :MDL , :MGA , :MGF , :MKD , :MKN , :MLF , :MMK , :MNT , :MOP , :MRO , :MRU , :MTL , :MTP , :MUR , :MVP , :MVR , :MWK , :MXN , :MXP , :MXV , :MYR , :MZE , :MZM , :MZN , :NAD , :NGN , :NIC , :NIO , :NLG , :NOK , :NPR , :NZD , :OMR , :PAB , :PEI , :PEN , :PES , :PGK , :PHP , :PKR , :PLN , :PLZ , :PTE , :PYG , :QAR , :RHD , :ROL , :RON , :RSD , :RUB , :RUR , :RWF , :SAR , :SBD , :SCR , :SDD , :SDG , :SDP , :SEK , :SGD , :SHP , :SIT , :SKK , :SLE , :SLL , :SOS , :SRD , :SRG , :SSP , :STD , :STN , :SUR , :SVC , :SYP , :SZL , :THB , :TJR , :TJS , :TMM , :TMT , :TND , :TOP , :TPE , :TRL , :TRY , :TTD , :TWD , :TZS , :UAH , :UAK , :UGS , :UGX , :USD , :USN , :USS , :UYI , :UYP , :UYU , :UYW , :UZS , :VEB , :VED , :VEF , :VES , :VND , :VNN , :VUV , :WST , :XAF , :XAG , :XAU , :XBA , :XBB , :XBC , :XBD , :XCD , :XDR , :XEU , :XFO , :XFU , :XOF , :XPD , :XPF , :XPT , :XRE , :XSU , :XTS , :XUA , :XXX , :YDD , :YER , :YUD , :YUM , :YUN , :YUR , :ZAL , :ZAR , :ZMK , :ZMW , :ZRN , :ZRZ , :ZWD , :ZWL , :ZWR ]","ref":"Cldr.html#known_currencies/0"},{"type":"function","title":"Cldr.known_gettext_locale_name/2","doc":"Returns either the Gettext locale_name in Cldr format or false based upon whether the locale name is configured in Gettext . Arguments locale is any valid locale name returned by Cldr.known_locale_names/1 backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend!/0 . Note that Cldr.default_backend!/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs . Examples iex&gt; Cldr . known_gettext_locale_name ( &quot;en&quot; , TestBackend.Cldr ) &quot;en&quot; iex&gt; Cldr . known_gettext_locale_name ( &quot;en-SA&quot; , TestBackend.Cldr ) false","ref":"Cldr.html#known_gettext_locale_name/2"},{"type":"function","title":"Cldr.known_gettext_locale_name?/2","doc":"Returns a boolean indicating if the specified locale name is configured and available in Gettext. Arguments locale is any valid locale name returned by Cldr.known_locale_names/1 backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend!/0 . Note that Cldr.default_backend!/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs . Examples iex&gt; Cldr . known_gettext_locale_name? ( &quot;en&quot; , TestBackend.Cldr ) true iex&gt; Cldr . known_gettext_locale_name? ( &quot;!!&quot; , TestBackend.Cldr ) false","ref":"Cldr.html#known_gettext_locale_name?/2"},{"type":"function","title":"Cldr.known_gettext_locale_names/1","doc":"Returns a list of Gettext locale names but in CLDR format with underscore replaced by hyphen in order to facilitate comparisons with Cldr locale names. Arguments backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend!/0 . Note that Cldr.default_backend!/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs .","ref":"Cldr.html#known_gettext_locale_names/1"},{"type":"function","title":"Cldr.known_locale_name/2","doc":"Returns either the locale_name or false based upon whether the locale name is configured in Cldr . This is helpful when building a list of or expressions to return the first known locale name from a list. Arguments locale is any valid locale name returned by Cldr.known_locale_names/1 backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend!/0 . Note that Cldr.default_backend!/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs . Examples iex&gt; Cldr . known_locale_name ( :&quot;en-AU&quot; , TestBackend.Cldr ) :&quot;en-AU&quot; iex&gt; Cldr . known_locale_name ( :&quot;en-SA&quot; , TestBackend.Cldr ) nil","ref":"Cldr.html#known_locale_name/2"},{"type":"function","title":"Cldr.known_locale_name?/2","doc":"Returns a boolean indicating if the specified locale name is configured and available in Cldr. Arguments locale is any valid locale name returned by Cldr.known_locale_names/1 backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend!/0 . Note that Cldr.default_backend!/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs . Examples iex&gt; Cldr . known_locale_name? ( :en , TestBackend.Cldr ) true iex&gt; Cldr . known_locale_name? ( :&quot;!!&quot; , TestBackend.Cldr ) false","ref":"Cldr.html#known_locale_name?/2"},{"type":"function","title":"Cldr.known_locale_names/1","doc":"Returns a list of the known locale names. Arguments backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend!/0 . Note that Cldr.default_backend!/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs . Known locales are those locales which are the subset of all CLDR locales that have been configured for use either directly in the config.exs file or in Gettext .","ref":"Cldr.html#known_locale_names/1"},{"type":"function","title":"Cldr.known_number_system_types/1","doc":"Returns a list of atoms representing the number systems types known to Cldr . Arguments backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend/0 . Note that Cldr.default_backend/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs . Example iex&gt; Cldr . known_number_system_types ( TestBackend.Cldr ) [ :default , :finance , :native , :traditional ]","ref":"Cldr.html#known_number_system_types/1"},{"type":"function","title":"Cldr.known_number_systems/0","doc":"Returns a list of atoms representing the number systems known to Cldr . Example iex&gt; Cldr . known_number_systems [ :adlm , :ahom , :arab , :arabext , :armn , :armnlow , :bali , :beng , :bhks , :brah , :cakm , :cham , :cyrl , :deva , :diak , :ethi , :fullwide , :geor , :gong , :gonm , :grek , :greklow , :gujr , :guru , :hanidays , :hanidec , :hans , :hansfin , :hant , :hantfin , :hebr , :hmng , :hmnp , :java , :jpan , :jpanfin , :jpanyear , :kali , :kawi , :khmr , :knda , :lana , :lanatham , :laoo , :latn , :lepc , :limb , :mathbold , :mathdbl , :mathmono , :mathsanb , :mathsans , :mlym , :modi , :mong , :mroo , :mtei , :mymr , :mymrshan , :mymrtlng , :nagm , :newa , :nkoo , :olck , :orya , :osma , :rohg , :roman , :romanlow , :saur , :segment , :shrd , :sind , :sinh , :sora , :sund , :takr , :talu , :taml , :tamldec , :telu , :thai , :tibt , :tirh , :tnsa , :vaii , :wara , :wcho ]","ref":"Cldr.html#known_number_systems/0"},{"type":"function","title":"Cldr.known_rbnf_locale_name/2","doc":"Returns either the RBNF locale_name or false based upon whether the locale name is configured in Cldr and has RBNF rules defined. Arguments locale is any valid locale name returned by Cldr.known_locale_names/1 backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend!/0 . Note that Cldr.default_backend!/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs . Examples iex&gt; Cldr . known_rbnf_locale_name ( :en , TestBackend.Cldr ) :en iex&gt; Cldr . known_rbnf_locale_name ( :&quot;en-SA&quot; , TestBackend.Cldr ) false","ref":"Cldr.html#known_rbnf_locale_name/2"},{"type":"function","title":"Cldr.known_rbnf_locale_name?/2","doc":"Returns a boolean indicating if the specified locale name is configured and available in Cldr and supports rules based number formats (RBNF). Arguments locale is any valid locale name returned by Cldr.known_locale_names/1 backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend!/0 . Note that Cldr.default_backend!/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs . Examples iex&gt; Cldr . known_rbnf_locale_name? ( :en , TestBackend.Cldr ) true iex&gt; Cldr . known_rbnf_locale_name? ( :&quot;!!&quot; , TestBackend.Cldr ) false","ref":"Cldr.html#known_rbnf_locale_name?/2"},{"type":"function","title":"Cldr.known_rbnf_locale_names/1","doc":"Returns a list of locale names which have rules based number formats (RBNF). Arguments backend is any module that includes use Cldr and therefore is a Cldr backend module","ref":"Cldr.html#known_rbnf_locale_names/1"},{"type":"function","title":"Cldr.known_territories/0","doc":"Returns a list of the territories known to Cldr . The territories codes are defined in UN M.49 which defines both individual territories and enclosing territories. These enclosing territories are defined for statistical purposes and do not relate to political alignment. For example, the territory :&quot;001&quot; is defined as &quot;the world&quot;. Example iex&gt; Cldr . known_territories [ :&quot;001&quot; , :&quot;002&quot; , :&quot;003&quot; , :&quot;005&quot; , :&quot;009&quot; , :&quot;011&quot; , :&quot;013&quot; , :&quot;014&quot; , :&quot;015&quot; , :&quot;017&quot; , :&quot;018&quot; , :&quot;019&quot; , :&quot;021&quot; , :&quot;029&quot; , :&quot;030&quot; , :&quot;034&quot; , :&quot;035&quot; , :&quot;039&quot; , :&quot;053&quot; , :&quot;054&quot; , :&quot;057&quot; , :&quot;061&quot; , :&quot;142&quot; , :&quot;143&quot; , :&quot;145&quot; , :&quot;150&quot; , :&quot;151&quot; , :&quot;154&quot; , :&quot;155&quot; , :&quot;202&quot; , :&quot;419&quot; , :AC , :AD , :AE , :AF , :AG , :AI , :AL , :AM , :AO , :AQ , :AR , :AS , :AT , :AU , :AW , :AX , :AZ , :BA , :BB , :BD , :BE , :BF , :BG , :BH , :BI , :BJ , :BL , :BM , :BN , :BO , :BQ , :BR , :BS , :BT , :BV , :BW , :BY , :BZ , :CA , :CC , :CD , :CF , :CG , :CH , :CI , :CK , :CL , :CM , :CN , :CO , :CP , :CQ , :CR , :CU , :CV , :CW , :CX , :CY , :CZ , :DE , :DG , :DJ , :DK , :DM , :DO , :DZ , :EA , :EC , :EE , :EG , :EH , :ER , :ES , :ET , :EU , :EZ , :FI , :FJ , :FK , :FM , :FO , :FR , :GA , :GB , :GD , :GE , :GF , :GG , :GH , :GI , :GL , :GM , :GN , :GP , :GQ , :GR , :GS , :GT , :GU , :GW , :GY , :HK , :HM , :HN , :HR , :HT , :HU , :IC , :ID , :IE , :IL , :IM , :IN , :IO , :IQ , :IR , :IS , :IT , :JE , :JM , :JO , :JP , :KE , :KG , :KH , :KI , :KM , :KN , :KP , :KR , :KW , :KY , :KZ , :LA , :LB , :LC , :LI , :LK , :LR , :LS , :LT , :LU , :LV , :LY , :MA , :MC , :MD , :ME , :MF , :MG , :MH , :MK , :ML , :MM , :MN , :MO , :MP , :MQ , :MR , :MS , :MT , :MU , :MV , :MW , :MX , :MY , :MZ , :NA , :NC , :NE , :NF , :NG , :NI , :NL , :NO , :NP , :NR , :NU , :NZ , :OM , :PA , :PE , :PF , :PG , :PH , :PK , :PL , :PM , :PN , :PR , :PS , :PT , :PW , :PY , :QA , :QO , :RE , :RO , :RS , :RU , :RW , :SA , :SB , :SC , :SD , :SE , :SG , :SH , :SI , :SJ , :SK , :SL , :SM , :SN , :SO , :SR , :SS , :ST , :SV , :SX , :SY , :SZ , :TA , :TC , :TD , :TF , :TG , :TH , :TJ , :TK , :TL , :TM , :TN , :TO , :TR , :TT , :TV , :TW , :TZ , :UA , :UG , :UM , :UN , :US , :UY , :UZ , :VA , :VC , :VE , :VG , :VI , :VN , :VU , :WF , :WS , :XK , :YE , :YT , :ZA , :ZM , :ZW ]","ref":"Cldr.html#known_territories/0"},{"type":"function","title":"Cldr.known_territory_subdivision_containment/0","doc":"Returns a map of territory subdivisions sith a list of their parent subdivisions and region. For a description of territory subdivisions see Cldr.known_territory_subdivisions/0","ref":"Cldr.html#known_territory_subdivision_containment/0"},{"type":"function","title":"Cldr.known_territory_subdivisions/0","doc":"Returns the map of territories and subdivisions and their child subdivsions. The subdivision codes designate a subdivision of a country or region. They are called various names, such as a state in the United States, or a province in Canada. The codes in CLDR are based on ISO 3166-2 subdivision codes. The ISO codes have a region code followed by a hyphen, then a suffix consisting of 1..3 ASCII letters or digits. The CLDR codes are designed to work in a unicode_locale_id (BCP47), and are thus all lowercase, with no hyphen. For example, the following are valid, and mean “English as used in California, USA”. en - u - sd - usca en - US - u - sd - usca CLDR has additional subdivision codes. These may start with a 3-digit region code or use a suffix of 4 ASCII letters or digits, so they will not collide with the ISO codes. Subdivision codes for unknown values are the region code plus &quot;zzzz&quot;, such as &quot;uszzzz&quot; for an unknown subdivision of the US. Other codes may be added for stability.","ref":"Cldr.html#known_territory_subdivisions/0"},{"type":"function","title":"Cldr.put_default_backend/1","doc":"Set the default system-wide backend module. Arguments backend is any module that includes use Cldr and therefore is a Cldr backend module. Returns {:ok, backend} or {:error, {exception, reason}}","ref":"Cldr.html#put_default_backend/1"},{"type":"function","title":"Cldr.put_default_locale/1","doc":"Set's the system default locale. The locale set here is the base level system default equivalent to setting the :default_locale key in config.exs . Arguments locale is a Cldr.LanguageTag struct returned by Cldr.Locale.new!/2 with a non-nil :cldr_locale_name . Returns {:ok, locale}","ref":"Cldr.html#put_default_locale/1"},{"type":"function","title":"Cldr.put_default_locale/2","doc":"Sets the system default locale. The locale set here is the base level system default equivalent to setting the :default_locale key in config.exs . Arguments locale is any valid locale name returned by Cldr.known_locale_names/1 . backend is any module that includes use Cldr and therefore is a Cldr backend module. Returns {:ok, locale} or {:error, {exception, reason}}","ref":"Cldr.html#put_default_locale/2"},{"type":"function","title":"Cldr.put_gettext_locale/1","doc":"Set the current process's Gettext locale from a t:Cldr.LanguageTag . Arguments locale is a Cldr.LanguageTag struct returned by Cldr.Locale.new!/2 . Returns {:ok, gettext_locale_name} or {:error, {exception, reason}} Behaviour If the locale.gettext_locale_name is nil then an error is returned. The gettext locale for the gettext_backend configured for the CLDR backend defined by the t:Cldr.LanguageTag is set. Examples iex&gt; import Cldr.LanguageTag.Sigil iex&gt; Cldr . put_gettext_locale ( ~l&quot;en&quot; ) { :ok , &quot;en&quot; } iex&gt; import Cldr.LanguageTag.Sigil iex&gt; Cldr . put_gettext_locale ( ~l&quot;de&quot; ) { :error , { Cldr.UnknownLocaleError , &quot;Locale #Cldr.LanguageTag&lt;de [validated]&gt; does not map to a known gettext locale name&quot; } }","ref":"Cldr.html#put_gettext_locale/1"},{"type":"function","title":"Cldr.put_locale/2","doc":"Set the current process's locale for a specified backend or for all backends. Arguments backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is to set the locale for all backends. locale is any valid locale name returned by Cldr.known_locale_names/1 or a Cldr.LanguageTag struct returned by Cldr.Locale.new!/2 . It may also be a map that contains the keys &quot;cldr_locale&quot; and &quot;cldr_backend&quot; which is the shape of a Phoenix and Plug session making it easy to set the locale from a session. Returns {:ok, locale} Behaviour If no backend is provided and the locale is a Cldr.LanguageTag.t then the the locale is set as the default for the current process Notes See rfc5646 for the specification of a language tag Examples iex&gt; Cldr . put_locale ( TestBackend.Cldr , &quot;en&quot; ) { :ok , % Cldr.LanguageTag { backend : TestBackend.Cldr , canonical_locale_name : &quot;en&quot; , cldr_locale_name : :en , language_subtags : [ ] , extensions : %{ } , gettext_locale_name : &quot;en&quot; , language : &quot;en&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :en , requested_locale_name : &quot;en&quot; , script : :Latn , territory : :US , transform : %{ } , language_variants : [ ] } } iex&gt; Cldr . put_locale ( TestBackend.Cldr , &quot;invalid-locale!&quot; ) { :error , { Cldr.LanguageTag.ParseError , &quot;Expected a BCP47 language tag. Could not parse the remaining \\&quot; ! \\&quot; starting at position 15&quot; } }","ref":"Cldr.html#put_locale/2"},{"type":"function","title":"Cldr.quote/3","doc":"Add locale-specific quotation marks around a string. Arguments string is any valid Elixir string backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend!/0 . Note that Cldr.default_backend!/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs . options is a keyword list of options Options :locale is any valid locale name returned by Cldr.known_locale_names/1 . The default is Cldr.get_locale/0 Examples iex&gt; Cldr . quote &quot;Quoted String&quot; , MyApp.Cldr &quot;“Quoted String”&quot; iex&gt; Cldr . quote &quot;Quoted String&quot; , MyApp.Cldr , locale : &quot;ja&quot; &quot;「Quoted String」&quot;","ref":"Cldr.html#quote/3"},{"type":"function","title":"Cldr.requested_locale_names/1","doc":"Returns a list of all requested locale names. Arguments backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend!/0 . Note that Cldr.default_backend!/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs . The list is the combination of configured locales, Gettext locales and the default locale. See also known_locales/1 and all_locales/0","ref":"Cldr.html#requested_locale_names/1"},{"type":"function","title":"Cldr.territory_chain/1","doc":"Return the territory fallback chain based upon a locales territory (including u extension) and territory containment definitions. While CLDR also includes subdivisions in the territory chain, this implementation does not consider them. Arguments territory is either a binary or atom territory code or a t:Cldr.LanguageTag Returns {:ok, list} where list is a list of territories in decreasing order of containment (ie larger enclosing areas) or {:error, {exception, reason}} indicating an error Examples iex&gt; Cldr . territory_chain &quot;US&quot; { :ok , [ :US , :&quot;021&quot; , :&quot;019&quot; , :&quot;001&quot; ] } iex&gt; Cldr . territory_chain :AU { :ok , [ :AU , :&quot;053&quot; , :&quot;009&quot; , :&quot;001&quot; ] } iex&gt; { :ok , locale } = Cldr . validate_locale ( &quot;en-US-u-rg-CAzzzz&quot; , MyApp.Cldr ) iex&gt; Cldr . territory_chain locale { :ok , [ :CA , :&quot;021&quot; , :&quot;019&quot; , :&quot;001&quot; ] } iex&gt; Cldr . territory_chain :&quot;001&quot; { :ok , [ :&quot;001&quot; ] }","ref":"Cldr.html#territory_chain/1"},{"type":"function","title":"Cldr.territory_chain/2","doc":"Return the territory fallback chain based upon a locales territory (including u extension) and territory containment definitions. While CLDR also includes subdivisions in the territory chain, this implementation does not consider them. Arguments locale is a binary locale name backend is any module that includes use Cldr and therefore is a Cldr backend module. Returns {:ok, list} where list is a list of territories in decreasing order of containment (ie larger enclosing areas) or {:error, {exception, reason}} indicating an error Examples iex&gt; Cldr . territory_chain &quot;en-US-u-rg-CAzzzz&quot; , MyApp.Cldr { :ok , [ :CA , :&quot;021&quot; , :&quot;019&quot; , :&quot;001&quot; ] }","ref":"Cldr.html#territory_chain/2"},{"type":"function","title":"Cldr.territory_containment/0","doc":"","ref":"Cldr.html#territory_containment/0"},{"type":"function","title":"Cldr.the_world/0","doc":"Returns the territory for the world This is the outermost containment of territories in CLDR. CLDR does not yet consider non-terrestrial territories.","ref":"Cldr.html#the_world/0"},{"type":"function","title":"Cldr.to_string/1","doc":"Return a localsed string for types that implement the Cldr.Chars protocol. The Cldr.Chars protocol is implemented in this library for t:Cldr.LanguageTag.t() . Other CLDR-related libraries implement the protocol for the types they support such as Float , Integer , Decimal , Money , Unit and List .","ref":"Cldr.html#to_string/1"},{"type":"function","title":"Cldr.unknown_calendar_error/1","doc":"Returns an error tuple for an invalid calendar. Arguments calendar is any calendar name not returned by Cldr.known_calendars/0 Returns {:error, {Cldr.UnknownCalendarError, message}} Examples iex&gt; Cldr . unknown_calendar_error ( &quot;invalid&quot; ) { Cldr.UnknownCalendarError , &quot;The calendar name \\&quot; invalid \\&quot; is invalid&quot; }","ref":"Cldr.html#unknown_calendar_error/1"},{"type":"function","title":"Cldr.unknown_currency_error/1","doc":"Returns an error tuple for an invalid currency. Arguments currency is any currency code not returned by Cldr.known_currencies/0 Returns {:error, {Cldr.UnknownCurrencyError, message}} Examples iex&gt; Cldr . unknown_currency_error ( &quot;invalid&quot; ) { Cldr.UnknownCurrencyError , &quot;The currency \\&quot; invalid \\&quot; is invalid&quot; }","ref":"Cldr.html#unknown_currency_error/1"},{"type":"function","title":"Cldr.unknown_locale_names/1","doc":"Returns a list of the locales names that are configured, but not known in CLDR. Arguments backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend!/0 . Note that Cldr.default_backend!/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs . Since there is a compile-time exception raise if there are any unknown locales this function should always return an empty list.","ref":"Cldr.html#unknown_locale_names/1"},{"type":"function","title":"Cldr.unknown_measurement_system_error/1","doc":"","ref":"Cldr.html#unknown_measurement_system_error/1"},{"type":"function","title":"Cldr.unknown_number_system_error/1","doc":"Returns an error tuple for an unknown number system. Arguments number_system is any number system name not returned by Cldr.known_number_systems/0 Returns {:error, {Cldr.UnknownNumberSystemError, message}} Examples iex&gt; Cldr . unknown_number_system_error &quot;invalid&quot; { Cldr.UnknownNumberSystemError , &quot;The number system \\&quot; invalid \\&quot; is invalid&quot; } iex&gt; Cldr . unknown_number_system_error :invalid { Cldr.UnknownNumberSystemError , &quot;The number system :invalid is unknown&quot; }","ref":"Cldr.html#unknown_number_system_error/1"},{"type":"function","title":"Cldr.unknown_number_system_type_error/1","doc":"Returns an error tuple for an unknown number system type. Options number_system_type is any number system type name not returned by Cldr.known_number_system_types/1 Returns {:error, {Cldr.UnknownNumberSystemTypeError, message}} Examples iex&gt; Cldr . unknown_number_system_type_error ( &quot;invalid&quot; ) { Cldr.UnknownNumberSystemTypeError , &quot;The number system type \\&quot; invalid \\&quot; is invalid&quot; } iex&gt; Cldr . unknown_number_system_type_error ( :invalid ) { Cldr.UnknownNumberSystemTypeError , &quot;The number system type :invalid is unknown&quot; }","ref":"Cldr.html#unknown_number_system_type_error/1"},{"type":"function","title":"Cldr.unknown_plural_type_error/1","doc":"Returns an error tuple for an unknown plural type. Options plural_type is any unknown number system type Returns {:error, {Cldr.UnknownPluralTypeError, message}} Examples iex&gt; Cldr . unknown_plural_type_error ( &quot;invalid&quot; ) { Cldr.UnknownPluralTypeError , &quot;The plural type \\&quot; invalid \\&quot; is invalid&quot; } iex&gt; Cldr . unknown_plural_type_error ( :invalid ) { Cldr.UnknownPluralTypeError , &quot;The plural type :invalid is unknown&quot; }","ref":"Cldr.html#unknown_plural_type_error/1"},{"type":"function","title":"Cldr.unknown_script_error/1","doc":"Returns an error tuple for an invalid script. Arguments script is any script as a string or an atom Returns {:error, {Cldr.InvalidScriptError, message}} Examples iex&gt; Cldr . unknown_script_error &quot;invalid&quot; { Cldr.InvalidScriptError , &quot;The script \\&quot; invalid \\&quot; is invalid&quot; } iex&gt; Cldr . unknown_script_error :invalid { Cldr.InvalidScriptError , &quot;The script :invalid is invalid&quot; }","ref":"Cldr.html#unknown_script_error/1"},{"type":"function","title":"Cldr.unknown_territory_error/1","doc":"Returns an error tuple for an unknown territory. Arguments territory is any territory code not returned by Cldr.known_territories/0 Returns {:error, {Cldr.UnknownTerritoryError, message}} Examples iex&gt; Cldr . unknown_territory_error ( &quot;invalid&quot; ) { Cldr.UnknownTerritoryError , &quot;The territory \\&quot; invalid \\&quot; is unknown&quot; }","ref":"Cldr.html#unknown_territory_error/1"},{"type":"function","title":"Cldr.validate_backend/1","doc":"Validates that a module is a CLDR backend module. Arguments backend is any module name that may be a Cldr backend module. Returns {:ok, backend} is the module if a CLDR backend module or {:error, {exception, reason}} if the module is unknown or if the module is not a backend module. Examples iex&gt; Cldr . validate_backend MyApp.Cldr { :ok , MyApp.Cldr } iex&gt; Cldr . validate_backend :something_else { :error , { Cldr.UnknownBackendError , &quot;The backend :something_else is not known or not a backend module.&quot; } }","ref":"Cldr.html#validate_backend/1"},{"type":"function","title":"Cldr.validate_calendar/1","doc":"Normalise and validate a calendar name. Arguments calendar is any calendar name returned by Cldr.known_calendars/0 Returns {:ok, normalized_calendar_name} or {:error, {Cldr.UnknownCalendarError, message}} Examples iex&gt; Cldr . validate_calendar ( :gregorian ) { :ok , :gregorian } iex&gt; Cldr . validate_calendar ( :invalid ) { :error , { Cldr.UnknownCalendarError , &quot;The calendar name :invalid is invalid&quot; } }","ref":"Cldr.html#validate_calendar/1"},{"type":"function","title":"Cldr.validate_currency/1","doc":"Normalize and validate a currency code. Arguments currency is any ISO 4217 currency code as returned by Cldr.known_currencies/0 or any valid private use ISO4217 code which is a three-letter alphabetic code that starts with &quot;X&quot;. Returns {:ok, normalized_currency_code} or {:error, {Cldr.UnknownCurrencyError, message}} Examples iex&gt; Cldr . validate_currency ( :USD ) { :ok , :USD } iex&gt; Cldr . validate_currency ( &quot;USD&quot; ) { :ok , :USD } iex&gt; Cldr . validate_currency ( :XTC ) { :ok , :XTC } iex&gt; Cldr . validate_currency ( &quot;xtc&quot; ) { :ok , :XTC } iex&gt; Cldr . validate_currency ( &quot;invalid&quot; ) { :error , { Cldr.UnknownCurrencyError , &quot;The currency \\&quot; invalid \\&quot; is invalid&quot; } } iex&gt; Cldr . validate_currency ( :invalid ) { :error , { Cldr.UnknownCurrencyError , &quot;The currency :invalid is invalid&quot; } }","ref":"Cldr.html#validate_currency/1"},{"type":"function","title":"Cldr.validate_gettext_locale/2","doc":"Normalise and validate a gettext locale name. Arguments locale_name is any valid locale name returned by Cldr.known_locale_names/1 or a Cldr.LanguageTag struct returned by Cldr.Locale.new!/2 backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend/0 . Note that Cldr.default_backend/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs . Returns {:ok, language_tag} {:error, reason} Examples","ref":"Cldr.html#validate_gettext_locale/2"},{"type":"function","title":"Cldr.validate_locale/2","doc":"Normalise and validate a locale name. Arguments locale is any valid locale name returned by Cldr.known_locale_names/1 or a Cldr.LanguageTag struct returned by Cldr.Locale.new!/2 backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend!/0 . Note that Cldr.default_backend!/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs . Returns {:ok, language_tag} {:error, reason} Examples iex&gt; Cldr . validate_locale ( :en , TestBackend.Cldr ) { :ok , % Cldr.LanguageTag { backend : TestBackend.Cldr , canonical_locale_name : &quot;en&quot; , cldr_locale_name : :en , extensions : %{ } , gettext_locale_name : &quot;en&quot; , language : &quot;en&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :en , requested_locale_name : &quot;en&quot; , script : :Latn , territory : :US , transform : %{ } , language_variants : [ ] } } iex&gt; Cldr . validate_locale ( :af , TestBackend.Cldr ) { :ok , % Cldr.LanguageTag { backend : TestBackend.Cldr , canonical_locale_name : &quot;af&quot; , cldr_locale_name : :af , extensions : %{ } , gettext_locale_name : nil , language : &quot;af&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :af , requested_locale_name : &quot;af&quot; , script : :Latn , territory : :ZA , transform : %{ } , language_variants : [ ] } } iex&gt; Cldr . validate_locale ( &quot;zzz&quot; , TestBackend.Cldr ) { :error , { Cldr.InvalidLanguageError , &quot;The language \\&quot; zzz \\&quot; is invalid&quot; } }","ref":"Cldr.html#validate_locale/2"},{"type":"function","title":"Cldr.validate_measurement_system/1","doc":"Normalise and validate a measurement system type. Arguments measurement_system is a known measurement system. Returns {:ok, normalized_measurement_system} or {:error, {exception, message}} Examples iex&gt; Cldr . validate_measurement_system :metric { :ok , :metric } iex&gt; Cldr . validate_measurement_system &quot;ussystem&quot; { :ok , :ussystem } iex&gt; Cldr . validate_measurement_system &quot;uksystem&quot; { :ok , :uksystem } iex&gt; Cldr . validate_measurement_system &quot;something&quot; { :error , { Cldr.UnknownMeasurementSystemError , &quot;The measurement system \\&quot; something \\&quot; is invalid&quot; } }","ref":"Cldr.html#validate_measurement_system/1"},{"type":"function","title":"Cldr.validate_number_system/1","doc":"Normalize and validate a number system name. Arguments number_system is any number system name returned by Cldr.known_number_systems/0 Returns {:ok, normalized_number_system_name} or {:error, {exception, message}} Examples iex&gt; Cldr . validate_number_system :latn { :ok , :latn } iex&gt; Cldr . validate_number_system :arab { :ok , :arab } iex&gt; Cldr . validate_number_system &quot;invalid&quot; { :error , { Cldr.UnknownNumberSystemError , &quot;The number system :invalid is unknown&quot; } }","ref":"Cldr.html#validate_number_system/1"},{"type":"function","title":"Cldr.validate_number_system_type/2","doc":"Normalise and validate a number system type. Arguments number_system_type is any number system type returned by Cldr.known_number_system_types/1 backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend/0 . Note that Cldr.default_backend/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs . Returns {:ok, normalized_number_system_type} or {:error, {exception, message}} Examples iex&gt; Cldr . validate_number_system_type ( :default , TestBackend.Cldr ) { :ok , :default } iex&gt; Cldr . validate_number_system_type ( :traditional , TestBackend.Cldr ) { :ok , :traditional } iex&gt; Cldr . validate_number_system_type ( :latn , TestBackend.Cldr ) { :error , { Cldr.UnknownNumberSystemTypeError , &quot;The number system type :latn is unknown&quot; } }","ref":"Cldr.html#validate_number_system_type/2"},{"type":"function","title":"Cldr.validate_plural_type/1","doc":"Normalize and validate a plural type. Arguments plural_type is any plural type returned by Cldr.Number.PluralRule.known_plural_types/0 Returns {:ok, normalized_plural_type} or {:error, {exception, message}} Examples iex&gt; Cldr . validate_plural_type :few { :ok , :few } iex&gt; Cldr . validate_plural_type &quot;one&quot; { :ok , :one } iex&gt; Cldr . validate_plural_type &quot;invalid&quot; { :error , { Cldr.UnknownPluralTypeError , &quot;The plural type :invalid is unknown&quot; } }","ref":"Cldr.html#validate_plural_type/1"},{"type":"function","title":"Cldr.validate_script/1","doc":"Normalise and validate a script code. Arguments script is any script code as a binary or atom Returns: {:ok, normalized_script_code} or {:error, {Cldr.UnknownscriptError, message}} Examples iex&gt; Cldr . validate_script ( &quot;thai&quot; ) { :ok , :Thai } iex&gt; Cldr . validate_script ( &quot;qaai&quot; ) { :ok , :Zinh } iex&gt; Cldr . validate_script ( Cldr.Locale . new! ( &quot;en&quot; , TestBackend.Cldr ) ) { :ok , :Latn } iex&gt; Cldr . validate_script ( &quot;aaaa&quot; ) { :error , { Cldr.InvalidScriptError , &quot;The script \\&quot; aaaa \\&quot; is invalid&quot; } } iex&gt; Cldr . validate_script ( %{ } ) { :error , { Cldr.InvalidScriptError , &quot;The script %{} is invalid&quot; } }","ref":"Cldr.html#validate_script/1"},{"type":"function","title":"Cldr.validate_territory/1","doc":"Normalise and validate a territory code. Arguments territory is any territory code returned by Cldr.known_territories/0 Returns: {:ok, normalized_territory_code} or {:error, {Cldr.UnknownTerritoryError, message}} Examples iex&gt; Cldr . validate_territory ( &quot;en&quot; ) { :error , { Cldr.UnknownTerritoryError , &quot;The territory \\&quot; en \\&quot; is unknown&quot; } } iex&gt; Cldr . validate_territory ( &quot;gb&quot; ) { :ok , :GB } iex&gt; Cldr . validate_territory ( &quot;001&quot; ) { :ok , :&quot;001&quot; } iex&gt; Cldr . validate_territory ( Cldr.Locale . new! ( &quot;en&quot; , TestBackend.Cldr ) ) { :ok , :US } iex&gt; Cldr . validate_territory ( %{ } ) { :error , { Cldr.UnknownTerritoryError , &quot;The territory %{} is unknown&quot; } }","ref":"Cldr.html#validate_territory/1"},{"type":"function","title":"Cldr.validate_territory_subdivision/1","doc":"Normalise and validate a territory subdivision code. Arguments subdivision is any territory code returned by Cldr.known_territory_subdivisions/0 Returns: {:ok, normalized_subdivision_code} or {:error, {Cldr.UnknownTerritoryError, message}} Examples","ref":"Cldr.html#validate_territory_subdivision/1"},{"type":"function","title":"Cldr.version/0","doc":"Returns the version of the CLDR repository. Example iex&gt; Cldr . version Version . parse! ( &quot;43.0.0&quot; )","ref":"Cldr.html#version/0"},{"type":"function","title":"Cldr.with_locale/2","doc":"Execute a function with a locale ensuring that the current locale is restored after the function. Arguments locale is any Cldr.LanguageTag.t/0 , tyically returned by Cldr.validate_locale/2 . fun is any 0-arity function or function capture. Returns The value returned by the function fun/0 or raises an exception if the current locale cannot be identified.","ref":"Cldr.html#with_locale/2"},{"type":"function","title":"Cldr.with_locale/3","doc":"Execute a function with a locale ensuring that the current locale is restored after the function. Arguments locale is any valid locale name returned by Cldr.known_locale_names/1 . backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend!/0 . fun is any 0-arity function or function capture. Returns The value returned by the function fun/0 or {:error, {exception, reason}} if the locale is invalid or raises an exception if the current locale cannot be identified.","ref":"Cldr.html#with_locale/3"},{"type":"type","title":"Cldr.backend/0","doc":"","ref":"Cldr.html#t:backend/0"},{"type":"module","title":"Cldr.AcceptLanguage","doc":"Tokenizer and parser for HTTP Accept-Language header values as defined in rfc2616 . The Accept-Language request-header field is similar to Accept, but restricts the set of natural languages that are preferred as a response to the request. Language tags function are provided in Cldr.LanguageTag . The format of an Accept-Language header is as follows in ABNF format: Accept - Language = &quot;Accept-Language&quot; &quot;:&quot; 1 #( language-range [ &quot;;&quot; &quot;q&quot; &quot;=&quot; qvalue ] ) language - range = ( ( 1 * 8 ALPHA * ( &quot;-&quot; 1 * 8 ALPHA ) ) | &quot;*&quot; ) Each language-range MAY be given an associated quality value which represents an estimate of the user's preference for the languages specified by that range. The quality value defaults to &quot;q=1&quot;. For example, Accept - Language : da , en - gb ; q = 0.8 , en ; q = 0.7 would mean: &quot;I prefer Danish, but will accept British English and other types of English.&quot;","ref":"Cldr.AcceptLanguage.html"},{"type":"function","title":"Cldr.AcceptLanguage.best_match/2","doc":"Parse an Accept-Language string and return the best match for a configured Cldr locale. accept_langauge is a string representing an accept language header Returns: {:ok, language_tag} or {:error, reason} Examples iex&gt; Cldr.AcceptLanguage . best_match ( &quot;da;q=0.1,zh-TW;q=0.3&quot; , TestBackend.Cldr ) { :ok , % Cldr.LanguageTag { backend : TestBackend.Cldr , canonical_locale_name : &quot;zh-TW&quot; , cldr_locale_name : :&quot;zh-Hant&quot; , language_subtags : [ ] , extensions : %{ } , gettext_locale_name : nil , language : &quot;zh&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :&quot;zh-Hant&quot; , requested_locale_name : &quot;zh-TW&quot; , script : :Hant , territory : :TW , transform : %{ } , language_variants : [ ] } } iex&gt; Cldr.AcceptLanguage . best_match ( &quot;da;q=0.1,zh-TW;q=0.3&quot; , TestBackend.Cldr ) { :ok , % Cldr.LanguageTag { backend : TestBackend.Cldr , canonical_locale_name : &quot;zh-TW&quot; , cldr_locale_name : :&quot;zh-Hant&quot; , language_subtags : [ ] , extensions : %{ } , gettext_locale_name : nil , language : &quot;zh&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :&quot;zh-Hant&quot; , requested_locale_name : &quot;zh-TW&quot; , script : :Hant , territory : :TW , transform : %{ } , language_variants : [ ] } } iex&gt; Cldr.AcceptLanguage . best_match ( &quot;xx,yy;q=0.3&quot; , TestBackend.Cldr ) { :error , { Cldr.NoMatchingLocale , &quot;No configured locale could be matched to \\&quot; xx,yy;q=0.3 \\&quot; &quot; } } iex&gt; Cldr.AcceptLanguage . best_match ( &quot;invalid_tag&quot; , TestBackend.Cldr ) { :error , { Cldr.LanguageTag.ParseError , &quot;Expected a BCP47 language tag. Could not parse the remaining \\&quot; g \\&quot; starting at position 11&quot; } }","ref":"Cldr.AcceptLanguage.html#best_match/2"},{"type":"function","title":"Cldr.AcceptLanguage.errors/1","doc":"Filters the returned results of parse/1 to return only the error tuples. Example iex&gt; Cldr.AcceptLanguage . parse! ( &quot;da,zh-TW;q=0.3,invalid_tag&quot; , TestBackend.Cldr ) ...&gt; |&gt; Cldr.AcceptLanguage . errors [ error : { Cldr.LanguageTag.ParseError , &quot;Expected a BCP47 language tag. Could not parse the remaining \\&quot; g \\&quot; starting at position 11&quot; } ]","ref":"Cldr.AcceptLanguage.html#errors/1"},{"type":"function","title":"Cldr.AcceptLanguage.parse/2","doc":"Parses an Accept-Language header value in its string or tokenized form to return a tuple of the form {:ok, [{quality, %Cldr.LanguageTag{}}, ...]} sorted by quality. Arguments accept-language is any string in the format defined by rfc2616 backend is any module that includes use Cldr and therefore is a Cldr backend module Returns {:ok, [{quality, language_tag}, ...]} or {:error, {Cldr.AcceptLanguageError, String.t}} If at least one valid language tag is found but errors are also detected on one more more tags, an {ok, list} tuple is returned wuth an error tuple for each invalid tag added at the end of the list. Example iex&gt; Cldr.AcceptLanguage . parse ( &quot;da,zh-TW;q=0.3&quot; , TestBackend.Cldr ) { :ok , [ { 1.0 , % Cldr.LanguageTag { backend : TestBackend.Cldr , canonical_locale_name : &quot;da&quot; , cldr_locale_name : :da , language_subtags : [ ] , extensions : %{ } , gettext_locale_name : nil , language : &quot;da&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :da , requested_locale_name : &quot;da&quot; , script : :Latn , territory : :DK , transform : %{ } , language_variants : [ ] } } , { 0.3 , % Cldr.LanguageTag { backend : TestBackend.Cldr , canonical_locale_name : &quot;zh-TW&quot; , cldr_locale_name : :&quot;zh-Hant&quot; , language_subtags : [ ] , extensions : %{ } , gettext_locale_name : nil , language : &quot;zh&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :&quot;zh-Hant&quot; , requested_locale_name : &quot;zh-TW&quot; , script : :Hant , territory : :TW , transform : %{ } , language_variants : [ ] } } ] } iex&gt; Cldr.AcceptLanguage . parse ( &quot;invalid_tag&quot; , TestBackend.Cldr ) { :error , { Cldr.LanguageTag.ParseError , &quot;Expected a BCP47 language tag. Could not parse the remaining \\&quot; g \\&quot; starting at position 11&quot; } } iex&gt; Cldr.AcceptLanguage . parse ( &quot;da,zh-TW;q=0.3,invalid_tag&quot; , TestBackend.Cldr ) { :ok , [ { 1.0 , % Cldr.LanguageTag { backend : TestBackend.Cldr , canonical_locale_name : &quot;da&quot; , cldr_locale_name : :da , language_subtags : [ ] , extensions : %{ } , gettext_locale_name : nil , language : &quot;da&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :da , requested_locale_name : &quot;da&quot; , script : :Latn , territory : :DK , transform : %{ } , language_variants : [ ] } } , { 0.3 , % Cldr.LanguageTag { backend : TestBackend.Cldr , canonical_locale_name : &quot;zh-TW&quot; , cldr_locale_name : :&quot;zh-Hant&quot; , language_subtags : [ ] , extensions : %{ } , gettext_locale_name : nil , language : &quot;zh&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :&quot;zh-Hant&quot; , requested_locale_name : &quot;zh-TW&quot; , script : :Hant , territory : :TW , transform : %{ } , language_variants : [ ] } } , { :error , { Cldr.LanguageTag.ParseError , &quot;Expected a BCP47 language tag. Could not parse the remaining \\&quot; g \\&quot; starting at position 11&quot; } } ] }","ref":"Cldr.AcceptLanguage.html#parse/2"},{"type":"function","title":"Cldr.AcceptLanguage.parse!/2","doc":"Parses an Accept-Language header value in its string or tokenized form to produce a list of tuples of the form [{quality, %Cldr.LanguageTag{}}, ...] sorted by quality in descending order. accept-language is any string in the format defined by rfc2616 Returns: {:ok, [{quality, language_tag}, ...]} or raises a Cldr.AcceptLanguageError exception If at least one valid language tag is found but errors are also detected on one more more tags, an {ok, list} tuple is returned wuth an error tuple for each invalid tag added at the end of the list. Example iex&gt; Cldr.AcceptLanguage . parse! ( &quot;da,zh-TW;q=0.3&quot; , TestBackend.Cldr ) [ { 1.0 , % Cldr.LanguageTag { backend : TestBackend.Cldr , canonical_locale_name : &quot;da&quot; , cldr_locale_name : :da , language_subtags : [ ] , extensions : %{ } , gettext_locale_name : nil , language : &quot;da&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :da , requested_locale_name : &quot;da&quot; , script : :Latn , territory : :DK , transform : %{ } , language_variants : [ ] } } , { 0.3 , % Cldr.LanguageTag { backend : TestBackend.Cldr , canonical_locale_name : &quot;zh-TW&quot; , cldr_locale_name : :&quot;zh-Hant&quot; , language_subtags : [ ] , extensions : %{ } , gettext_locale_name : nil , language : &quot;zh&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :&quot;zh-Hant&quot; , requested_locale_name : &quot;zh-TW&quot; , script : :Hant , territory : :TW , transform : %{ } , language_variants : [ ] } } ] Cldr.AcceptLanguage . parse! &quot;invalid_tag&quot; ** (Cldr.AcceptLanguageError) &quot;Expected a BCP47 language tag. Could not parse the remaining &quot;g&quot; starting at position 11 (ex_cldr) lib/cldr/accept_language.ex:304: Cldr.AcceptLanguage.parse!/1 iex&gt; Cldr.AcceptLanguage . parse! ( &quot;da,zh-TW;q=0.3,invalid_tag&quot; , TestBackend.Cldr ) [ { 1.0 , % Cldr.LanguageTag { backend : TestBackend.Cldr , canonical_locale_name : &quot;da&quot; , cldr_locale_name : :da , language_subtags : [ ] , extensions : %{ } , gettext_locale_name : nil , language : &quot;da&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :da , requested_locale_name : &quot;da&quot; , script : :Latn , territory : :DK , transform : %{ } , language_variants : [ ] } } , { 0.3 , % Cldr.LanguageTag { backend : TestBackend.Cldr , canonical_locale_name : &quot;zh-TW&quot; , cldr_locale_name : :&quot;zh-Hant&quot; , language_subtags : [ ] , extensions : %{ } , gettext_locale_name : nil , language : &quot;zh&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :&quot;zh-Hant&quot; , requested_locale_name : &quot;zh-TW&quot; , script : :Hant , territory : :TW , transform : %{ } , language_variants : [ ] } } , { :error , { Cldr.LanguageTag.ParseError , &quot;Expected a BCP47 language tag. Could not parse the remaining \\&quot; g \\&quot; starting at position 11&quot; } } ]","ref":"Cldr.AcceptLanguage.html#parse!/2"},{"type":"function","title":"Cldr.AcceptLanguage.sort_by_quality/1","doc":"","ref":"Cldr.AcceptLanguage.html#sort_by_quality/1"},{"type":"function","title":"Cldr.AcceptLanguage.tokenize/1","doc":"Splits the language ranges for an Accept-Language header value into tuples {quality, language} . accept-language is any string in the format defined by rfc2616 Example iex&gt; Cldr.AcceptLanguage . tokenize &quot;da,zh-TW;q=0.3&quot; [ { 1.0 , &quot;da&quot; } , { 0.3 , &quot;zh-tw&quot; } ]","ref":"Cldr.AcceptLanguage.html#tokenize/1"},{"type":"module","title":"Cldr.Locale","doc":"Functions to parse and normalize locale names into a structure locale represented by a Cldr.LanguageTag . CLDR represents localisation data organized into locales, with each locale being identified by a locale name that is formatted according to RFC5646 . In practise, the CLDR data utilizes a simple subset of locale name formats being: a Language code such as en or fr a Language code and Territory code such as en-GB a Language code and Script such as zh-Hant and in only two cases a Language code, Territory code and Variant such as ca-ES-valencia and en-US-posix . The RFC defines a language tag as: A language tag is composed from a sequence of one or more &quot;subtags&quot;, each of which refines or narrows the range of language identified by the overall tag. Subtags, in turn, are a sequence of alphanumeric characters (letters and digits), distinguished and separated from other subtags in a tag by a hyphen (&quot;-&quot;, [Unicode] U+002D) Therefore Cldr uses the hyphen (&quot;-&quot;, [Unicode] U+002D) as the subtag separator. On certain platforms, including POSIX platforms, the subtag separator is a &quot;_&quot; (underscore) rather than a &quot;-&quot; (hyphen). Where appropriate, Cldr will transliterate any underscore into a hyphen before parsing or processing. Locale name validity When validating a locale name, Cldr will attempt to match the requested locale name to a configured locale. Therefore Cldr.Locale.new/2 may return an {:ok, language_tag} tuple even when the locale returned does not exactly match the requested locale name. For example, the following attempts to create a locale matching the non-existent &quot;english as spoken in Spain&quot; local name. Here Cldr will match to the nearest configured locale, which in this case will be &quot;en&quot;. iex&gt; Cldr.Locale . new ( &quot;en-ES&quot; , TestBackend.Cldr ) { :ok , % Cldr.LanguageTag { backend : TestBackend.Cldr , canonical_locale_name : &quot;en-ES&quot; , cldr_locale_name : :en , extensions : %{ } , gettext_locale_name : &quot;en&quot; , language : &quot;en&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :en , requested_locale_name : &quot;en-ES&quot; , script : :Latn , territory : :ES , transform : %{ } , language_variants : [ ] } } Matching locales to requested locale names When attempting to match the requested locale name to a configured locale, Cldr attempt to match against a set of reductions in the following order and will return the first match: language, script, territory, [variants] language, territory, [variants] language, script, [variants] language, [variants] language, script, territory language, territory language, script language requested locale name nil Therefore matching is tolerant of a request for unknown scripts, territories and variants. Only the requested language is a requirement to be matched to a configured locale. Substitutions for Obsolete and Deprecated locale names CLDR provides data to help manage the transition from obsolete or deprecated locale names to current names. For example, the following requests the locale name &quot;mo&quot; which is the deprecated code for &quot;Moldovian&quot;. The replacement code is &quot;ro&quot; (Romanian). iex&gt; Cldr.Locale . new ( &quot;mo&quot; , TestBackend.Cldr ) { :ok , % Cldr.LanguageTag { backend : TestBackend.Cldr , extensions : %{ } , gettext_locale_name : nil , language : &quot;ro&quot; , language_subtags : [ ] , language_variants : [ ] , locale : %{ } , private_use : [ ] , rbnf_locale_name : :ro , requested_locale_name : &quot;mo&quot; , script : :Latn , transform : %{ } , canonical_locale_name : &quot;ro&quot; , cldr_locale_name : :ro , territory : :RO } } Likely subtags CLDR also provides data to indetify the most likely subtags for a requested locale name. This data is based on the default content data, the population data, and the suppress-script data in [BCP47]. It is heuristically derived, and may change over time. For example, when requesting the locale &quot;en&quot;, the following is returned: iex&gt; Cldr.Locale . new ( &quot;en&quot; , TestBackend.Cldr ) { :ok , % Cldr.LanguageTag { backend : TestBackend.Cldr , canonical_locale_name : &quot;en&quot; , cldr_locale_name : :en , extensions : %{ } , gettext_locale_name : &quot;en&quot; , language : &quot;en&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :en , requested_locale_name : &quot;en&quot; , script : :Latn , territory : :US , transform : %{ } , language_variants : [ ] } } Which shows that a the likely subtag for the script is :Latn and the likely territory is &quot;US&quot;. Using the example for Substitutions above, we can see the result of combining substitutions and likely subtags for locale name &quot;mo&quot; returns the current language code of &quot;ro&quot; as well as the likely territory code of &quot;MD&quot; (Moldova). Unknown territory codes Whilst Cldr is tolerant of invalid territory codes. Therefore validity is not checked by Cldr.Locale.new/2 but it is checked by Cldr.validate_locale/2 which is the recommended api for forming language tags. iex&gt; Cldr.Locale . new ( &quot;en-XX&quot; , TestBackend.Cldr ) { :ok , % Cldr.LanguageTag { backend : TestBackend.Cldr , canonical_locale_name : &quot;en-XX&quot; , cldr_locale_name : :en , extensions : %{ } , gettext_locale_name : &quot;en&quot; , language : &quot;en&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :en , requested_locale_name : &quot;en-XX&quot; , script : :Latn , territory : :XX , transform : %{ } , language_variants : [ ] } } Locale extensions Unicode defines the U extension which support defining the requested treatment of CLDR data formats. For example, a locale name can configure the requested: calendar to be used for dates collation currency currency format number system first day of the week 12-hour or 24-hour time time zone and many other items For example, the following locale name will request the use of the timezone Australia/Sydney , and request the use of accounting format when formatting currencies: iex&gt; MyApp.Cldr . validate_locale &quot;en-AU-u-tz-ausyd-cf-account&quot; { :ok , % Cldr.LanguageTag { backend : MyApp.Cldr , canonical_locale_name : &quot;en-AU-u-cf-account-tz-ausyd&quot; , cldr_locale_name : :&quot;en-AU&quot; , extensions : %{ } , gettext_locale_name : &quot;en&quot; , language : &quot;en&quot; , language_subtags : [ ] , language_variants : [ ] , locale : % Cldr.LanguageTag.U { calendar : nil , cf : :account , col_alternate : nil , col_backwards : nil , col_case_first : nil , col_case_level : nil , col_normalization : nil , col_numeric : nil , col_reorder : nil , col_strength : nil , collation : nil , currency : nil , dx : nil , em : nil , fw : nil , hc : nil , lb : nil , lw : nil , ms : nil , numbers : nil , rg : nil , sd : nil , ss : nil , timezone : &quot;Australia/Sydney&quot; , va : nil , vt : nil } , private_use : &#39;&#39; , rbnf_locale_name : :en , requested_locale_name : &quot;en-AU&quot; , script : :Latn , territory : :AU , transform : %{ } } }","ref":"Cldr.Locale.html"},{"type":"function","title":"Cldr.Locale.aliases/0","doc":"Return a map of the known aliases for Language, Script and Territory","ref":"Cldr.Locale.html#aliases/0"},{"type":"function","title":"Cldr.Locale.aliases/2","doc":"Return a map of the aliases for a given alias key and type Options type is one of [:language, :region, :script, :variant, :zone] key is the substitution key (a language, region, script, variant or zone)","ref":"Cldr.Locale.html#aliases/2"},{"type":"function","title":"Cldr.Locale.canonical_language_tag/3","doc":"Parses a locale name and returns a Cldr.LanguageTag struct that represents a locale. Arguments language_tag is any language tag returned by Cldr.Locale.new/2 or any locale_name returned by Cldr.known_locale_names/1 backend is any module that includes use Cldr and therefore is a Cldr backend module options is a keyword list of options Options :add_likely_subtags is a boolean thatdetermines if subtags that are likely to be applicable to this language tag are added to the language tag. The default is true . Returns {:ok, language_tag} or {:error, reason} Method The language tag is parsed in accordance with RFC5646 Any language, script or region aliases are replaced. This will replace any obsolete elements with current versions. If a territory, script or language variant is not specified, then a default is provided using the CLDR information returned by Cldr.Locale.likely_subtags/1 if the option :add_likely_subtags is true (the default). A Cldr locale name is selected that is the nearest fit to the requested locale. Example iex&gt; Cldr.Locale . canonical_language_tag ( &quot;en&quot; , TestBackend.Cldr ) { :ok , % Cldr.LanguageTag { backend : TestBackend.Cldr , canonical_locale_name : &quot;en&quot; , cldr_locale_name : :en , extensions : %{ } , gettext_locale_name : &quot;en&quot; , language : &quot;en&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :en , requested_locale_name : &quot;en&quot; , script : :Latn , territory : :US , transform : %{ } , language_variants : [ ] } }","ref":"Cldr.Locale.html#canonical_language_tag/3"},{"type":"function","title":"Cldr.Locale.canonical_language_tag!/3","doc":"Parses a locale name and returns a Cldr.LanguageTag struct that represents a locale or raises on error. Arguments language_tag is any language tag returned by Cldr.Locale.new/2 or any locale_name returned by Cldr.known_locale_names/1 backend is any module that includes use Cldr and therefore is a Cldr backend module See Cldr.Locale.canonical_language_tag/3 for more information.","ref":"Cldr.Locale.html#canonical_language_tag!/3"},{"type":"function","title":"Cldr.Locale.consider_as_tlds/0","doc":"Returns a list of territory top-level domains that are considered to be generic top level domains. See https://developers.google.com/search/docs/advanced/crawling/managing-multi-regional-sites for an explanation of why some valid territory suffixxes are considered as TLDs. Example iex&gt; Cldr.Locale . consider_as_tlds [ :AD , :AS , :BZ , :CC , :CD , :CO , :DJ , :FM , :IO , :LA , :ME , :MS , :NU , :SC , :SR , :SU , :TV , :TK , :WS ]","ref":"Cldr.Locale.html#consider_as_tlds/0"},{"type":"function","title":"Cldr.Locale.fallback_locale_names/1","doc":"Returns the list of fallback locale names, starting with the provided locale. Fallbacks are a list of locate names which can be used to resolve translation or other localization data if such localised data does not exist for this specific locale. Arguments locale is any LanguageTag.t Returns {:ok, list_of_locale_names} or {:error, {exception, reason}} Examples In these examples the default locale is :&quot;en-001&quot; . iex&gt; Cldr.Locale . fallback_locale_names ( Cldr.Locale . new! ( &quot;fr-CA&quot; , MyApp.Cldr ) ) { :ok , [ :&quot;fr-CA&quot; , :fr , :und ] } # Fallbacks are typically formed by progressively # stripping variant, territory and script from the # given locale name. But not always - there are # certain fallbacks that take a different path. iex&gt; Cldr.Locale . fallback_locale_names ( Cldr.Locale . new! ( &quot;nb&quot; , MyApp.Cldr ) ) { :ok , [ :nb , :no , :und ] }","ref":"Cldr.Locale.html#fallback_locale_names/1"},{"type":"function","title":"Cldr.Locale.fallback_locale_names/2","doc":"Returns the list of fallback locale names, starting the the provided locale name. Fallbacks are a list of locate names which can be used to resolve translation or other localization data if such localised data does not exist for this specific locale. Arguments locale_name is any locale name returned by Cldr.known_locale_names/1 backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_locale/0 . Returns {:ok, list_of_locale_names} or {:error, {exception, reason}} Examples In these examples the default locale is :&quot;en-001&quot; . iex&gt; Cldr.Locale . fallback_locale_names ( :&quot;fr-CA&quot; ) { :ok , [ :&quot;fr-CA&quot; , :fr , :und ] } # Fallbacks are typically formed by progressively # stripping variant, territory and script from the # given locale name. But not always - there are # certain fallbacks that take a different path. iex&gt; Cldr.Locale . fallback_locale_names ( :nb ) { :ok , [ :nb , :no , :und ] }","ref":"Cldr.Locale.html#fallback_locale_names/2"},{"type":"function","title":"Cldr.Locale.fallback_locale_names!/1","doc":"Returns the list of fallback locale names, starting with the provided locale. Fallbacks are a list of locate names which can be used to resolve translation or other localization data if such localised data does not exist for this specific locale. Arguments locale is any LanguageTag.t Returns list_of_locale_names or raises an exception Examples In these examples the default locale is :&quot;en-001&quot; . iex&gt; Cldr.Locale . fallback_locale_names! ( Cldr.Locale . new! ( &quot;fr-CA&quot; , MyApp.Cldr ) ) [ :&quot;fr-CA&quot; , :fr , :und ] # Fallbacks are typically formed by progressively # stripping variant, territory and script from the # given locale name. But not always - there are # certain fallbacks that take a different path. iex&gt; Cldr.Locale . fallback_locale_names! ( Cldr.Locale . new! ( &quot;nb&quot; , MyApp.Cldr ) ) [ :nb , :no , :und ]","ref":"Cldr.Locale.html#fallback_locale_names!/1"},{"type":"function","title":"Cldr.Locale.fallback_locales/1","doc":"Returns the list of fallback locales, starting the the provided locale. Fallbacks are a list of locate names which can be used to resolve translation or other localization data if such localised data does not exist for this specific locale. Arguments locale is any LanguageTag.t Returns {:ok, list_of_locales} or {:error, {exception, reason}} Examples Cldr.Locale . fallback_locales ( Cldr.Locale . new! ( &quot;fr-CA&quot; , MyApp.Cldr ) ) =&gt; { :ok , [ # Cldr.LanguageTag &lt; fr - CA [ validated ] &gt; , # Cldr.LanguageTag &lt; fr [ validated ] &gt; , # Cldr.LanguageTag &lt; und [ validated ] &gt; ] } # Fallbacks are typically formed by progressively # stripping variant, territory and script from the # given locale name. But not always - there are # certain fallbacks that take a different path. Cldr.Locale . fallback_locales ( Cldr.Locale . new! ( &quot;nb&quot; , MyApp.Cldr ) ) =&gt; { :ok , [ # Cldr.LanguageTag &lt; nb [ validated ] &gt; , # Cldr.LanguageTag &lt; no [ validated ] &gt; , # Cldr.LanguageTag &lt; und [ validated ] &gt; ] }","ref":"Cldr.Locale.html#fallback_locales/1"},{"type":"function","title":"Cldr.Locale.fallback_locales/2","doc":"Returns the list of fallback locales, starting the the provided locale. Fallbacks are a list of locate names which can be used to resolve translation or other localization data if such localised data does not exist for this specific locale. Arguments locale_name is any locale name returned by Cldr.known_locale_names/1 backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_locale/0 . Returns {:ok, list_of_locales} or {:error, {exception, reason}} Examples Cldr.Locale . fallback_locales ( :&quot;fr-CA&quot; ) =&gt; { :ok , [ # Cldr.LanguageTag &lt; fr - CA [ validated ] &gt; , # Cldr.LanguageTag &lt; fr [ validated ] &gt; , # Cldr.LanguageTag &lt; und [ validated ] &gt; ] } # Fallbacks are typically formed by progressively # stripping variant, territory and script from the # given locale name. But not always - there are # certain fallbacks that take a different path. Cldr.Locale . fallback_locales ( :nb ) =&gt; { :ok , [ # Cldr.LanguageTag &lt; nb [ validated ] &gt; , # Cldr.LanguageTag &lt; no [ validated ] &gt; , # Cldr.LanguageTag &lt; und [ validated ] &gt; ] }","ref":"Cldr.Locale.html#fallback_locales/2"},{"type":"function","title":"Cldr.Locale.first_match/3","doc":"Execute a function for a locale returning the first match on language, script, territory, and variant combination. A match is determined when the fun/1 returns a truthy value. Arguments language_tag is any language tag returned by Cldr.Locale.new/2 . fun/2 is 2-arity function that takes a string locale name and subtags. The locale name is a built from the language, script, territory and variant combinations of language_tag . omit_singular_script? is a boolean indicating if a match should fail if the language tag script is the only (default) script for the lanaguge. The default is false . Returns The first truthy value returned by fun/2 or nil if no match is made.","ref":"Cldr.Locale.html#first_match/3"},{"type":"macro","title":"Cldr.Locale.is_locale_name/1","doc":"","ref":"Cldr.Locale.html#is_locale_name/1"},{"type":"function","title":"Cldr.Locale.language_data/0","doc":"Mapping of language data to known scripts and territories","ref":"Cldr.Locale.html#language_data/0"},{"type":"function","title":"Cldr.Locale.languages_for_territories/0","doc":"Returns a map of a territory code to its most-spoken language. Example Cldr.Locale . languages_for_territories ( ) =&gt; %{ AQ : &quot;und&quot; , PE : &quot;es&quot; , SR : &quot;nl&quot; , NU : &quot;en&quot; , ... }","ref":"Cldr.Locale.html#languages_for_territories/0"},{"type":"function","title":"Cldr.Locale.likely_subtags/0","doc":"Returns the map of likely subtags. Note that not all locales are guaranteed to have likely subtags. Example Cldr.Locale . likely_subtags =&gt; % { bez ; % Cldr.LanguageTag { backend : TestBackend.Cldr , canonical_locale_name : nil , cldr_locale_name : nil , extensions : %{ } , language : &quot;bez&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : nil , requested_locale_name : nil , script : :Latn , territory : :TZ , transform : %{ } , language_variants : [ ] } , fuf : % Cldr.LanguageTag { canonical_locale_name : nil , cldr_locale_name : nil , extensions : %{ } , language : &quot;fuf&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : nil , requested_locale_name : nil , script : :Latn , territory : :GN , transform : %{ } , language_variants : [ ] } , ...","ref":"Cldr.Locale.html#likely_subtags/0"},{"type":"function","title":"Cldr.Locale.likely_subtags/1","doc":"Returns the likely substags, as a Cldr.LanguageTag , for a given locale name. Options locale is any valid locale name returned by Cldr.known_locale_names/1 or a Cldr.LanguageTag struct Examples iex&gt; Cldr.Locale . likely_subtags :en % Cldr.LanguageTag { backend : nil , canonical_locale_name : nil , cldr_locale_name : nil , extensions : %{ } , gettext_locale_name : nil , language : &quot;en&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : nil , requested_locale_name : &quot;en-Latn-US&quot; , script : :Latn , territory : :US , transform : %{ } , language_variants : [ ] }","ref":"Cldr.Locale.html#likely_subtags/1"},{"type":"function","title":"Cldr.Locale.locale_for_territory/2","doc":"Returns the &quot;best fit&quot; locale for a given territory. Using the population percentage data from CLDR, the language most commonly spoken in the given territory is used to form a locale name which is then validated against the given backend. First a territory-specific locale is validated and if that fails, the base language only is validate. For example, if the territory is AU then then the language most spoken is &quot;en&quot;. First, the locale &quot;en-AU&quot; is validated and if that fails, &quot;en&quot; is validated. Arguments territory is any ISO 3166 Alpha-2 territory code that can be validated by Cldr.validate_territory/1 backend is any module that includes use Cldr and therefore is a Cldr backend module. Returns {:ok, language_tag} or {:error, {exception, reason}} Examples iex&gt; Cldr.Locale.locale_for_territory(:AU, TestBackend.Cldr) Cldr.validate_locale(:&quot;en-AU&quot;, TestBackend.Cldr) iex&gt; Cldr.Locale.locale_for_territory(:US, TestBackend.Cldr) Cldr.validate_locale(:&quot;en-US&quot;, TestBackend.Cldr) iex&gt; Cldr.Locale.locale_for_territory(:ZZ) {:error, {Cldr.UnknownTerritoryError, &quot;The territory :ZZ is unknown&quot;}}","ref":"Cldr.Locale.html#locale_for_territory/2"},{"type":"function","title":"Cldr.Locale.locale_from_host/3","doc":"Returns a &quot;best fit&quot; locale for a host name. Arguments host is any valid host name backend is any module that includes use Cldr and therefore is a Cldr backend module. options is a keyword list of options. The default is [tlds: Cldr.Locale.consider_as_tlds()] . Options :tlds is a list of territory codes as upper-cased atoms that are to be considered as top-level domains. The default list is consider_as_tlds/0 . Returns {:ok, langauge_tag} or {:error, {exception, reason}} Notes Certain top-level domains have become associated with content underlated to the territory for who the domain is registered. Therefore Google (and perhaps others) do not associate these TLDs as belonging to the territory but rather are considered generic top-level domain names. Examples iex&gt; Cldr.Locale . locale_from_host &quot;a.b.com.au&quot; , TestBackend.Cldr Cldr . validate_locale ( :&quot;en-AU&quot; , TestBackend.Cldr ) iex&gt; Cldr.Locale . locale_from_host &quot;a.b.com.tv&quot; , TestBackend.Cldr { :error , { Cldr.UnknownLocaleError , &quot;No locale was identified for territory \\&quot; tv \\&quot; &quot; } } iex&gt; Cldr.Locale . locale_from_host &quot;a.b.com&quot; , TestBackend.Cldr { :error , { Cldr.UnknownLocaleError , &quot;No locale was identified for territory \\&quot; com \\&quot; &quot; } }","ref":"Cldr.Locale.html#locale_from_host/3"},{"type":"function","title":"Cldr.Locale.locale_name_from/2","doc":"Return a locale name from a Cldr.LanguageTag Options locale_name is any Cldr.LanguageTag struct returned by Cldr.Locale.new!/2 Example iex&gt; Cldr.Locale . locale_name_from Cldr.Locale . new! ( &quot;en&quot; , TestBackend.Cldr ) &quot;en&quot;","ref":"Cldr.Locale.html#locale_name_from/2"},{"type":"function","title":"Cldr.Locale.locale_name_from/5","doc":"Return a locale name by combining language, script, territory and variant parameters Arguments language is a string representing a valid language code script is an atom that is a valid script code. territory is an atom that is a valid territory code. variants is a list of language variants as lower case string or [] . Returns The atom locale name constructed from the non-nil arguments joined by a &quot;-&quot;. Example iex&gt; Cldr.Locale . locale_name_from ( &quot;en&quot; , :Latn , &quot;001&quot; , [ ] ) &quot;en-Latn-001&quot; iex&gt; Cldr.Locale . locale_name_from ( &quot;en&quot; , :Latn , :&quot;001&quot; , [ ] ) &quot;en-Latn-001&quot;","ref":"Cldr.Locale.html#locale_name_from/5"},{"type":"function","title":"Cldr.Locale.locale_name_from_posix/1","doc":"See Cldr.Config.locale_name_from_posix/1 .","ref":"Cldr.Locale.html#locale_name_from_posix/1"},{"type":"function","title":"Cldr.Locale.locale_name_to_posix/1","doc":"See Cldr.Config.locale_name_to_posix/1 .","ref":"Cldr.Locale.html#locale_name_to_posix/1"},{"type":"function","title":"Cldr.Locale.new/2","doc":"See Cldr.Locale.canonical_language_tag/2 .","ref":"Cldr.Locale.html#new/2"},{"type":"function","title":"Cldr.Locale.new!/2","doc":"See Cldr.Locale.canonical_language_tag!/2 .","ref":"Cldr.Locale.html#new!/2"},{"type":"function","title":"Cldr.Locale.omit_likely_subtags/4","doc":"","ref":"Cldr.Locale.html#omit_likely_subtags/4"},{"type":"function","title":"Cldr.Locale.parent/1","doc":"Returns the parent for a given locale. The function implements locale inheritance in accordance with CLDR's inheritance rules . Only locales that are configured are returned. That is, there may be a different parent locale in CLDR but unless those locales are configured they are not candidates to be parents in this context. The contract is to return either a known locale or an error. Inheritance Inheritance starts by looking for a parent locale via Cldr.Config.parent_locales/0 . If not found, strip in turn the variant, script and territory while checking to see if a base locale for the given language exists. If no parent language exists then move to the default locale and its inheritance chain.","ref":"Cldr.Locale.html#parent/1"},{"type":"function","title":"Cldr.Locale.parent/2","doc":"","ref":"Cldr.Locale.html#parent/2"},{"type":"function","title":"Cldr.Locale.parent_locale_map/0","doc":"Returns mappings between a locale and its parent. The mappings exist only where normal inheritance rules are not applied.","ref":"Cldr.Locale.html#parent_locale_map/0"},{"type":"function","title":"Cldr.Locale.parents/2","doc":"Returns a list of all the parent locales for a given locale. Examples Cldr.Locale . parents &quot;fr-ca&quot; =&gt; { :ok , [ # Cldr.LanguageTag &lt; fr [ validated ] &gt; , # Cldr.LanguageTag &lt; en [ validated ] &gt; ] }","ref":"Cldr.Locale.html#parents/2"},{"type":"function","title":"Cldr.Locale.put_gettext_locale_name/1","doc":"","ref":"Cldr.Locale.html#put_gettext_locale_name/1"},{"type":"function","title":"Cldr.Locale.put_gettext_locale_name/2","doc":"","ref":"Cldr.Locale.html#put_gettext_locale_name/2"},{"type":"function","title":"Cldr.Locale.put_likely_subtags/1","doc":"Replace empty subtags within a Cldr.LanguageTag.t/0 with the most likely subtag. Arguments language_tag is any language tag returned by Cldr.Locale.new/2 options is a keyword list of options Options :add_likely is a boolean indicating whether to add likely subtags. The default is true . Notes A subtag is called empty if it has a missing script or territory subtag, or it is a base language subtag with the value und . In the description below, a subscript on a subtag x indicates which tag it is from: x&lt;sub&gt;s&lt;/sub&gt; is in the source, x&lt;sub&gt;m&lt;/sub&gt; is in a match, and x&lt;sub&gt;r&lt;/sub&gt; is in the final result. Lookup Lookup each of the following in order, and stops on the first match: language&lt;sub&gt;s&lt;/sub&gt;-script&lt;sub&gt;s&lt;/sub&gt;-region&lt;sub&gt;s&lt;/sub&gt; language&lt;sub&gt;s&lt;/sub&gt;-region&lt;sub&gt;s&lt;/sub&gt; language&lt;sub&gt;s&lt;/sub&gt;-script&lt;sub&gt;s&lt;/sub&gt; language&lt;sub&gt;s&lt;/sub&gt; und-script&lt;sub&gt;s&lt;/sub&gt; Returns If there is no match,either return an error value, or the match for und Otherwise there is a match = language&lt;sub&gt;m&lt;/sub&gt;-script&lt;sub&gt;m&lt;/sub&gt;-region&lt;sub&gt;m&lt;/sub&gt; Let x&lt;sub&gt;r&lt;/sub&gt; = x&lt;sub&gt;s&lt;/sub&gt; if x&lt;sub&gt;s&lt;/sub&gt; is not empty, and x&lt;sub&gt;m&lt;/sub&gt; otherwise. Return the language tag composed of language&lt;sub&gt;r&lt;/sub&gt;-script&lt;sub&gt;r&lt;/sub&gt;-region&lt;sub&gt;r&lt;/sub&gt; + variants + extensions . Example iex&gt; Cldr.Locale . put_likely_subtags Cldr.LanguageTag . parse! ( &quot;zh-SG&quot; ) % Cldr.LanguageTag { backend : nil , canonical_locale_name : nil , cldr_locale_name : nil , language_subtags : [ ] , extensions : %{ } , gettext_locale_name : nil , language : &quot;zh&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : nil , requested_locale_name : &quot;zh-SG&quot; , script : :Hans , territory : &quot;SG&quot; , transform : %{ } , language_variants : [ ] }","ref":"Cldr.Locale.html#put_likely_subtags/1"},{"type":"function","title":"Cldr.Locale.root_language/0","doc":"Returns the root language for CLDR.","ref":"Cldr.Locale.html#root_language/0"},{"type":"function","title":"Cldr.Locale.script_direction_from_locale/1","doc":"Returns the script direction for a locale. Arguments language_tag is any language tag returned by Cldr.Locale.new/2 or any locale_name returned by Cldr.known_locale_names/1 . If the parameter is a locale_name then a default backend must be configured in config.exs or an exception will be raised. Returns The script direction which is either :ltr (for left-to-right scripts) or :rtl (for right-to-left scripts). Examples iex&gt; Cldr.Locale . script_direction_from_locale &quot;en-US&quot; :ltr iex&gt; Cldr.Locale . script_direction_from_locale &quot;ar&quot; :rtl","ref":"Cldr.Locale.html#script_direction_from_locale/1"},{"type":"function","title":"Cldr.Locale.script_direction_from_locale/2","doc":"Returns the script direction for a locale. Arguments locale_name is any locale name returned by Cldr.known_locale_names/1 . backend is any module that includes use Cldr and therefore is a Cldr backend module. Returns The script direction which is either :ltr (for left-to-right scripts) or :rtl (for right-to-left scripts). Examples iex&gt; Cldr.Locale . script_direction_from_locale :&quot;en-US&quot; , TestBackend.Cldr :ltr iex&gt; Cldr.Locale . script_direction_from_locale :he , TestBackend.Cldr :rtl","ref":"Cldr.Locale.html#script_direction_from_locale/2"},{"type":"function","title":"Cldr.Locale.script_from_locale/1","doc":"Returns the script for a locale. Arguments language_tag is any language tag returned by Cldr.Locale.new/2 or any locale_name returned by Cldr.known_locale_names/1 . If the parameter is a locale_name then a default backend must be configured in config.exs or an exception will be raised. Returns The script to be used for localization purposes. Examples iex&gt; Cldr.Locale . script_from_locale &quot;en-US&quot; :Latn iex&gt; Cldr.Locale . script_from_locale &quot;th&quot; :Thai","ref":"Cldr.Locale.html#script_from_locale/1"},{"type":"function","title":"Cldr.Locale.script_from_locale/2","doc":"Returns the script for a locale. Arguments locale_name is any locale name returned by Cldr.known_locale_names/1 . backend is any module that includes use Cldr and therefore is a Cldr backend module. Returns The script to be used for localization purposes. Examples iex&gt; Cldr.Locale . script_from_locale &quot;en-US&quot; , TestBackend.Cldr :Latn iex&gt; Cldr.Locale . script_from_locale &quot;th&quot; , TestBackend.Cldr :Thai","ref":"Cldr.Locale.html#script_from_locale/2"},{"type":"function","title":"Cldr.Locale.substitute_aliases/1","doc":"Substitute deprecated subtags with a Cldr.LanguageTag with their non-deprecated alternatives. Arguments language_tag is any language tag returned by Cldr.Locale.new/2 Method Replace any deprecated subtags with their canonical values using the alias data. Use the first value in the replacement list, if it exists. Language tag replacements may have multiple parts, such as sh ➞ sr_Latn or mo ➞ ro_MD . In such a case, the original script and/or region/territory are retained if there is one. Thus sh_Arab_AQ ➞ sr_Arab_AQ , not sr_Latn_AQ . Remove the script code 'Zzzz' and the territory code 'ZZ' if they occur. Get the components of the cleaned-up source tag (languages, scripts, and regions/territories), plus any variants and extensions. Example iex&gt; Cldr.Locale . substitute_aliases Cldr.LanguageTag.Parser . parse! ( &quot;mo&quot; ) % Cldr.LanguageTag { backend : nil , canonical_locale_name : nil , cldr_locale_name : nil , extensions : %{ } , gettext_locale_name : nil , language : &quot;ro&quot; , language_subtags : [ ] , language_variants : [ ] , locale : %{ } , private_use : [ ] , rbnf_locale_name : nil , requested_locale_name : &quot;mo&quot; , script : nil , territory : nil , transform : %{ } }","ref":"Cldr.Locale.html#substitute_aliases/1"},{"type":"function","title":"Cldr.Locale.territory_from_host/1","doc":"Returns the last segment of a host that might be a territory. Arguments host is any valid host name Returns {:ok, territory} or {:error, {exception, reason}} Examples iex&gt; Cldr.Locale . territory_from_host ( &quot;a.b.com.au&quot; ) { :ok , :AU } iex&gt; Cldr.Locale . territory_from_host ( &quot;a.b.com&quot; ) { :error , { Cldr.UnknownLocaleError , &quot;No locale was identified for territory \\&quot; com \\&quot; &quot; } }","ref":"Cldr.Locale.html#territory_from_host/1"},{"type":"function","title":"Cldr.Locale.territory_from_locale/1","doc":"Returns the effective territory for a locale. Arguments language_tag is any language tag returned by Cldr.Locale.new/2 or any locale_name returned by Cldr.known_locale_names/1 . If the parameter is a locale_name then a default backend must be configured in config.exs or an exception will be raised. Returns The territory to be used for localization purposes. Examples iex&gt; Cldr.Locale . territory_from_locale &quot;en-US&quot; :US iex&gt; Cldr.Locale . territory_from_locale &quot;en-US-u-rg-cazzzz&quot; :CA iex&gt; Cldr.Locale . territory_from_locale &quot;en-US-u-rg-xxxxx&quot; { :error , { Cldr.LanguageTag.ParseError , &quot;The value \\&quot; xxxxx \\&quot; is not valid for the key \\&quot; rg \\&quot; &quot; } } Notes A locale can reflect the desired territory to be used when determining region-specific defaults for items such as: default currency, default calendar and week data, default time cycle, and default measurement system and unit preferences Territory information is stored in the locale in up to three different places: The :territory extracted from the locale name or defined by default for a given language. This is the typical use case when locale names such as en-US or es-AR are used. In some cases it might be desirable to override the territory derived from the locale name. For example, the default territory for the language &quot;en&quot; is &quot;US&quot; but it may be desired to apply the defaults for the territory &quot;AU&quot; instead, without otherwise changing the localization intent. In this case the U extension is used to define a regional override . Similarly, the [regional subdivision identifier] ( https://unicode.org/reports/tr35/#UnicodeSubdivisionIdentifier ) can be used to influence localization decisions. This identifier is not currently used in ex_cldr and dependent libraries however it is correctly parsed to support future use.","ref":"Cldr.Locale.html#territory_from_locale/1"},{"type":"function","title":"Cldr.Locale.territory_from_locale/2","doc":"Returns the effective territory for a locale. Arguments locale_name is any locale name returned by Cldr.known_locale_names/1 . backend is any module that includes use Cldr and therefore is a Cldr backend module. Returns The territory to be used for localization purposes or {:error, {exception, reason}} . Examples iex&gt; Cldr.Locale . territory_from_locale &quot;en-US&quot; , TestBackend.Cldr :US iex&gt; Cldr.Locale . territory_from_locale &quot;en-US-u-rg-cazzzz&quot; , TestBackend.Cldr :CA iex&gt; Cldr.Locale . territory_from_locale &quot;en-US-u-rg-xxxxx&quot; , TestBackend.Cldr { :error , { Cldr.LanguageTag.ParseError , &quot;The value \\&quot; xxxxx \\&quot; is not valid for the key \\&quot; rg \\&quot; &quot; } } Notes A locale can reflect the desired territory to be used when determining region-specific defaults for items such as: default currency, default calendar and week data, default time cycle, and default measurement system and unit preferences Territory information is stored in the locale in up to three different places: The :territory extracted from the locale name or defined by default for a given language. This is the typical use case when locale names such as en-US or es-AR are used. In some cases it might be desirable to override the territory derived from the locale name. For example, the default territory for the language &quot;en&quot; is &quot;US&quot; but it may be desired to apply the defaults for the territory &quot;AU&quot; instead, without otherwise changing the localization intent. In this case the U extension is used to define a regional override . Similarly, the [regional subdivision identifier] ( https://unicode.org/reports/tr35/#UnicodeSubdivisionIdentifier ) can be used to influence localization decisions. This identifier is not currently used in ex_cldr and dependent libraries however it is correctly parsed to support future use.","ref":"Cldr.Locale.html#territory_from_locale/2"},{"type":"function","title":"Cldr.Locale.timezone_from_locale/1","doc":"Returns the effective time zone for a locale. Arguments language_tag is any language tag returned by Cldr.Locale.new/2 or any locale_name returned by Cldr.known_locale_names/1 . If the parameter is a locale_name then a default backend must be configured in config.exs or an exception will be raised. Returns The time zone ID as a String.t or {:error, {exception, reason}} Examples iex&gt; Cldr.Locale . timezone_from_locale &quot;en-US-u-tz-ausyd&quot; &quot;Australia/Sydney&quot; iex&gt; Cldr.Locale . timezone_from_locale &quot;en-AU&quot; { :error , { Cldr.AmbiguousTimezoneError , &quot;Cannot determine the timezone since the territory :AU has 24 timezone IDs&quot; } }","ref":"Cldr.Locale.html#timezone_from_locale/1"},{"type":"function","title":"Cldr.Locale.timezone_from_locale/2","doc":"Returns the effective time zone for a locale. Arguments locale_name is any name returned by Cldr.known_locale_names/1 backend is any module that includes use Cldr and therefore is a Cldr backend module Returns The time zone ID as a String.t or {:error, {exception, reason}} Examples iex&gt; Cldr.Locale . timezone_from_locale &quot;en-US-u-tz-ausyd&quot; , TestBackend.Cldr &quot;Australia/Sydney&quot; iex&gt; Cldr.Locale . timezone_from_locale :&quot;en-AU&quot; , TestBackend.Cldr { :error , { Cldr.AmbiguousTimezoneError , &quot;Cannot determine the timezone since the territory :AU has 24 timezone IDs&quot; } }","ref":"Cldr.Locale.html#timezone_from_locale/2"},{"type":"type","title":"Cldr.Locale.language/0","doc":"The name of a language","ref":"Cldr.Locale.html#t:language/0"},{"type":"type","title":"Cldr.Locale.locale_name/0","doc":"The name of a locale","ref":"Cldr.Locale.html#t:locale_name/0"},{"type":"type","title":"Cldr.Locale.locale_reference/0","doc":"A reference to a locale","ref":"Cldr.Locale.html#t:locale_reference/0"},{"type":"type","title":"Cldr.Locale.script/0","doc":"The name of a script","ref":"Cldr.Locale.html#t:script/0"},{"type":"type","title":"Cldr.Locale.script_direction/0","doc":"The direction in which a script is rendered","ref":"Cldr.Locale.html#t:script_direction/0"},{"type":"type","title":"Cldr.Locale.subtags/0","doc":"The list of language subtags as strings","ref":"Cldr.Locale.html#t:subtags/0"},{"type":"type","title":"Cldr.Locale.territory_code/0","doc":"A territory code as an ISO3166 Alpha-2 in atom form","ref":"Cldr.Locale.html#t:territory_code/0"},{"type":"type","title":"Cldr.Locale.territory_reference/0","doc":"The name of a territory","ref":"Cldr.Locale.html#t:territory_reference/0"},{"type":"type","title":"Cldr.Locale.variants/0","doc":"The list of language variants as strings","ref":"Cldr.Locale.html#t:variants/0"},{"type":"module","title":"Cldr.Rfc5646.Parser","doc":"Implements parsing for RFC5646 language tags with BCP47 extensions. The primary interface to this module is the function Cldr.LanguageTag.parse/1 .","ref":"Cldr.Rfc5646.Parser.html"},{"type":"function","title":"Cldr.Rfc5646.Parser.error_on_remaining/4","doc":"","ref":"Cldr.Rfc5646.Parser.html#error_on_remaining/4"},{"type":"function","title":"Cldr.Rfc5646.Parser.language_tag/2","doc":"Parses the given binary as language_tag. Returns {:ok, [token], rest, context, position, byte_offset} or {:error, reason, rest, context, line, byte_offset} where position describes the location of the language_tag (start position) as {line, column_on_line} . Options :byte_offset - the byte offset for the whole binary, defaults to 0 :line - the line and the byte offset into that line, defaults to {1, byte_offset} :context - the initial context value. It will be converted to a map","ref":"Cldr.Rfc5646.Parser.html#language_tag/2"},{"type":"function","title":"Cldr.Rfc5646.Parser.parse/2","doc":"","ref":"Cldr.Rfc5646.Parser.html#parse/2"},{"type":"module","title":"Cldr.LanguageTag","doc":"Represents a language tag as defined in rfc5646 with extensions &quot;u&quot; and &quot;t&quot; as defined in BCP 47 . Language tags are used to help identify languages, whether spoken, written, signed, or otherwise signaled, for the purpose of communication. This includes constructed and artificial languages but excludes languages not intended primarily for human communication, such as programming languages. Syntax A language tag is composed from a sequence of one or more &quot;subtags&quot;, each of which refines or narrows the range of language identified by the overall tag. Subtags, in turn, are a sequence of alphanumeric characters (letters and digits), distinguished and separated from other subtags in a tag by a hyphen (&quot;-&quot;, [Unicode] U+002D). There are different types of subtag, each of which is distinguished by length, position in the tag, and content: each subtag's type can be recognized solely by these features. This makes it possible to extract and assign some semantic information to the subtags, even if the specific subtag values are not recognized. Thus, a language tag processor need not have a list of valid tags or subtags (that is, a copy of some version of the IANA Language Subtag Registry) in order to perform common searching and matching operations. The only exceptions to this ability to infer meaning from subtag structure are the grandfathered tags listed in the productions 'regular' and 'irregular' below. These tags were registered under [RFC3066] and are a fixed list that can never change. The syntax of the language tag in ABNF is: Language-Tag = langtag ; normal language tags / privateuse ; private use tag / grandfathered ; grandfathered tags langtag = language [ &quot;-&quot; script ] [ &quot;-&quot; region ] * ( &quot;-&quot; variant ) * ( &quot;-&quot; extension ) [ &quot;-&quot; privateuse ] language = 2*3ALPHA ; shortest ISO 639 code [ &quot;-&quot; extlang ] ; sometimes followed by ; extended language subtags / 4 ALPHA ; or reserved for future use / 5 * 8 ALPHA ; or registered language subtag extlang = 3ALPHA ; selected ISO 639 codes * 2 ( &quot;-&quot; 3 ALPHA ) ; permanently reserved script = 4ALPHA ; ISO 15924 code region = 2ALPHA ; ISO 3166-1 code / 3 DIGIT ; UN M . 49 code variant = 5*8alphanum ; registered variants / ( DIGIT 3 alphanum ) extension = singleton 1 (&quot;-&quot; (2 8alphanum)) ; Single alphanumerics ; &quot;x&quot; reserved for private use singleton = DIGIT ; 0 - 9 / % x41 - 57 ; A - W / % x59 - 5 A ; Y - Z / % x61 - 77 ; a - w / % x79 - 7 A ; y - z privateuse = &quot;x&quot; 1 (&quot;-&quot; (1 8alphanum)) grandfathered = irregular ; non-redundant tags registered / regular ; during the RFC 3066 era irregular = &quot;en-GB-oed&quot; ; irregular tags do not match / &quot;i-ami&quot; ; the &#39;langtag&#39; production and / &quot;i-bnn&quot; ; would not otherwise be / &quot;i-default&quot; ; considered &#39;well-formed&#39; / &quot;i-enochian&quot; ; These tags are all valid , / &quot;i-hak&quot; ; but most are deprecated / &quot;i-klingon&quot; ; in favor of more modern / &quot;i-lux&quot; ; subtags or subtag / &quot;i-mingo&quot; ; combination / &quot;i-navajo&quot; / &quot;i-pwn&quot; / &quot;i-tao&quot; / &quot;i-tay&quot; / &quot;i-tsu&quot; / &quot;sgn-BE-FR&quot; / &quot;sgn-BE-NL&quot; / &quot;sgn-CH-DE&quot; regular = &quot;art-lojban&quot; ; these tags match the 'langtag' / &quot;cel-gaulish&quot; ; production , but their subtags / &quot;no-bok&quot; ; are not extended language / &quot;no-nyn&quot; ; or variant subtags : their meaning / &quot;zh-guoyu&quot; ; is defined by their registration / &quot;zh-hakka&quot; ; and all of these are deprecated / &quot;zh-min&quot; ; in favor of a more modern / &quot;zh-min-nan&quot; ; subtag or sequence of subtags / &quot;zh-xiang&quot; alphanum = (ALPHA / DIGIT) ; letters and numbers All subtags have a maximum length of eight characters. Whitespace is not permitted in a language tag. There is a subtlety in the ABNF production 'variant': a variant starting with a digit has a minimum length of four characters, while those starting with a letter have a minimum length of five characters. Unicode BCP 47 Extension type &quot;u&quot; - Locale Extension Description Examples +-------+ ------------------------------- --------- ca Calendar type buddhist, chinese, gregory cf Currency format style standard, account co Collation type standard, search, phonetic, pinyin cu Currency type ISO4217 code like &quot;USD&quot;, &quot;EUR&quot; fw First day of the week identifier sun, mon, tue, wed, ... hc Hour cycle identifier h12, h23, h11, h24 lb Line break style identifier strict, normal, loose lw Word break identifier normal, breakall, keepall, phrase ms Measurement system identifier metric, ussystem, uksystem mu Measurement unit override celsius, fahrenhe, kelvin which overrides the ms key nu Number system identifier arabext, armnlow, roman, tamldec rg Region override The value is a unicode_region_subtag for a regular region (not a macroregion), suffixed by &quot;ZZZZ&quot; sd Subdivision identifier A unicode_subdivision_id, which is a unicode_region_subtagconcatenated with a unicode_subdivision_suffix. ss Break suppressions identifier none, standard tz Timezone identifier Short identifiers defined in terms of a TZ time zone database va Common variant type POSIX style locale variant Unicode BCP 47 Extension type &quot;t&quot; - Transforms Extension Description +-------+ ----------------------------------------- mo Transform extension mechanism: to reference an authority or rules for a type of transformation s0 Transform source: for non-languages/scripts, such as fullwidth-halfwidth conversion. d0 Transform sdestination: for non-languages/scripts, such as fullwidth-halfwidth conversion. i0 Input Method Engine transform k0 Keyboard transform t0 Machine Translation: Used to indicate content that has been machine translated h0 Hybrid Locale Identifiers: h0 with the value 'hybrid' indicates that the -t- value is a language that is mixed into the main language tag to form a hybrid x0 Private use transform Extensions are formatted by specifying keyword pairs after an extension separator. The example de-DE-u-co-phonebk specifies German as spoken in Germany with a collation of phonebk . Another example, &quot;en-latn-AU-u-cf-account&quot; represents English as spoken in Australia, with the number system &quot;latn&quot; but formatting currencies with the &quot;accounting&quot; style.","ref":"Cldr.LanguageTag.html"},{"type":"function","title":"Cldr.LanguageTag.parse/1","doc":"Parse a locale name into a t:Cldr.LanguageTag struct. Arguments locale_name is any BCP 47 string. Returns {:ok, t:Cldr.LanguageTag} or {:error, reason}","ref":"Cldr.LanguageTag.html#parse/1"},{"type":"function","title":"Cldr.LanguageTag.parse!/1","doc":"Parse a locale name into a Cldr.LangaugeTag struct and raises on error Arguments locale_name is any BCP 47 string. Returns t:Cldr.LanguageTag or raises an exception","ref":"Cldr.LanguageTag.html#parse!/1"},{"type":"function","title":"Cldr.LanguageTag.to_string/2","doc":"Reconstitute a textual language tag from a LanguageTag that is suitable to pass to a collator. Note that this function will always calculate the canonical locale name. Kernel.to_string/1 will return the pre-calculated canonical locale name and is to be preferred. Arguments locale is a Cldr.LanguageTag struct returned by Cldr.Locale.new!/2 omit_singlular_script? is a boolean indicating if the script name should be omitted if the landuage_tag territory has only this one script. The default is false . Returns A formatted string representation of the language tag that is also parseable back into a Cldr.LanguageTag.t() Examples iex&gt; { :ok , locale } = Cldr . validate_locale &quot;en-US&quot; , MyApp.Cldr iex&gt; Cldr.LanguageTag . to_string ( locale ) &quot;en-US&quot; iex&gt; { :ok , locale } = Cldr . validate_locale &quot;en-US-u-co-phonebk-nu-arab&quot; , MyApp.Cldr iex&gt; Cldr.LanguageTag . to_string ( locale ) &quot;en-US-u-co-phonebk-nu-arab&quot;","ref":"Cldr.LanguageTag.html#to_string/2"},{"type":"type","title":"Cldr.LanguageTag.t/0","doc":"","ref":"Cldr.LanguageTag.html#t:t/0"},{"type":"exception","title":"Cldr.LanguageTag.ParseError","doc":"Exception raised when a language tag cannot be parsed (there is unparsed content).","ref":"Cldr.LanguageTag.ParseError.html"},{"type":"module","title":"Cldr.LanguageTag.Parser","doc":"Parses a CLDR language tag (also referred to as locale string). The applicable specification is from CLDR which is similar based upon RFC5646 with some variations.","ref":"Cldr.LanguageTag.Parser.html"},{"type":"function","title":"Cldr.LanguageTag.Parser.normalize_field/1","doc":"","ref":"Cldr.LanguageTag.Parser.html#normalize_field/1"},{"type":"function","title":"Cldr.LanguageTag.Parser.parse/1","doc":"Parse a locale name into a t:Cldr.LanguageTag locale_name is a string representation of a language tag as defined by RFC5646 . Returns {:ok, language_tag} or {:error, reasons}","ref":"Cldr.LanguageTag.Parser.html#parse/1"},{"type":"function","title":"Cldr.LanguageTag.Parser.parse!/1","doc":"Parse a locale name into a t:Cldr.LanguageTag locale_name is a string representation of a language tag as defined by RFC5646 . Returns language_tag or raises an exception","ref":"Cldr.LanguageTag.Parser.html#parse!/1"},{"type":"module","title":"Cldr.LanguageTag.Sigil","doc":"Implements a sigil_l/2 macro to constructing t:Cldr.LanguageTag structs.","ref":"Cldr.LanguageTag.Sigil.html"},{"type":"macro","title":"Cldr.LanguageTag.Sigil.sigil_l/2","doc":"Handles sigil ~l for language tags. Arguments locale_name is either a BCP 47 locale name as a string or locale_name | backend where backend is a backend module name Options u Will parse the locale but will not add likely subtags and its not guaranteed that this language tag is known to the backend module. Returns a t:Cldr.LanguageTag struct or raises an exception Examples iex&gt; import Cldr.LanguageTag.Sigil iex&gt; ~l(en-US-u-ca-gregory) # Cldr.LanguageTag &lt; en - US - u - ca - gregory [ validated ] &gt; iex&gt; import Cldr.LanguageTag.Sigil iex&gt; ~l(en-US-u-ca-gregory|MyApp.Cldr) # Cldr.LanguageTag &lt; en - US - u - ca - gregory [ validated ] &gt;","ref":"Cldr.LanguageTag.Sigil.html#sigil_l/2"},{"type":"module","title":"Cldr.LanguageTag.T","doc":"Defines the struct for the BCP 47 t extension.","ref":"Cldr.LanguageTag.T.html"},{"type":"function","title":"Cldr.LanguageTag.T.display_name/2","doc":"","ref":"Cldr.LanguageTag.T.html#display_name/2"},{"type":"function","title":"Cldr.LanguageTag.T.format_key_type/2","doc":"","ref":"Cldr.LanguageTag.T.html#format_key_type/2"},{"type":"function","title":"Cldr.LanguageTag.T.join_field_values/2","doc":"","ref":"Cldr.LanguageTag.T.html#join_field_values/2"},{"type":"type","title":"Cldr.LanguageTag.T.t/0","doc":"Defines the BCP 47 t extension of a t:Cldr.LanguageTag .","ref":"Cldr.LanguageTag.T.html#t:t/0"},{"type":"module","title":"Cldr.LanguageTag.U","doc":"Defines the struct for the BCP 47 u extension.","ref":"Cldr.LanguageTag.U.html"},{"type":"function","title":"Cldr.LanguageTag.U.encode/1","doc":"","ref":"Cldr.LanguageTag.U.html#encode/1"},{"type":"type","title":"Cldr.LanguageTag.U.t/0","doc":"Defines the BCP 47 u extension of a t:Cldr.LanguageTag .","ref":"Cldr.LanguageTag.U.html#t:t/0"},{"type":"module","title":"Cldr.Number.PluralRule","doc":"Defines the plural rule implementation modules. The functions in this module generates code to implement the plural rules of CLDR.","ref":"Cldr.Number.PluralRule.html"},{"type":"function","title":"Cldr.Number.PluralRule.known_plural_types/0","doc":"Returns a list of the possible pluralization types","ref":"Cldr.Number.PluralRule.html#known_plural_types/0"},{"type":"function","title":"Cldr.Number.PluralRule.plural_type/3","doc":"Returns the plural type for a given number. Arguments number is an integer, float or Decimal number backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend!/0 . options is a keyword list of options Options locale is any valid locale name returned by Cldr.known_locale_names/1 or a Cldr.LanguageTag struct returned by Cldr.Locale.new!/2 , The default is Cldr.get_locale/0 . backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend!/0 . This option allows the backend to be specified as an argument or an option. type is either Cardinal or Ordinal . The default is Cardinal . Examples iex&gt; Cldr.Number.PluralRule . plural_type ( 123 ) :other iex&gt; Cldr.Number.PluralRule . plural_type ( 123 , type : Ordinal ) :few iex&gt; Cldr.Number.PluralRule . plural_type ( 123 , type : Cardinal ) :other iex&gt; Cldr.Number.PluralRule . plural_type ( 2 , locale : &quot;de&quot; ) :other","ref":"Cldr.Number.PluralRule.html#plural_type/3"},{"type":"type","title":"Cldr.Number.PluralRule.operand/0","doc":"","ref":"Cldr.Number.PluralRule.html#t:operand/0"},{"type":"type","title":"Cldr.Number.PluralRule.plural_type/0","doc":"Defines the plural types into which a number can be categorised.","ref":"Cldr.Number.PluralRule.html#t:plural_type/0"},{"type":"protocol","title":"Cldr.Chars","doc":"The Cldr.Chars protocol mirrors the String.Chars protocol but localises the output. It is intended to be drop-in replacement for String.Chars .","ref":"Cldr.Chars.html"},{"type":"function","title":"Cldr.Chars.to_string/1","doc":"Converts term to a localised string.","ref":"Cldr.Chars.html#to_string/1"},{"type":"type","title":"Cldr.Chars.t/0","doc":"","ref":"Cldr.Chars.html#t:t/0"},{"type":"protocol","title":"Cldr.DisplayName","doc":"Returns the localised display name for a CLDR struct (locale, unit, currency)","ref":"Cldr.DisplayName.html"},{"type":"function","title":"Cldr.DisplayName.display_name/2","doc":"","ref":"Cldr.DisplayName.html#display_name/2"},{"type":"type","title":"Cldr.DisplayName.t/0","doc":"","ref":"Cldr.DisplayName.html#t:t/0"},{"type":"module","title":"Cldr.Gettext.Plural","doc":"Implements a macro to define a CLDR-based Gettext plural module gettext allows for user-defined plural forms modules to be configured for a gettext backend . To define a plural forms module that uses CLDR plural rules create a new module and then use Cldr.Gettext.Plural . For example: defmodule MyApp.Gettext.Plural do use Cldr.Gettext.Plural , cldr_backend : MyApp.Cldr end This module can then be used in the configuration of a gettext backend. For example: defmodule MyApp.Gettext do use Gettext , plural_forms : MyApp.Gettext.Plural end","ref":"Cldr.Gettext.Plural.html"},{"type":"macro","title":"Cldr.Gettext.Plural.__using__/1","doc":"Configure a module to be a gettext plural module. A CLDR-based gettext plural module is defined by including use Cldr.Gettext.Plural as in this example: defmodule MyApp.Gettext.Plural do use Cldr.Gettext.Plural , cldr_backend : MyApp.Cldr end Arguments options is a keyword list of options. The default is [] Options :cldr_backend is any CLDR backend module. The default is Cldr.default_backend!/0 .","ref":"Cldr.Gettext.Plural.html#__using__/1"},{"type":"module","title":"Cldr.Config","doc":"Provider configuration support functions for ex_cldr. The functions in this module should be considered private use and they may change at any time.","ref":"Cldr.Config.html"},{"type":"function","title":"Cldr.Config.aliases/0","doc":"Returns the map of aliases for languages, scripts and regions","ref":"Cldr.Config.html#aliases/0"},{"type":"function","title":"Cldr.Config.all_language_tags/0","doc":"Returns the map of language tags for all available locales","ref":"Cldr.Config.html#all_language_tags/0"},{"type":"function","title":"Cldr.Config.all_language_tags?/0","doc":"Returns a boolean indicating whether the language_tags.ebin file exists","ref":"Cldr.Config.html#all_language_tags?/0"},{"type":"function","title":"Cldr.Config.all_locale_names/0","doc":"Returns a list of all locales in the CLDR repository. Returns a list of the complete locales list in CLDR, irrespective of whether they are configured for use in the application. Any configured locales that are not present in this list will raise an exception at compile time.","ref":"Cldr.Config.html#all_locale_names/0"},{"type":"function","title":"Cldr.Config.app_name/0","doc":"Return the configured application name for cldr Note this is probably :ex_cldr which is what this app is called on hex.pm","ref":"Cldr.Config.html#app_name/0"},{"type":"function","title":"Cldr.Config.calendar_data/0","doc":"See Cldr.Config.calendars/0 .","ref":"Cldr.Config.html#calendar_data/0"},{"type":"function","title":"Cldr.Config.calendar_preferences/0","doc":"Return the map of calendar preferences by territory","ref":"Cldr.Config.html#calendar_preferences/0"},{"type":"function","title":"Cldr.Config.calendars/0","doc":"Returns the data that defines start and end of calendar eras. Example iex&gt; Cldr.Config . calendars |&gt; Map . get ( :gregorian ) %{ calendar_system : :solar , eras : [ [ 0 , %{ end : [ 0 , 12 , 31 ] , aliases : [ &quot;bc&quot; , &quot;bce&quot; ] , code : :gregory_inverse } ] , [ 1 , %{ start : [ 1 , 1 , 1 ] , aliases : [ &quot;ad&quot; , &quot;ce&quot; ] , code : :gregory } ] ] }","ref":"Cldr.Config.html#calendars/0"},{"type":"function","title":"Cldr.Config.calendars_for_locale/2","doc":"Returns the calendars available for a given locale name Example iex&gt; Cldr.Config . calendars_for_locale &quot;en&quot; , TestBackend.Cldr [ :buddhist , :chinese , :coptic , :dangi , :ethiopic , :ethiopic_amete_alem , :generic , :gregorian , :hebrew , :indian , :islamic , :islamic_civil , :islamic_rgsa , :islamic_tbla , :islamic_umalqura , :japanese , :persian , :roc ]","ref":"Cldr.Config.html#calendars_for_locale/2"},{"type":"function","title":"Cldr.Config.canonical_name/1","doc":"","ref":"Cldr.Config.html#canonical_name/1"},{"type":"function","title":"Cldr.Config.cldr_data_dir/0","doc":"Returns the path of the CLDR data directory for the ex_cldr app. This is the directory where base CLDR data files are stored including included locale files.","ref":"Cldr.Config.html#cldr_data_dir/0"},{"type":"function","title":"Cldr.Config.cldr_home/0","doc":"Return the root path of the cldr application","ref":"Cldr.Config.html#cldr_home/0"},{"type":"function","title":"Cldr.Config.client_data_dir/1","doc":"Return the path name of the CLDR data directory for a client application. The order of priority to determine where the client data directory is located is: A specified :data_dir of a backend configuration The specified :data_dir of the backend's :otp_app configuration The specified :data_dir of the global configuration The priv_dir() of a specified :otp_app The priv_dir() of ex_cldr Note that config_from_opts/1 merges the global config, the otp_app config and the module config together so that :data_dir already resolves this priority in most cases. The remaining cases are for when no :data_dir is specified.","ref":"Cldr.Config.html#client_data_dir/1"},{"type":"function","title":"Cldr.Config.client_locales_dir/1","doc":"Returns the directory where downloaded ex_cldr locales files are located.","ref":"Cldr.Config.html#client_locales_dir/1"},{"type":"function","title":"Cldr.Config.configured_locale_names/1","doc":"Returns a list of all locales configured in a Cldr.Config.t struct. In order of priority return either: The list of locales configured configured in mix.exs if any The default locale If the configured locales is :all then all locales in CLDR are configured. The locale &quot;und&quot; is always added to the list of configured locales since it is required to support some RBNF functions. The use of :all is not recommended since all 571 locales take quite some time (minutes) to compile. It is however helpful for testing Cldr.","ref":"Cldr.Config.html#configured_locale_names/1"},{"type":"function","title":"Cldr.Config.currencies_for/2","doc":"Returns the currency metadata for a locale. Arguments locale is any valid locale name returned by Cldr.known_locale_names/1 or a Cldr.LanguageTag struct returned by Cldr.Locale.new!/2 config is a Config.Cldr.t() struct or a Cldr.backend() module","ref":"Cldr.Config.html#currencies_for/2"},{"type":"function","title":"Cldr.Config.currencies_for!/2","doc":"","ref":"Cldr.Config.html#currencies_for!/2"},{"type":"function","title":"Cldr.Config.day_period_info/0","doc":"Returns the data that defines time periods of a day for a language. Time period rules are used to define the meaning of &quot;morning&quot;, &quot;evening&quot;, &quot;noon&quot;, &quot;midnight&quot; and potentially other periods on a per-language basis. Example iex&gt; Cldr.Config . day_period_info |&gt; Map . get ( &quot;fr&quot; ) %{ &quot;afternoon1&quot; =&gt; %{ &quot;before&quot; =&gt; [ 18 , 0 ] , &quot;from&quot; =&gt; [ 12 , 0 ] } , &quot;evening1&quot; =&gt; %{ &quot;before&quot; =&gt; [ 24 , 0 ] , &quot;from&quot; =&gt; [ 18 , 0 ] } , &quot;midnight&quot; =&gt; %{ &quot;at&quot; =&gt; [ 0 , 0 ] } , &quot;morning1&quot; =&gt; %{ &quot;before&quot; =&gt; [ 12 , 0 ] , &quot;from&quot; =&gt; [ 4 , 0 ] } , &quot;night1&quot; =&gt; %{ &quot;before&quot; =&gt; [ 4 , 0 ] , &quot;from&quot; =&gt; [ 0 , 0 ] } , &quot;noon&quot; =&gt; %{ &quot;at&quot; =&gt; [ 12 , 0 ] } }","ref":"Cldr.Config.html#day_period_info/0"},{"type":"function","title":"Cldr.Config.default_backend/0","doc":"Return the system-wide default backend","ref":"Cldr.Config.html#default_backend/0"},{"type":"function","title":"Cldr.Config.default_locale/0","doc":"Return the system-wide default locale.","ref":"Cldr.Config.html#default_locale/0"},{"type":"function","title":"Cldr.Config.default_locale_name/1","doc":"Return the default locale name for a given backend configuration. In order of priority return either: The default locale for a given backend configuration The global default locale specified in mix.exs under the ex_cldr key The Gettext.get_locale/1 for the current configuration The system-wide default locale which is currently :&quot;en-001&quot;","ref":"Cldr.Config.html#default_locale_name/1"},{"type":"function","title":"Cldr.Config.download_data_dir/0","doc":"Returns the directory where the downloaded CLDR repository files are stored. These are the real CLDR data files that are used only for the development of ex_cldr. They are not included in the hex package.","ref":"Cldr.Config.html#download_data_dir/0"},{"type":"function","title":"Cldr.Config.expand_locale_names/1","doc":"Expands wildcards in locale names. Locales often have region variants (for example en-AU is one of 104 variants in CLDR). To make it easier to configure a language and all its variants, a locale can be specified as a regex which will then do a match against all CLDR locales. For locale names that have a Script or Variant component the base language is also configured since plural rules will fall back to the language for these locale names. Examples iex&gt; Cldr.Config . expand_locale_names ( [ &quot;en-A+&quot; ] ) [ :en , :&quot;en-AE&quot; , :&quot;en-AG&quot; , :&quot;en-AI&quot; , :&quot;en-AS&quot; , :&quot;en-AT&quot; , :&quot;en-AU&quot; ] iex&gt; Cldr.Config . expand_locale_names ( [ &quot;fr-*&quot; ] ) [ :fr , :&quot;fr-BE&quot; , :&quot;fr-BF&quot; , :&quot;fr-BI&quot; , :&quot;fr-BJ&quot; , :&quot;fr-BL&quot; , :&quot;fr-CA&quot; , :&quot;fr-CD&quot; , :&quot;fr-CF&quot; , :&quot;fr-CG&quot; , :&quot;fr-CH&quot; , :&quot;fr-CI&quot; , :&quot;fr-CM&quot; , :&quot;fr-DJ&quot; , :&quot;fr-DZ&quot; , :&quot;fr-GA&quot; , :&quot;fr-GF&quot; , :&quot;fr-GN&quot; , :&quot;fr-GP&quot; , :&quot;fr-GQ&quot; , :&quot;fr-HT&quot; , :&quot;fr-KM&quot; , :&quot;fr-LU&quot; , :&quot;fr-MA&quot; , :&quot;fr-MC&quot; , :&quot;fr-MF&quot; , :&quot;fr-MG&quot; , :&quot;fr-ML&quot; , :&quot;fr-MQ&quot; , :&quot;fr-MR&quot; , :&quot;fr-MU&quot; , :&quot;fr-NC&quot; , :&quot;fr-NE&quot; , :&quot;fr-PF&quot; , :&quot;fr-PM&quot; , :&quot;fr-RE&quot; , :&quot;fr-RW&quot; , :&quot;fr-SC&quot; , :&quot;fr-SN&quot; , :&quot;fr-SY&quot; , :&quot;fr-TD&quot; , :&quot;fr-TG&quot; , :&quot;fr-TN&quot; , :&quot;fr-VU&quot; , :&quot;fr-WF&quot; , :&quot;fr-YT&quot; , :frr ]","ref":"Cldr.Config.html#expand_locale_names/1"},{"type":"function","title":"Cldr.Config.fallback/1","doc":"Returns the immediate fallback locale for a locale name. Follows the CLDR TR35 resource bundle lookup algorithm. This function is only intended to return the fallback for the locales defined by CLDR. It does not perform any alias lookup or likely subtag processing. Algorithm Summary Decompose the locale name into language, script, territory and variant. CLDR locale names have no more than these four parts but usually have less. Look for a locale in the following order: language-script-territory language-script language-territory language At each stage in (2) resolve an alias in parent_locales/1","ref":"Cldr.Config.html#fallback/1"},{"type":"function","title":"Cldr.Config.fallback_chain/1","doc":"Returns the fallback chain for a locale name. Follows the CLDR TR35 resource bundle lookup algorithm. This function is only intended to return fallback chains for the locales defined by CLDR. It does not perform any alias lookup or likely subtag processing. The primary purpose for this function is to support including fallback locales in a backend configuration since both RBNF and Subdivision data follows the fallback chain. Algorithm Summary Decompose the locale name into language, script, territory and variant. CLDR locale names have no more than these four parts but usually have less. Look for a locale in the following order: language-script-territory language-script language-territory language At each stage in (2) resolve an alias in parent_locales/1","ref":"Cldr.Config.html#fallback_chain/1"},{"type":"function","title":"Cldr.Config.get_precompile_number_formats/1","doc":"Get the configured number formats that should be precompiled at application compilation time.","ref":"Cldr.Config.html#get_precompile_number_formats/1"},{"type":"function","title":"Cldr.Config.gettext/1","doc":"Return the configured Gettext module name or nil .","ref":"Cldr.Config.html#gettext/1"},{"type":"function","title":"Cldr.Config.gettext_configured?/1","doc":"Returns true if a Gettext module is configured in Cldr and the Gettext module is available. Example iex&gt; test_config = TestBackend.Cldr . __cldr__ ( :config ) iex&gt; Cldr.Config . gettext_configured? ( test_config ) true","ref":"Cldr.Config.html#gettext_configured?/1"},{"type":"function","title":"Cldr.Config.gettext_default_locale/1","doc":"Return the default gettext locale for a CLDR config.","ref":"Cldr.Config.html#gettext_default_locale/1"},{"type":"function","title":"Cldr.Config.grammatical_features/0","doc":"Returns the CLDR grammatical features data which is used with formatting units.","ref":"Cldr.Config.html#grammatical_features/0"},{"type":"function","title":"Cldr.Config.grammatical_gender/0","doc":"Returns the CLDR grammatical gender data which is used with formatting units.","ref":"Cldr.Config.html#grammatical_gender/0"},{"type":"function","title":"Cldr.Config.include_module_docs?/1","doc":"","ref":"Cldr.Config.html#include_module_docs?/1"},{"type":"function","title":"Cldr.Config.json_library/0","doc":"Return the configured json lib","ref":"Cldr.Config.html#json_library/0"},{"type":"function","title":"Cldr.Config.known_calendars/0","doc":"Returns a list of strings representing the calendars known to Cldr . Example iex&gt; Cldr.Config . known_calendars [ :buddhist , :chinese , :coptic , :dangi , :ethiopic , :ethiopic_amete_alem , :gregorian , :hebrew , :indian , :islamic , :islamic_civil , :islamic_rgsa , :islamic_tbla , :islamic_umalqura , :japanese , :persian , :roc ]","ref":"Cldr.Config.html#known_calendars/0"},{"type":"function","title":"Cldr.Config.known_currencies/0","doc":"Returns a list of the currencies known in Cldr in upcased atom format. Example iex&gt; Cldr.Config . known_currencies [ :ADP , :AED , :AFA , :AFN , :ALK , :ALL , :AMD , :ANG , :AOA , :AOK , :AON , :AOR , :ARA , :ARL , :ARM , :ARP , :ARS , :ATS , :AUD , :AWG , :AZM , :AZN , :BAD , :BAM , :BAN , :BBD , :BDT , :BEC , :BEF , :BEL , :BGL , :BGM , :BGN , :BGO , :BHD , :BIF , :BMD , :BND , :BOB , :BOL , :BOP , :BOV , :BRB , :BRC , :BRE , :BRL , :BRN , :BRR , :BRZ , :BSD , :BTN , :BUK , :BWP , :BYB , :BYN , :BYR , :BZD , :CAD , :CDF , :CHE , :CHF , :CHW , :CLE , :CLF , :CLP , :CNH , :CNX , :CNY , :COP , :COU , :CRC , :CSD , :CSK , :CUC , :CUP , :CVE , :CYP , :CZK , :DDM , :DEM , :DJF , :DKK , :DOP , :DZD , :ECS , :ECV , :EEK , :EGP , :ERN , :ESA , :ESB , :ESP , :ETB , :EUR , :FIM , :FJD , :FKP , :FRF , :GBP , :GEK , :GEL , :GHC , :GHS , :GIP , :GMD , :GNF , :GNS , :GQE , :GRD , :GTQ , :GWE , :GWP , :GYD , :HKD , :HNL , :HRD , :HRK , :HTG , :HUF , :IDR , :IEP , :ILP , :ILR , :ILS , :INR , :IQD , :IRR , :ISJ , :ISK , :ITL , :JMD , :JOD , :JPY , :KES , :KGS , :KHR , :KMF , :KPW , :KRH , :KRO , :KRW , :KWD , :KYD , :KZT , :LAK , :LBP , :LKR , :LRD , :LSL , :LTL , :LTT , :LUC , :LUF , :LUL , :LVL , :LVR , :LYD , :MAD , :MAF , :MCF , :MDC , :MDL , :MGA , :MGF , :MKD , :MKN , :MLF , :MMK , :MNT , :MOP , :MRO , :MRU , :MTL , :MTP , :MUR , :MVP , :MVR , :MWK , :MXN , :MXP , :MXV , :MYR , :MZE , :MZM , :MZN , :NAD , :NGN , :NIC , :NIO , :NLG , :NOK , :NPR , :NZD , :OMR , :PAB , :PEI , :PEN , :PES , :PGK , :PHP , :PKR , :PLN , :PLZ , :PTE , :PYG , :QAR , :RHD , :ROL , :RON , :RSD , :RUB , :RUR , :RWF , :SAR , :SBD , :SCR , :SDD , :SDG , :SDP , :SEK , :SGD , :SHP , :SIT , :SKK , :SLE , :SLL , :SOS , :SRD , :SRG , :SSP , :STD , :STN , :SUR , :SVC , :SYP , :SZL , :THB , :TJR , :TJS , :TMM , :TMT , :TND , :TOP , :TPE , :TRL , :TRY , :TTD , :TWD , :TZS , :UAH , :UAK , :UGS , :UGX , :USD , :USN , :USS , :UYI , :UYP , :UYU , :UYW , :UZS , :VEB , :VED , :VEF , :VES , :VND , :VNN , :VUV , :WST , :XAF , :XAG , :XAU , :XBA , :XBB , :XBC , :XBD , :XCD , :XDR , :XEU , :XFO , :XFU , :XOF , :XPD , :XPF , :XPT , :XRE , :XSU , :XTS , :XUA , :XXX , :YDD , :YER , :YUD , :YUM , :YUN , :YUR , :ZAL , :ZAR , :ZMK , :ZMW , :ZRN , :ZRZ , :ZWD , :ZWL , :ZWR ]","ref":"Cldr.Config.html#known_currencies/0"},{"type":"function","title":"Cldr.Config.known_gettext_locale_names/1","doc":"Return a list of the locales defined in Gettext . Return a list of locales configured in Gettext or [] if Gettext is not configured.","ref":"Cldr.Config.html#known_gettext_locale_names/1"},{"type":"function","title":"Cldr.Config.known_locale_name/2","doc":"Returns either the locale name (if its known) or false if the locale name is not known.","ref":"Cldr.Config.html#known_locale_name/2"},{"type":"function","title":"Cldr.Config.known_locale_names/1","doc":"Returns a list of all locales that are configured and available in the CLDR repository.","ref":"Cldr.Config.html#known_locale_names/1"},{"type":"function","title":"Cldr.Config.known_number_system_types/1","doc":"Returns the number system types that are known.","ref":"Cldr.Config.html#known_number_system_types/1"},{"type":"function","title":"Cldr.Config.known_number_systems/0","doc":"Returns a list of strings representing the number systems known to Cldr . Example iex&gt; Cldr.Config . known_number_systems [ :adlm , :ahom , :arab , :arabext , :armn , :armnlow , :bali , :beng , :bhks , :brah , :cakm , :cham , :cyrl , :deva , :diak , :ethi , :fullwide , :geor , :gong , :gonm , :grek , :greklow , :gujr , :guru , :hanidays , :hanidec , :hans , :hansfin , :hant , :hantfin , :hebr , :hmng , :hmnp , :java , :jpan , :jpanfin , :jpanyear , :kali , :kawi , :khmr , :knda , :lana , :lanatham , :laoo , :latn , :lepc , :limb , :mathbold , :mathdbl , :mathmono , :mathsanb , :mathsans , :mlym , :modi , :mong , :mroo , :mtei , :mymr , :mymrshan , :mymrtlng , :nagm , :newa , :nkoo , :olck , :orya , :osma , :rohg , :roman , :romanlow , :saur , :segment , :shrd , :sind , :sinh , :sora , :sund , :takr , :talu , :taml , :tamldec , :telu , :thai , :tibt , :tirh , :tnsa , :vaii , :wara , :wcho ]","ref":"Cldr.Config.html#known_number_systems/0"},{"type":"function","title":"Cldr.Config.known_number_systems_like/3","doc":"Returns locale and number systems that have the same digits and separators as the supplied one. Transliterating between locale &amp; number systems is expensive. To avoid unnecessary transliteration we look for locale and number systems that have the same digits and separators. Typically we are comparing to locale &quot;en&quot; and number system &quot;latn&quot; since this is what the number formatting routines use as placeholders. This function is intended for use at compile time only and is used to help optimise the generation of transliteration functions.","ref":"Cldr.Config.html#known_number_systems_like/3"},{"type":"function","title":"Cldr.Config.known_rbnf_locale_name/2","doc":"Returns either the locale name (if its known and has an rbnf configuration) or false .","ref":"Cldr.Config.html#known_rbnf_locale_name/2"},{"type":"function","title":"Cldr.Config.known_rbnf_locale_names/1","doc":"Returns a list of all locales that have RBNF data and that are configured and available in the CLDR repository.","ref":"Cldr.Config.html#known_rbnf_locale_names/1"},{"type":"function","title":"Cldr.Config.known_territories/0","doc":"Returns a list of atoms representing the territories known to Cldr . Example iex&gt; Cldr.Config . known_territories [ :&quot;001&quot; , :&quot;002&quot; , :&quot;003&quot; , :&quot;005&quot; , :&quot;009&quot; , :&quot;011&quot; , :&quot;013&quot; , :&quot;014&quot; , :&quot;015&quot; , :&quot;017&quot; , :&quot;018&quot; , :&quot;019&quot; , :&quot;021&quot; , :&quot;029&quot; , :&quot;030&quot; , :&quot;034&quot; , :&quot;035&quot; , :&quot;039&quot; , :&quot;053&quot; , :&quot;054&quot; , :&quot;057&quot; , :&quot;061&quot; , :&quot;142&quot; , :&quot;143&quot; , :&quot;145&quot; , :&quot;150&quot; , :&quot;151&quot; , :&quot;154&quot; , :&quot;155&quot; , :&quot;202&quot; , :&quot;419&quot; , :AC , :AD , :AE , :AF , :AG , :AI , :AL , :AM , :AO , :AQ , :AR , :AS , :AT , :AU , :AW , :AX , :AZ , :BA , :BB , :BD , :BE , :BF , :BG , :BH , :BI , :BJ , :BL , :BM , :BN , :BO , :BQ , :BR , :BS , :BT , :BV , :BW , :BY , :BZ , :CA , :CC , :CD , :CF , :CG , :CH , :CI , :CK , :CL , :CM , :CN , :CO , :CP , :CQ , :CR , :CU , :CV , :CW , :CX , :CY , :CZ , :DE , :DG , :DJ , :DK , :DM , :DO , :DZ , :EA , :EC , :EE , :EG , :EH , :ER , :ES , :ET , :EU , :EZ , :FI , :FJ , :FK , :FM , :FO , :FR , :GA , :GB , :GD , :GE , :GF , :GG , :GH , :GI , :GL , :GM , :GN , :GP , :GQ , :GR , :GS , :GT , :GU , :GW , :GY , :HK , :HM , :HN , :HR , :HT , :HU , :IC , :ID , :IE , :IL , :IM , :IN , :IO , :IQ , :IR , :IS , :IT , :JE , :JM , :JO , :JP , :KE , :KG , :KH , :KI , :KM , :KN , :KP , :KR , :KW , :KY , :KZ , :LA , :LB , :LC , :LI , :LK , :LR , :LS , :LT , :LU , :LV , :LY , :MA , :MC , :MD , :ME , :MF , :MG , :MH , :MK , :ML , :MM , :MN , :MO , :MP , :MQ , :MR , :MS , :MT , :MU , :MV , :MW , :MX , :MY , :MZ , :NA , :NC , :NE , :NF , :NG , :NI , :NL , :NO , :NP , :NR , :NU , :NZ , :OM , :PA , :PE , :PF , :PG , :PH , :PK , :PL , :PM , :PN , :PR , :PS , :PT , :PW , :PY , :QA , :QO , :RE , :RO , :RS , :RU , :RW , :SA , :SB , :SC , :SD , :SE , :SG , :SH , :SI , :SJ , :SK , :SL , :SM , :SN , :SO , :SR , :SS , :ST , :SV , :SX , :SY , :SZ , :TA , :TC , :TD , :TF , :TG , :TH , :TJ , :TK , :TL , :TM , :TN , :TO , :TR , :TT , :TV , :TW , :TZ , :UA , :UG , :UM , :UN , :US , :UY , :UZ , :VA , :VC , :VE , :VG , :VI , :VN , :VU , :WF , :WS , :XK , :YE , :YT , :ZA , :ZM , :ZW ]","ref":"Cldr.Config.html#known_territories/0"},{"type":"function","title":"Cldr.Config.language_data/0","doc":"Return the language data that maps valid territories and scripts","ref":"Cldr.Config.html#language_data/0"},{"type":"function","title":"Cldr.Config.language_tag/1","doc":"Return the saved language tag for the given locale name.","ref":"Cldr.Config.html#language_tag/1"},{"type":"function","title":"Cldr.Config.language_tag_for_territory/0","doc":"Return the mapping from a territory to a language tag. This is used to derive a locale from a territory.","ref":"Cldr.Config.html#language_tag_for_territory/0"},{"type":"function","title":"Cldr.Config.likely_subtags/0","doc":"Returns the likely subtags map which maps a locale string to %LaguageTag{} representing the likely subtags for that locale string","ref":"Cldr.Config.html#likely_subtags/0"},{"type":"function","title":"Cldr.Config.locale_filename/1","doc":"Returns the filename that contains the json representation of a locale.","ref":"Cldr.Config.html#locale_filename/1"},{"type":"function","title":"Cldr.Config.locale_name_from_posix/1","doc":"Transforms a locale name from the Posix format to the Cldr format","ref":"Cldr.Config.html#locale_name_from_posix/1"},{"type":"function","title":"Cldr.Config.locale_name_to_posix/1","doc":"Transforms a locale name from the CLDR format to the Posix format","ref":"Cldr.Config.html#locale_name_to_posix/1"},{"type":"function","title":"Cldr.Config.locale_path/2","doc":"Returns the location of the json data for a locale Arguments locale is any locale returned from Cldr.known_locale_names/1 config is any t:Cldr.Config Returns {:ok, path} or {:error, :not_found}","ref":"Cldr.Config.html#locale_path/2"},{"type":"function","title":"Cldr.Config.locale_path!/2","doc":"Returns the location of the json data for a locale Arguments locale is any locale returned from Cldr.known_locale_names/1 config is any t:Cldr.Config Returns path or raises an exception","ref":"Cldr.Config.html#locale_path!/2"},{"type":"function","title":"Cldr.Config.maybe_add_fallback_locales/1","doc":"Add the fallback locales to a list of configured locales","ref":"Cldr.Config.html#maybe_add_fallback_locales/1"},{"type":"function","title":"Cldr.Config.measurement_systems/0","doc":"Return a map of measurement systems","ref":"Cldr.Config.html#measurement_systems/0"},{"type":"function","title":"Cldr.Config.merge_locales_with_default/1","doc":"","ref":"Cldr.Config.html#merge_locales_with_default/1"},{"type":"function","title":"Cldr.Config.normalize_plural_rules/1","doc":"","ref":"Cldr.Config.html#normalize_plural_rules/1"},{"type":"function","title":"Cldr.Config.number_symbols_for/2","doc":"Get the number symbol definitions for a locale","ref":"Cldr.Config.html#number_symbols_for/2"},{"type":"function","title":"Cldr.Config.number_symbols_for/3","doc":"","ref":"Cldr.Config.html#number_symbols_for/3"},{"type":"function","title":"Cldr.Config.number_symbols_for!/2","doc":"Get the number symbol definitions for a locale or raises if an error","ref":"Cldr.Config.html#number_symbols_for!/2"},{"type":"function","title":"Cldr.Config.number_symbols_for!/3","doc":"","ref":"Cldr.Config.html#number_symbols_for!/3"},{"type":"function","title":"Cldr.Config.number_system_for/3","doc":"Returns the number system for a given locale and number system name. Example iex&gt; Cldr.Config . number_system_for ( :th , :thai , % Cldr.Config { locales : [ &quot;th&quot; , &quot;de&quot; ] } ) { :ok , %{ digits : &quot;๐๑๒๓๔๕๖๗๘๙&quot; , type : :numeric } }","ref":"Cldr.Config.html#number_system_for/3"},{"type":"function","title":"Cldr.Config.number_system_names_for/2","doc":"Returns the number system names for a locale Example iex&gt; Cldr.Config . number_system_names_for ( :th , % Cldr.Config { locales : [ &quot;en&quot; , &quot;th&quot; ] } ) { :ok , [ :latn , :thai ] }","ref":"Cldr.Config.html#number_system_names_for/2"},{"type":"function","title":"Cldr.Config.number_system_types_for/2","doc":"Returns the number system types for a locale","ref":"Cldr.Config.html#number_system_types_for/2"},{"type":"function","title":"Cldr.Config.number_systems_for/2","doc":"Returns the number systems for a locale Example iex&gt; Cldr.Config . number_systems_for ( :en , % Cldr.Config { locales : [ &quot;en&quot; , &quot;de&quot; ] } ) { :ok , %{ default : :latn , native : :latn } }","ref":"Cldr.Config.html#number_systems_for/2"},{"type":"function","title":"Cldr.Config.number_systems_for!/2","doc":"Returns the number systems for a locale or raises if there is an error Example iex&gt; Cldr.Config . number_systems_for! ( :de , % Cldr.Config { locales : [ &quot;en&quot; , &quot;de&quot; ] } ) %{ default : :latn , native : :latn }","ref":"Cldr.Config.html#number_systems_for!/2"},{"type":"function","title":"Cldr.Config.parent_locales/0","doc":"Returns a map of locale names to its parent locale name. Note that these mappings only exist where the normal inheritance doesn't apply.","ref":"Cldr.Config.html#parent_locales/0"},{"type":"function","title":"Cldr.Config.plural_ranges/0","doc":"Return a map of plural ranges","ref":"Cldr.Config.html#plural_ranges/0"},{"type":"function","title":"Cldr.Config.raise_if_otp_app_not_loaded!/1","doc":"","ref":"Cldr.Config.html#raise_if_otp_app_not_loaded!/1"},{"type":"function","title":"Cldr.Config.requested_locale_names/1","doc":"Returns a list of all configured locales. The list contains locales configured both in Gettext and specified in the mix.exs configuration file as well as the default locale.","ref":"Cldr.Config.html#requested_locale_names/1"},{"type":"function","title":"Cldr.Config.required_modules/0","doc":"Identifies the top level keys in the consolidated locale file. These keys represent difference dimensions of content in the CLDR repository and serve three purposes: To structure the content in the locale file To provide a rudimentary way to validate that some json represents a valid locale file","ref":"Cldr.Config.html#required_modules/0"},{"type":"function","title":"Cldr.Config.root_locale_name/0","doc":"","ref":"Cldr.Config.html#root_locale_name/0"},{"type":"function","title":"Cldr.Config.source_data_dir/0","doc":"Return the directory where Cldr stores its source core data, This directory should not be expected to be available other than when developing Cldr since it points to a source directory. These are the json files that result from the normalization of the original CLDR data.","ref":"Cldr.Config.html#source_data_dir/0"},{"type":"function","title":"Cldr.Config.split_currency_metadata/1","doc":"","ref":"Cldr.Config.html#split_currency_metadata/1"},{"type":"function","title":"Cldr.Config.system_name_from/3","doc":"Returns a number system name for a given locale and number system reference. Arguments system_name is any number system name returned by Cldr.known_number_systems/0 or a number system type returned by Cldr.known_number_system_types/1 locale is any valid locale name returned by Cldr.known_locale_names/1 or a Cldr.LanguageTag struct returned by Cldr.Locale.new!/2 config is a Config.Cldr.t() struct or a Cldr.backend() module Number systems can be referenced in one of two ways: As a number system type such as :default , :native , :traditional and :finance . This allows references to a number system for a locale in a consistent fashion for a given use With the number system name directly, such as :latn, :arab or any name returned by Cldr.known_number_systems/0 This function dereferences the supplied system_name and returns the actual system name. Examples iex&gt; Cldr.Config . system_name_from ( :default , :en , TestBackend.Cldr ) { :ok , :latn } iex&gt; Cldr.Config . system_name_from ( &quot;latn&quot; , :en , TestBackend.Cldr ) { :ok , :latn } iex&gt; Cldr.Config . system_name_from ( :native , :en , TestBackend.Cldr ) { :ok , :latn } iex&gt; Cldr.Config . system_name_from ( :nope , :en , TestBackend.Cldr ) { :error , { Cldr.UnknownNumberSystemError , &quot;The number system :nope is unknown&quot; } }","ref":"Cldr.Config.html#system_name_from/3"},{"type":"function","title":"Cldr.Config.territories/0","doc":"Returns a map of territory info for all territories known to CLDR. The territory information is independent of the ex_cldr configuration. Example iex&gt; Cldr.Config . territories [ :GB ] %{ currency : [ GBP : %{ from : ~D[1694-07-27] } ] , gdp : 2925000000000 , language_population : %{ &quot;ar&quot; =&gt; %{ population_percent : 0.3 } , &quot;bn&quot; =&gt; %{ population_percent : 0.4 } , &quot;cy&quot; =&gt; %{ official_status : &quot;official_regional&quot; , population_percent : 1.3 } , &quot;de&quot; =&gt; %{ population_percent : 9 } , &quot;en&quot; =&gt; %{ official_status : &quot;official&quot; , population_percent : 98 } , &quot;en-Shaw&quot; =&gt; %{ population_percent : 0 } , &quot;es&quot; =&gt; %{ population_percent : 8 } , &quot;fr&quot; =&gt; %{ population_percent : 23 } , &quot;ga&quot; =&gt; %{ official_status : &quot;official_regional&quot; , population_percent : 0.15 } , &quot;gd&quot; =&gt; %{ official_status : &quot;official_regional&quot; , population_percent : 0.11 , writing_percent : 5 } , &quot;gu&quot; =&gt; %{ population_percent : 2.9 } , &quot;it&quot; =&gt; %{ population_percent : 0.2 } , &quot;kw&quot; =&gt; %{ population_percent : 0.003 } , &quot;lt&quot; =&gt; %{ population_percent : 0.2 } , &quot;pa&quot; =&gt; %{ population_percent : 3.6 } , &quot;pl&quot; =&gt; %{ population_percent : 4 } , &quot;pt&quot; =&gt; %{ population_percent : 0.2 } , &quot;sco&quot; =&gt; %{ population_percent : 2.5 , writing_percent : 5 } , &quot;so&quot; =&gt; %{ population_percent : 0.2 } , &quot;ta&quot; =&gt; %{ population_percent : 3.2 } , &quot;tr&quot; =&gt; %{ population_percent : 0.2 } , &quot;ur&quot; =&gt; %{ population_percent : 3.5 } , &quot;zh-Hant&quot; =&gt; %{ population_percent : 0.3 } } , literacy_percent : 99 , measurement_system : %{ default : :uksystem , paper_size : :a4 , temperature : :uksystem } , population : 65761100 }","ref":"Cldr.Config.html#territories/0"},{"type":"function","title":"Cldr.Config.territory/1","doc":"Get territory info for a specific territory. territory is a string, atom or language_tag representation of a territory code in the list returned by Cldr.known_territories Returns: A map of the territory information or {:error, reason} Example iex&gt; Cldr.Config . territory &quot;au&quot; %{ currency : [ AUD : %{ from : ~D[1966-02-14] } ] , gdp : 1248000000000 , language_population : %{ &quot;en&quot; =&gt; %{ official_status : &quot;de_facto_official&quot; , population_percent : 96 } , &quot;it&quot; =&gt; %{ population_percent : 1.9 } , &quot;wbp&quot; =&gt; %{ population_percent : 0.0098 } , &quot;zh-Hant&quot; =&gt; %{ population_percent : 2.1 } , &quot;hnj&quot; =&gt; %{ population_percent : 0.0086 } } , literacy_percent : 99 , measurement_system : %{ default : :metric , paper_size : :a4 , temperature : :metric } , population : 25466500 } iex&gt; Cldr.Config . territory &quot;abc&quot; { :error , { Cldr.UnknownTerritoryError , &quot;The territory \\&quot; abc \\&quot; is unknown&quot; } }","ref":"Cldr.Config.html#territory/1"},{"type":"function","title":"Cldr.Config.territory_containers/0","doc":"Returns a map of territory containers","ref":"Cldr.Config.html#territory_containers/0"},{"type":"function","title":"Cldr.Config.territory_containment/0","doc":"Returns a map of territory containment","ref":"Cldr.Config.html#territory_containment/0"},{"type":"function","title":"Cldr.Config.territory_currency_data/0","doc":"Returns the currency mapping data for territories.","ref":"Cldr.Config.html#territory_currency_data/0"},{"type":"function","title":"Cldr.Config.territory_info/0","doc":"See Cldr.Config.territories/0 .","ref":"Cldr.Config.html#territory_info/0"},{"type":"function","title":"Cldr.Config.territory_info/1","doc":"See Cldr.Config.territory/1 .","ref":"Cldr.Config.html#territory_info/1"},{"type":"function","title":"Cldr.Config.territory_subdivision_containment/0","doc":"Return a mapping between a subdivision and its containing parents","ref":"Cldr.Config.html#territory_subdivision_containment/0"},{"type":"function","title":"Cldr.Config.territory_subdivisions/0","doc":"Return the territory subdivisions","ref":"Cldr.Config.html#territory_subdivisions/0"},{"type":"function","title":"Cldr.Config.unicode_script_to_subtag_mapping/0","doc":"Returns a mapping from Unicode script names to the respective subtag used in BCP 47 language tags.","ref":"Cldr.Config.html#unicode_script_to_subtag_mapping/0"},{"type":"function","title":"Cldr.Config.units/0","doc":"Returns unit conversion data, Example iex&gt; Cldr.Config . units |&gt; get_in ( [ :conversions , :quart ] ) %{ base_unit : :cubic_meter , factor : &quot;0.000946352946&quot; , offset : 0 , systems : [ :ussystem ] }","ref":"Cldr.Config.html#units/0"},{"type":"function","title":"Cldr.Config.unknown_locale_names/1","doc":"Returns a list of all locales that are configured but not available in the CLDR repository.","ref":"Cldr.Config.html#unknown_locale_names/1"},{"type":"function","title":"Cldr.Config.validity/1","doc":"Return a map of validity data for a given type. The types are :languages , :scripts , :territories , :subdivisions , :variants :units , :u , and :t","ref":"Cldr.Config.html#validity/1"},{"type":"function","title":"Cldr.Config.version/0","doc":"Returns the version string of the CLDR data repository","ref":"Cldr.Config.html#version/0"},{"type":"function","title":"Cldr.Config.week_info/0","doc":"See Cldr.Config.weeks/0 .","ref":"Cldr.Config.html#week_info/0"},{"type":"function","title":"Cldr.Config.weeks/0","doc":"Returns the data that defines start and end of calendar weeks, weekends and years","ref":"Cldr.Config.html#weeks/0"},{"type":"type","title":"Cldr.Config.number_system/0","doc":"","ref":"Cldr.Config.html#t:number_system/0"},{"type":"type","title":"Cldr.Config.t/0","doc":"","ref":"Cldr.Config.html#t:t/0"},{"type":"module","title":"Cldr.Install","doc":"Provides functions for installing locales. When installed as a package on from hex , Cldr has only the default locales [&quot;en&quot;, &quot;und&quot;] installed and configured. When other locales are added to the configuration Cldr will attempt to download the locale from github during compilation. If Cldr is installed from github directly then all locales are already installed.","ref":"Cldr.Install.html"},{"type":"function","title":"Cldr.Install.client_data_dir/1","doc":"See Cldr.Config.client_data_dir/1 .","ref":"Cldr.Install.html#client_data_dir/1"},{"type":"function","title":"Cldr.Install.client_locale_file/2","doc":"Returns the full pathname of the locale's json file. locale is any locale returned by Cldr.known_locale_names/1 No checking of locale validity is performed.","ref":"Cldr.Install.html#client_locale_file/2"},{"type":"function","title":"Cldr.Install.client_locales_dir/1","doc":"See Cldr.Config.client_locales_dir/1 .","ref":"Cldr.Install.html#client_locales_dir/1"},{"type":"function","title":"Cldr.Install.install_all_locale_names/1","doc":"Install all available locales.","ref":"Cldr.Install.html#install_all_locale_names/1"},{"type":"function","title":"Cldr.Install.install_known_locale_names/1","doc":"Install all the configured locales.","ref":"Cldr.Install.html#install_known_locale_names/1"},{"type":"function","title":"Cldr.Install.install_locale_name/3","doc":"Download the requested locale from github into the client application's cldr data directory. locale is any locale returned by Cldr.known_locale_names/1 options is a keyword list. Currently the only supported option is :force which defaults to false . If truthy the locale will be installed or re-installed. The data directory is typically priv/cldr/locales . This function is intended to be invoked during application compilation when a valid locale is configured but is not yet installed in the application. An https request to the master github repository for Cldr is made to download the correct version of the locale file which is then written to the configured data directory.","ref":"Cldr.Install.html#install_locale_name/3"},{"type":"function","title":"Cldr.Install.locale_filename/1","doc":"See Cldr.Config.locale_filename/1 .","ref":"Cldr.Install.html#locale_filename/1"},{"type":"function","title":"Cldr.Install.locale_installed?/2","doc":"Returns a boolean indicating if the requested locale is installed. No checking of the validity of the locale itself is performed. The check is based upon whether there is a locale file installed in the client application or in Cldr itself.","ref":"Cldr.Install.html#locale_installed?/2"},{"type":"function","title":"Cldr.Install.locale_stale?/2","doc":"Returns a boolean indicating if the requested locale has available data but the data is stale (is a older version not supported by this version of ex_cldr .)","ref":"Cldr.Install.html#locale_stale?/2"},{"type":"module","title":"Cldr.Locale.Loader","doc":"Provides a public interface to read the raw JSON locale files and return the CLDR data in a consistent format. The functions in this module are intended for the use of authors writing additional CLDR-based libraries. In addition, the functions in this module are intended for use at compile-time - not runtime - since reading, decoding and processing a locale file is an expensive operation.","ref":"Cldr.Locale.Loader.html"},{"type":"function","title":"Cldr.Locale.Loader.get_locale/2","doc":"Read the locale json, decode it and make any necessary transformations. This is the only place that we read the locale and we only read it once. All other uses of locale data are references to this data. Additionally the intention is that this is read only at compile time and used to construct accessor functions in other modules so that during production run there is no file access or decoding.","ref":"Cldr.Locale.Loader.html#get_locale/2"},{"type":"function","title":"Cldr.Locale.Loader.known_locale_names/1","doc":"Returns a list of all locales that are configured and available in the CLDR repository. Examples iex&gt; Cldr.Locale.Loader . known_locale_names % Cldr.Config { locales : [ &quot;en&quot; , &quot;de&quot; ] } [ :de , :en , :und ]","ref":"Cldr.Locale.Loader.html#known_locale_names/1"},{"type":"function","title":"Cldr.Locale.Loader.known_rbnf_locale_names/1","doc":"Returns a list of all locales that have RBNF data and that are configured and available in the CLDR repository.","ref":"Cldr.Locale.Loader.html#known_rbnf_locale_names/1"},{"type":"module","title":"Cldr.Substitution","doc":"Compiles substitution formats that are of the form &quot;{0} something {1}&quot; into a token list that allows for more efficient parameter substitution at runtime.","ref":"Cldr.Substitution.html"},{"type":"function","title":"Cldr.Substitution.parse/1","doc":"Parses a substitution template into a list of tokens to allow efficient parameter substitution at runtime. template is a binary that may include parameter markers that are substituted for values at runtime. Returns: A list of tokens where any substitution is marked as an integer any any binary tokens are passed through as is. Examples iex&gt; Cldr.Substitution . parse &quot;{0}, {1}&quot; [ 0 , &quot;, &quot; , 1 ] iex&gt; Cldr.Substitution . parse &quot;{0} This is something {1} or another {2}&quot; [ 0 , &quot; This is something &quot; , 1 , &quot; or another &quot; , 2 ] This function is primarily intended to support compile-time generation of templates that simplify and speed up parameter substitution at runtime.","ref":"Cldr.Substitution.html#parse/1"},{"type":"function","title":"Cldr.Substitution.substitute/2","doc":"Substitutes a list of values into a template token list that is created by Cldr.Substitution.parse/1 . list1 is a list of values that will be substituted into a a template list previously created by Cldr.Substitution.parse/1 list2 is a template list previously created by Cldr.Substitution.parse/1 Returns: A list with values substituted for parameters in the list1 template Examples: iex&gt; template = Cldr.Substitution . parse &quot;{0} This is something {1}&quot; [ 0 , &quot; This is something &quot; , 1 ] iex&gt; Cldr.Substitution . substitute [ &quot;a&quot; , &quot;b&quot; ] , template [ &quot;a&quot; , &quot; This is something &quot; , &quot;b&quot; ]","ref":"Cldr.Substitution.html#substitute/2"},{"type":"module","title":"Cldr.Timezone","doc":"Functions to map between the CLDR short time zone code and the IANA timezone names. The Unicode locale extension U allows the specification of the time zone requested for the provided locale. This short timezone codes never change even if the IANA names change over time. Therefore these short codes are always stable between CLDR releases.","ref":"Cldr.Timezone.html"},{"type":"function","title":"Cldr.Timezone.fetch/1","doc":"Returns a :{:ok, list} where list is a list of IANA timezone names for a given CLDR short zone code. If no such short code exists then :error is returned. Example iex&gt; Cldr.Timezone . fetch ( &quot;ausyd&quot; ) { :ok , [ &quot;Australia/Sydney&quot; , &quot;Australia/ACT&quot; , &quot;Australia/Canberra&quot; , &quot;Australia/NSW&quot; ] } iex&gt; Cldr.Timezone . fetch ( &quot;nope&quot; ) :error","ref":"Cldr.Timezone.html#fetch/1"},{"type":"function","title":"Cldr.Timezone.get/2","doc":"Returns a list of IANA time zone names for a given CLDR short zone code, or nil Examples iex&gt; Cldr.Timezone . fetch ( &quot;ausyd&quot; ) [ &quot;Australia/Sydney&quot; , &quot;Australia/ACT&quot; , &quot;Australia/Canberra&quot; , &quot;Australia/NSW&quot; ] } iex&gt; Cldr.Timezone . fetch ( &quot;nope&quot; ) nil","ref":"Cldr.Timezone.html#get/2"},{"type":"function","title":"Cldr.Timezone.timezones/0","doc":"Returns a mapping of CLDR short zone codes to IANA timezone names.","ref":"Cldr.Timezone.html#timezones/0"},{"type":"function","title":"Cldr.Timezone.timezones_for_territory/0","doc":"Returns a mapping of territories to their known IANA timezone names.","ref":"Cldr.Timezone.html#timezones_for_territory/0"},{"type":"module","title":"MyApp.Cldr","doc":"Provides the core functions to retrieve and manage the CLDR data that supports formatting and localisation. It provides the core functions to access formatted CLDR data, set and retrieve a current locale and validate certain core data types such as locales, currencies and territories.","ref":"MyApp.Cldr.html"},{"type":"function","title":"MyApp.Cldr.available_locale_name?/1","doc":"See Cldr.available_locale_name?/1 .","ref":"MyApp.Cldr.html#available_locale_name?/1"},{"type":"function","title":"MyApp.Cldr.default_locale/0","doc":"Returns the default locale . Example iex&gt; MyApp.Cldr . default_locale ( ) % Cldr.LanguageTag { backend : MyApp.Cldr , canonical_locale_name : &quot;en-001&quot; , cldr_locale_name : :&quot;en-001&quot; , language_subtags : [ ] , extensions : %{ } , gettext_locale_name : &quot;en&quot; , language : &quot;en&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :en , requested_locale_name : &quot;en-001&quot; , script : :Latn , territory : :&quot;001&quot; , transform : %{ } , language_variants : [ ] }","ref":"MyApp.Cldr.html#default_locale/0"},{"type":"function","title":"MyApp.Cldr.default_territory/0","doc":"Returns the default territory when a locale does not specify one and none can be inferred. Example iex&gt; MyApp.Cldr . default_territory ( ) :&quot;001&quot;","ref":"MyApp.Cldr.html#default_territory/0"},{"type":"function","title":"MyApp.Cldr.ellipsis/2","doc":"Add locale-specific ellipsis to a string. Arguments string is any String.t or a 2-element list of String.t between which the ellipsis is inserted. backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend!/0 . Note that Cldr.default_backend!/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs . options is a keyword list of options Options :locale is any valid locale name returned by Cldr.known_locale_names/1 . The default is Cldr.get_locale/0 . :location determines where to place the ellipsis. The options are :after (the default for a single string argument), :between (the default and only valid location for an argument that is a list of two strings) and :before . :format formats based upon whether the ellipsis is inserted between words or sentences. The valid options are :word or :sentence . The default is :sentence . Examples iex&gt; MyApp.Cldr . ellipsis &quot;And furthermore&quot; &quot;And furthermore…&quot; iex&gt; MyApp.Cldr . ellipsis [ &quot;And furthermore&quot; , &quot;there is much to be done&quot; ] , locale : :ja &quot;And furthermore…there is much to be done&quot; iex&gt; MyApp.Cldr . ellipsis &quot;And furthermore&quot; , format : :word &quot;And furthermore …&quot; iex&gt; MyApp.Cldr . ellipsis [ &quot;And furthermore&quot; , &quot;there is much to be done&quot; ] , locale : :ja , format : :word &quot;And furthermore … there is much to be done&quot;","ref":"MyApp.Cldr.html#ellipsis/2"},{"type":"function","title":"MyApp.Cldr.for_dialyzer/0","doc":"","ref":"MyApp.Cldr.html#for_dialyzer/0"},{"type":"function","title":"MyApp.Cldr.get_locale/0","doc":"Return the current locale to be used for Cldr functions that take an optional locale parameter for which a locale is not supplied. Example iex&gt; MyApp.Cldr . put_locale ( &quot;pl&quot; ) iex&gt; MyApp.Cldr . get_locale % Cldr.LanguageTag { backend : Elixir.MyApp.Cldr , canonical_locale_name : &quot;pl&quot; , cldr_locale_name : :pl , extensions : %{ } , language : &quot;pl&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :pl , territory : :PL , requested_locale_name : &quot;pl&quot; , script : :Latn , transform : %{ } , language_variants : [ ] }","ref":"MyApp.Cldr.html#get_locale/0"},{"type":"function","title":"MyApp.Cldr.known_calendars/0","doc":"See Cldr.known_calendars/0 .","ref":"MyApp.Cldr.html#known_calendars/0"},{"type":"function","title":"MyApp.Cldr.known_currencies/0","doc":"See Cldr.known_currencies/0 .","ref":"MyApp.Cldr.html#known_currencies/0"},{"type":"function","title":"MyApp.Cldr.known_gettext_locale_name/1","doc":"Returns either the Gettext locale_name in Cldr format or false based upon whether the locale name is configured in Gettext . Arguments locale is any valid locale name returned by MyApp.Cldr.known_gettext_locale_names/0 Examples iex&gt; MyApp.Cldr . known_gettext_locale_name &quot;en&quot; &quot;en&quot; iex&gt; MyApp.Cldr . known_gettext_locale_name &quot;en-SA&quot; false","ref":"MyApp.Cldr.html#known_gettext_locale_name/1"},{"type":"function","title":"MyApp.Cldr.known_gettext_locale_name?/1","doc":"Returns a boolean indicating if the specified locale name is configured and available in Gettext. Arguments locale is any valid locale name returned by MyApp.Cldr.known_locale_names/0 Examples iex&gt; MyApp.Cldr . known_gettext_locale_name? ( &quot;en&quot; ) true iex&gt; MyApp.Cldr . known_gettext_locale_name? ( &quot;!!&quot; ) false","ref":"MyApp.Cldr.html#known_gettext_locale_name?/1"},{"type":"function","title":"MyApp.Cldr.known_gettext_locale_names/0","doc":"Returns a list of Gettext locale names but in CLDR format with underscore replaced by hyphen in order to facilitate comparisons with Cldr locale names.","ref":"MyApp.Cldr.html#known_gettext_locale_names/0"},{"type":"function","title":"MyApp.Cldr.known_locale_name/1","doc":"Returns either the locale_name or false based upon whether the locale name is configured in Cldr . This is helpful when building a list of or expressions to return the first known locale name from a list. Arguments locale is any valid locale name returned by MyApp.Cldr.known_locale_names/0 Examples iex&gt; MyApp.Cldr . known_locale_name :&quot;en-AU&quot; :&quot;en-AU&quot; iex&gt; MyApp.Cldr . known_locale_name :&quot;en-SA&quot; false","ref":"MyApp.Cldr.html#known_locale_name/1"},{"type":"function","title":"MyApp.Cldr.known_locale_name?/1","doc":"Returns a boolean indicating if the specified locale name is configured and available in Cldr. Arguments locale is any valid locale name returned by MyApp.Cldr.known_locale_names/0 Examples iex&gt; MyApp.Cldr . known_locale_name? ( :en ) true iex&gt; MyApp.Cldr . known_locale_name? ( :&quot;!!&quot; ) false","ref":"MyApp.Cldr.html#known_locale_name?/1"},{"type":"function","title":"MyApp.Cldr.known_locale_names/0","doc":"Returns a list of the known locale names. Known locales are those locales which are the subset of all CLDR locales that have been configured for use either in this module or in Gettext .","ref":"MyApp.Cldr.html#known_locale_names/0"},{"type":"function","title":"MyApp.Cldr.known_number_system_types/0","doc":"Returns a list of atoms representing the number systems types known to Cldr . Example iex&gt; MyApp.Cldr . known_number_system_types [ :default , :finance , :native , :traditional ]","ref":"MyApp.Cldr.html#known_number_system_types/0"},{"type":"function","title":"MyApp.Cldr.known_number_systems/0","doc":"See Cldr.known_number_systems/0 .","ref":"MyApp.Cldr.html#known_number_systems/0"},{"type":"function","title":"MyApp.Cldr.known_rbnf_locale_name/1","doc":"Returns either the RBNF locale_name or false based upon whether the locale name is configured in Cldr and has RBNF rules defined. Arguments locale is any valid locale name returned by MyApp.Cldr.known_locale_names/0 Examples iex&gt; MyApp.Cldr . known_rbnf_locale_name :en :en iex&gt; MyApp.Cldr . known_rbnf_locale_name :&quot;en-SA&quot; false","ref":"MyApp.Cldr.html#known_rbnf_locale_name/1"},{"type":"function","title":"MyApp.Cldr.known_rbnf_locale_name?/1","doc":"Returns a boolean indicating if the specified locale name is configured and available in Cldr and supports rules based number formats (RBNF). Arguments locale is any valid locale name returned by MyApp.Cldr.known_locale_names/0 Examples iex&gt; MyApp.Cldr . known_rbnf_locale_name? ( :en ) true iex&gt; MyApp.Cldr . known_rbnf_locale_name? ( :&quot;!!&quot; ) false","ref":"MyApp.Cldr.html#known_rbnf_locale_name?/1"},{"type":"function","title":"MyApp.Cldr.known_rbnf_locale_names/0","doc":"Returns a list of locale names which have rules-based number formats (RBNF).","ref":"MyApp.Cldr.html#known_rbnf_locale_names/0"},{"type":"function","title":"MyApp.Cldr.known_territories/0","doc":"See Cldr.known_territories/0 .","ref":"MyApp.Cldr.html#known_territories/0"},{"type":"function","title":"MyApp.Cldr.normalize_lenient_parse/3","doc":"Normalizes a string by applying transliteration of common symbols in numbers, currencies and dates","ref":"MyApp.Cldr.html#normalize_lenient_parse/3"},{"type":"function","title":"MyApp.Cldr.put_locale/1","doc":"Set the current locale to be used for Cldr functions that take an optional locale parameter for which a locale is not supplied. Arguments locale is any valid locale name returned by MyApp.Cldr.known_locale_names/0 or a t:Cldr.LanguageTag struct returned by MyApp.Cldr.Locale.new!/1 See rfc5646 for the specification of a language tag. Examples iex&gt; MyApp.Cldr . put_locale ( &quot;en&quot; ) { :ok , % Cldr.LanguageTag { backend : MyApp.Cldr , canonical_locale_name : &quot;en&quot; , cldr_locale_name : :en , language_subtags : [ ] , extensions : %{ } , gettext_locale_name : &quot;en&quot; , language : &quot;en&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :en , requested_locale_name : &quot;en&quot; , script : :Latn , territory : :US , transform : %{ } , language_variants : [ ] } } iex&gt; MyApp.Cldr . put_locale ( &quot;invalid-locale!&quot; ) { :error , { Cldr.LanguageTag.ParseError , &quot;Expected a BCP47 language tag. Could not parse the remaining \\&quot; ! \\&quot; starting at position 15&quot; } }","ref":"MyApp.Cldr.html#put_locale/1"},{"type":"function","title":"MyApp.Cldr.quote/2","doc":"Add locale-specific quotation marks around a string. Arguments string is any valid Elixir string options is a keyword list of options Options locale is any valid locale name returned by Cldr.known_locale_names/1 . The default is Cldr.get_locale/0 Examples iex&gt; MyApp.Cldr . quote &quot;Quoted String&quot; &quot;“Quoted String”&quot; iex&gt; MyApp.Cldr . quote &quot;Quoted String&quot; , locale : :ja &quot;「Quoted String」&quot;","ref":"MyApp.Cldr.html#quote/2"},{"type":"function","title":"MyApp.Cldr.unknown_locale_names/0","doc":"Returns a list of the locales names that are configured, but not known in CLDR. Since there is a compile-time exception raised if there are any unknown locales this function should always return an empty list.","ref":"MyApp.Cldr.html#unknown_locale_names/0"},{"type":"function","title":"MyApp.Cldr.validate_calendar/1","doc":"See Cldr.validate_calendar/1 .","ref":"MyApp.Cldr.html#validate_calendar/1"},{"type":"function","title":"MyApp.Cldr.validate_currency/1","doc":"See Cldr.validate_currency/1 .","ref":"MyApp.Cldr.html#validate_currency/1"},{"type":"function","title":"MyApp.Cldr.validate_locale/1","doc":"Normalise and validate a locale name. Arguments locale is any valid locale name returned by MyApp.Cldr.known_locale_names/0 or a Cldr.LanguageTag struct returned by MyApp.Cldr.Locale.new!/1 Returns {:ok, language_tag} {:error, reason} Notes See rfc5646 for the specification of a language tag. Examples iex&gt; MyApp.Cldr . validate_locale ( :en ) { :ok , % Cldr.LanguageTag { backend : MyApp.Cldr , canonical_locale_name : &quot;en&quot; , cldr_locale_name : :en , extensions : %{ } , gettext_locale_name : &quot;en&quot; , language : &quot;en&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :en , requested_locale_name : &quot;en&quot; , script : :Latn , territory : :US , transform : %{ } , language_variants : [ ] } } iex&gt; MyApp.Cldr . validate_locale MyApp.Cldr . default_locale ( ) { :ok , % Cldr.LanguageTag { backend : MyApp.Cldr , canonical_locale_name : &quot;en-001&quot; , cldr_locale_name : :&quot;en-001&quot; , extensions : %{ } , gettext_locale_name : &quot;en&quot; , language : &quot;en&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :en , requested_locale_name : &quot;en-001&quot; , script : :Latn , territory : :&quot;001&quot; , transform : %{ } , language_variants : [ ] } } iex&gt; MyApp.Cldr . validate_locale ( &quot;zzz&quot; ) { :error , { Cldr.InvalidLanguageError , &quot;The language \\&quot; zzz \\&quot; is invalid&quot; } }","ref":"MyApp.Cldr.html#validate_locale/1"},{"type":"function","title":"MyApp.Cldr.validate_number_system/1","doc":"See Cldr.validate_number_system/1 .","ref":"MyApp.Cldr.html#validate_number_system/1"},{"type":"function","title":"MyApp.Cldr.validate_number_system_type/1","doc":"Normalise and validate a number system type. Arguments number_system_type is any number system type returned by Cldr.known_number_system_types/1 Returns {:ok, normalized_number_system_type} or {:error, {exception, message}} Examples iex&gt; MyApp.Cldr . validate_number_system_type :default { :ok , :default } iex&gt; MyApp.Cldr . validate_number_system_type :traditional { :ok , :traditional } iex&gt; MyApp.Cldr . validate_number_system_type :latn { :error , { Cldr.UnknownNumberSystemTypeError , &quot;The number system type :latn is unknown&quot; } } iex&gt; MyApp.Cldr . validate_number_system_type &quot;bork&quot; { :error , { Cldr.UnknownNumberSystemTypeError , &quot;The number system type \\&quot; bork \\&quot; is invalid&quot; } }","ref":"MyApp.Cldr.html#validate_number_system_type/1"},{"type":"function","title":"MyApp.Cldr.validate_territory/1","doc":"See Cldr.validate_territory/1 .","ref":"MyApp.Cldr.html#validate_territory/1"},{"type":"function","title":"MyApp.Cldr.with_locale/2","doc":"Execute a function with a locale ensuring that the current locale is restored after the function. Arguments locale is any valid locale name returned by Cldr.known_locale_names/1 . fun is any 0-arity function or function capture. Returns The value returned by the function fun/0 or {:error, {exception, reason}} if the locale is invalid or raises an exception if the current locale cannot be identified.","ref":"MyApp.Cldr.html#with_locale/2"},{"type":"module","title":"MyApp.Cldr.AcceptLanguage","doc":"Parses HTTP Accept-Language header values as defined in rfc2616 . The Accept-Language request-header field is similar to Accept, but restricts the set of natural languages that are preferred as a response to the request. Language tags function are provided in Cldr.LanguageTag . The format of an Accept-Language header is as follows in ABNF format: Accept - Language = &quot;Accept-Language&quot; &quot;:&quot; 1 #( language-range [ &quot;;&quot; &quot;q&quot; &quot;=&quot; qvalue ] ) language - range = ( ( 1 * 8 ALPHA * ( &quot;-&quot; 1 * 8 ALPHA ) ) | &quot;*&quot; ) Each language-range MAY be given an associated quality value which represents an estimate of the user's preference for the languages specified by that range. The quality value defaults to &quot;q=1&quot;. For example, Accept - Language : da , en - gb ; q = 0.8 , en ; q = 0.7 would mean: &quot;I prefer Danish, but will accept British English and other types of English.&quot;","ref":"MyApp.Cldr.AcceptLanguage.html"},{"type":"function","title":"MyApp.Cldr.AcceptLanguage.best_match/1","doc":"Parse an Accept-Language string and return the best match for a configured Cldr locale. Arguments accept_langauge is a string representing an accept language header Returns {:ok, language_tag} or {:error, reason} Examples iex&gt; MyApp.Cldr.AcceptLanguage . best_match ( &quot;da;q=0.1,zh-TW;q=0.3&quot; , TestBackend.Cldr ) { :ok , % Cldr.LanguageTag { backend : TestBackend.Cldr , canonical_locale_name : &quot;zh-TW&quot; , cldr_locale_name : :&quot;zh-Hant&quot; , language_subtags : [ ] , extensions : %{ } , gettext_locale_name : nil , language : &quot;zh&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :&quot;zh-Hant&quot; , requested_locale_name : &quot;zh-TW&quot; , script : :Hant , territory : :TW , transform : %{ } , language_variants : [ ] } } iex&gt; MyApp.Cldr.AcceptLanguage . best_match ( &quot;da;q=0.1,zh-TW;q=0.3&quot; , TestBackend.Cldr ) { :ok , % Cldr.LanguageTag { backend : TestBackend.Cldr , canonical_locale_name : &quot;zh-TW&quot; , cldr_locale_name : :&quot;zh-Hant&quot; , language_subtags : [ ] , extensions : %{ } , gettext_locale_name : nil , language : &quot;zh&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :&quot;zh-Hant&quot; , requested_locale_name : &quot;zh-TW&quot; , script : :Hant , territory : :TW , transform : %{ } , language_variants : [ ] } } iex&gt; MyApp.Cldr.AcceptLanguage . best_match ( &quot;xx,yy;q=0.3&quot; ) { :error , { Cldr.NoMatchingLocale , &quot;No configured locale could be matched to \\&quot; xx,yy;q=0.3 \\&quot; &quot; } } iex&gt; MyApp.Cldr.AcceptLanguage . best_match ( &quot;invalid_tag&quot; ) { :error , { Cldr.LanguageTag.ParseError , &quot;Expected a BCP47 language tag. Could not parse the remaining \\&quot; g \\&quot; starting at position 11&quot; } }","ref":"MyApp.Cldr.AcceptLanguage.html#best_match/1"},{"type":"function","title":"MyApp.Cldr.AcceptLanguage.parse/1","doc":"Parses an Accept-Language header value in its string or tokenized form to return a tuple of the form {:ok, [{quality, %Cldr.LanguageTag{}}, ...]} sorted by quality. Arguments accept-language is any string in the format defined by rfc2616 backend is any module that includes use Cldr and therefore is a Cldr backend module Returns {:ok, [{quality, language_tag}, ...]} or {:error, {Cldr.AcceptLanguageError, String.t}} If at least one valid language tag is found but errors are also detected on one more more tags, an {ok, list} tuple is returned wuth an error tuple for each invalid tag added at the end of the list. Example iex&gt; Cldr.AcceptLanguage . parse ( &quot;da,zh-TW;q=0.3&quot; , TestBackend.Cldr ) { :ok , [ { 1.0 , % Cldr.LanguageTag { backend : TestBackend.Cldr , canonical_locale_name : &quot;da&quot; , cldr_locale_name : :da , language_subtags : [ ] , extensions : %{ } , gettext_locale_name : nil , language : &quot;da&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :da , requested_locale_name : &quot;da&quot; , script : :Latn , territory : :DK , transform : %{ } , language_variants : [ ] } } , { 0.3 , % Cldr.LanguageTag { backend : TestBackend.Cldr , canonical_locale_name : &quot;zh-TW&quot; , cldr_locale_name : :&quot;zh-Hant&quot; , language_subtags : [ ] , extensions : %{ } , gettext_locale_name : nil , language : &quot;zh&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :&quot;zh-Hant&quot; , requested_locale_name : &quot;zh-TW&quot; , script : :Hant , territory : :TW , transform : %{ } , language_variants : [ ] } } ] } iex&gt; MyApp.Cldr.AcceptLanguage . parse ( &quot;invalid_tag&quot; ) { :error , { Cldr.LanguageTag.ParseError , &quot;Expected a BCP47 language tag. Could not parse the remaining \\&quot; g \\&quot; starting at position 11&quot; } } iex&gt; MyApp.Cldr.AcceptLanguage . parse ( &quot;da,zh-TW;q=0.3,invalid_tag&quot; ) { :ok , [ { 1.0 , % Cldr.LanguageTag { backend : TestBackend.Cldr , canonical_locale_name : &quot;da&quot; , cldr_locale_name : :da , language_subtags : [ ] , extensions : %{ } , gettext_locale_name : nil , language : &quot;da&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :da , requested_locale_name : &quot;da&quot; , script : :Latn , territory : :DK , transform : %{ } , language_variants : [ ] } } , { 0.3 , % Cldr.LanguageTag { backend : TestBackend.Cldr , canonical_locale_name : &quot;zh-TW&quot; , cldr_locale_name : :&quot;zh-Hant&quot; , language_subtags : [ ] , extensions : %{ } , gettext_locale_name : nil , language : &quot;zh&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :&quot;zh-Hant&quot; , requested_locale_name : &quot;zh-TW&quot; , script : :Hant , territory : :TW , transform : %{ } , language_variants : [ ] } } , { :error , { Cldr.LanguageTag.ParseError , &quot;Expected a BCP47 language tag. Could not parse the remaining \\&quot; g \\&quot; starting at position 11&quot; } } ] }","ref":"MyApp.Cldr.AcceptLanguage.html#parse/1"},{"type":"function","title":"MyApp.Cldr.AcceptLanguage.parse!/1","doc":"Parses an Accept-Language header value in its string or tokenized form to produce a list of tuples of the form [{quality, %Cldr.LanguageTag{}}, ...] sorted by quality in descending order. Arguments accept-language is any string in the format defined by rfc2616 Returns {:ok, [{quality, language_tag}, ...]} or raises a Cldr.AcceptLanguageError exception If at least one valid language tag is found but errors are also detected on one more more tags, an {ok, list} tuple is returned wuth an error tuple for each invalid tag added at the end of the list. Example iex&gt; MyApp.Cldr.AcceptLanguage . parse! ( &quot;da,zh-TW;q=0.3&quot; ) [ { 1.0 , % Cldr.LanguageTag { backend : TestBackend.Cldr , canonical_locale_name : &quot;da&quot; , cldr_locale_name : :da , language_subtags : [ ] , extensions : %{ } , gettext_locale_name : nil , language : &quot;da&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :da , requested_locale_name : &quot;da&quot; , script : :Latn , territory : :DK , transform : %{ } , language_variants : [ ] } } , { 0.3 , % Cldr.LanguageTag { backend : TestBackend.Cldr , canonical_locale_name : &quot;zh-TW&quot; , cldr_locale_name : :&quot;zh-Hant&quot; , language_subtags : [ ] , extensions : %{ } , gettext_locale_name : nil , language : &quot;zh&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :&quot;zh-Hant&quot; , requested_locale_name : &quot;zh-TW&quot; , script : :Hant , territory : :TW , transform : %{ } , language_variants : [ ] } } ] MyApp.Cldr.AcceptLanguage . parse! &quot;invalid_tag&quot; ** (Cldr.AcceptLanguageError) &quot;Expected a BCP47 language tag. Could not parse the remaining &quot;g&quot; starting at position 11 (ex_cldr) lib/cldr/accept_language.ex:304: Cldr.AcceptLanguage.parse!/1 iex&gt; MyApp.Cldr.AcceptLanguage . parse! ( &quot;da,zh-TW;q=0.3,invalid_tag&quot; ) [ { 1.0 , % Cldr.LanguageTag { backend : TestBackend.Cldr , canonical_locale_name : &quot;da&quot; , cldr_locale_name : :da , language_subtags : [ ] , extensions : %{ } , gettext_locale_name : nil , language : &quot;da&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :da , requested_locale_name : &quot;da&quot; , script : :Latn , territory : :DK , transform : %{ } , language_variants : [ ] } } , { 0.3 , % Cldr.LanguageTag { backend : TestBackend.Cldr , canonical_locale_name : &quot;zh-TW&quot; , cldr_locale_name : :&quot;zh-Hant&quot; , language_subtags : [ ] , extensions : %{ } , gettext_locale_name : nil , language : &quot;zh&quot; , locale : %{ } , private_use : [ ] , rbnf_locale_name : :&quot;zh-Hant&quot; , requested_locale_name : &quot;zh-TW&quot; , script : :Hant , territory : :TW , transform : %{ } , language_variants : [ ] } } , { :error , { Cldr.LanguageTag.ParseError , &quot;Expected a BCP47 language tag. Could not parse the remaining \\&quot; g \\&quot; starting at position 11&quot; } } ]","ref":"MyApp.Cldr.AcceptLanguage.html#parse!/1"},{"type":"module","title":"MyApp.Cldr.Locale","doc":"Backend module that provides functions to define new locales and display human-readable locale names for presentation purposes.","ref":"MyApp.Cldr.Locale.html"},{"type":"function","title":"MyApp.Cldr.Locale.fallback_locale_names/1","doc":"Returns the list of fallback locale names, starting with the provided locale name. Fallbacks are a list of locate names which can be used to resolve translation or other localization data if such localised data does not exist for this specific locale.. Arguments locale_name is any locale name returned by MyApp.Cldr.known_locale_names/0 Returns {:ok, list_of_locale_names} or {:error, {exception, reason}} Examples iex&gt; MyApp.Cldr.Locale . fallback_locale_names ( :&quot;fr-CA&quot; ) { :ok , [ :&quot;fr-CA&quot; , :fr , :und ] } # Fallbacks are typically formed by progressively # stripping variant, territory and script from the # given locale name. But not always - there are # certain fallbacks that take a different path. iex&gt; MyApp.Cldr.Locale . fallback_locale_names ( :nb ) { :ok , [ :nb , :no , :und ] }","ref":"MyApp.Cldr.Locale.html#fallback_locale_names/1"},{"type":"function","title":"MyApp.Cldr.Locale.fallback_locales/1","doc":"Returns the list of fallback locales, starting with the provided locale name. Fallbacks are a list of locate names which can be used to resolve translation or other localization data if such localised data does not exist for this specific locale. Arguments locale_name is any locale name returned by MyApp.Cldr.known_locale_names/0 Returns {:ok, list_of_locales} or {:error, {exception, reason}} Examples MyApp.Cldr.Locale . fallback_locales ( :&quot;fr-CA&quot; ) =&gt; { :ok , [ # Cldr.LanguageTag &lt; fr - CA [ validated ] &gt; , # Cldr.LanguageTag &lt; fr [ validated ] &gt; , # Cldr.LanguageTag &lt; und [ validated ] &gt; ] } # Fallbacks are typically formed by progressively # stripping variant, territory and script from the # given locale name. But not always - there are # certain fallbacks that take a different path. MyApp.Cldr.Locale . fallback_locales ( :nb ) ) =&gt; { :ok , [ # Cldr.LanguageTag &lt; nb [ validated ] &gt; , # Cldr.LanguageTag &lt; no [ validated ] &gt; , # Cldr.LanguageTag &lt; und [ validated ] &gt; ] }","ref":"MyApp.Cldr.Locale.html#fallback_locales/1"},{"type":"function","title":"MyApp.Cldr.Locale.locale_for_territory/1","doc":"Returns the &quot;best fit&quot; locale for a given territory. Using the population percentage data from CLDR, the language most commonly spoken in the given territory is used to form a locale name which is then validated against the given backend. First a territory-specific locale is validated and if that fails, the base language only is validate. For example, if the territory is AU then then the language most spoken is &quot;en&quot;. First, the locale &quot;en-AU&quot; is validated and if that fails, &quot;en&quot; is validated. Arguments territory is any ISO 3166 Alpha-2 territory code that can be validated by Cldr.validate_territory/1 Returns {:ok, language_tag} or {:error, {exception, reason}} Examples iex&gt; MyApp.Cldr.Locale.locale_for_territory(:AU) Elixir.MyApp.Cldr.validate_locale(:&quot;en-AU&quot;) iex&gt; MyApp.Cldr.Locale.locale_for_territory(:US) Elixir.MyApp.Cldr.validate_locale(:&quot;en-US&quot;) iex&gt; MyApp.Cldr.Locale.locale_for_territory(:ZZ) {:error, {Cldr.UnknownTerritoryError, &quot;The territory :ZZ is unknown&quot;}}","ref":"MyApp.Cldr.Locale.html#locale_for_territory/1"},{"type":"function","title":"MyApp.Cldr.Locale.locale_from_host/2","doc":"Returns a &quot;best fit&quot; locale for a host name. Arguments host is any valid host name options is a keyword list of options. The default is [] . Options :tlds is a list of territory codes as upper-cased atoms that are to be considered as top-level domains. See Cldr.Locale.locale_from_host/2 for the default list. Returns {:ok, langauge_tag} or {:error, {exception, reason}} Notes Certain top-level domains have become associated with content underlated to the territory for who the domain is registered. Therefore Google (and perhaps others) do not associate these TLDs as belonging to the territory but rather are considered generic top-level domain names. Examples iex&gt; MyApp.Cldr.Locale . locale_from_host &quot;a.b.com.au&quot; Elixir.MyApp.Cldr . validate_locale ( :&quot;en-AU&quot; ) iex&gt; MyApp.Cldr.Locale . locale_from_host ( &quot;a.b.com.tv&quot; ) { :error , { Cldr.UnknownLocaleError , &quot;No locale was identified for territory \\&quot; tv \\&quot; &quot; } } iex&gt; MyApp.Cldr.Locale . locale_from_host ( &quot;a.b.com&quot; ) { :error , { Cldr.UnknownLocaleError , &quot;No locale was identified for territory \\&quot; com \\&quot; &quot; } }","ref":"MyApp.Cldr.Locale.html#locale_from_host/2"},{"type":"function","title":"MyApp.Cldr.Locale.new/1","doc":"","ref":"MyApp.Cldr.Locale.html#new/1"},{"type":"function","title":"MyApp.Cldr.Locale.new!/1","doc":"","ref":"MyApp.Cldr.Locale.html#new!/1"},{"type":"function","title":"MyApp.Cldr.Locale.script_direction_from_locale/1","doc":"Returns the script direction for a locale. Arguments language_tag is any language tag returned by Cldr.Locale.new/2 or any locale_name returned by Cldr.known_locale_names/1 . Returns The script direction which is either :ltr (for left-to-right scripts) or :rtl (for right-to-left scripts). Examples iex&gt; MyApp.Cldr.Locale . script_direction_from_locale &quot;en-US&quot; :ltr iex&gt; MyApp.Cldr.Locale . script_direction_from_locale :ar :rtl","ref":"MyApp.Cldr.Locale.html#script_direction_from_locale/1"},{"type":"function","title":"MyApp.Cldr.Locale.territory_from_host/1","doc":"Returns the last segment of a host that might be a territory. Arguments host is any valid host name Returns {:ok, territory} or {:error, {exception, reason}} Examples iex&gt; Cldr.Locale . territory_from_host ( &quot;a.b.com.au&quot; ) { :ok , :AU } iex&gt; Cldr.Locale . territory_from_host ( &quot;a.b.com&quot; ) { :error , { Cldr.UnknownLocaleError , &quot;No locale was identified for territory \\&quot; com \\&quot; &quot; } }","ref":"MyApp.Cldr.Locale.html#territory_from_host/1"},{"type":"function","title":"MyApp.Cldr.Locale.territory_from_locale/1","doc":"Returns the territory from a language tag or locale name. Arguments locale is any language tag returned by MyApp.Cldr.Locale.new/1 or a locale name in the list returned by MyApp.Cldr.known_locale_names/0 Returns A territory code as an atom Examples iex&gt; MyApp.Cldr.Locale . territory_from_locale &quot;en-US&quot; :US iex&gt; MyApp.Cldr.Locale . territory_from_locale &quot;en-US-u-rg-GBzzzz&quot; :GB","ref":"MyApp.Cldr.Locale.html#territory_from_locale/1"},{"type":"function","title":"MyApp.Cldr.Locale.timezone_from_locale/1","doc":"Returns the time zone from a language tag or locale name. Arguments locale is any language tag returned by MyApp.Cldr.Locale.new/1 or a locale name in the list returned by MyApp.Cldr.known_locale_names/0 Returns A time zone ID as a string or :error if no time zone can be determined Examples iex&gt; MyApp.Cldr.Locale . timezone_from_locale &quot;en-US-u-tz-ausyd&quot; &quot;Australia/Sydney&quot;","ref":"MyApp.Cldr.Locale.html#timezone_from_locale/1"},{"type":"module","title":"MyApp.Cldr.Number.Cardinal","doc":"Implements cardinal plural rules for numbers.","ref":"MyApp.Cldr.Number.Cardinal.html"},{"type":"function","title":"MyApp.Cldr.Number.Cardinal.available_locale_names/0","doc":"The locale names for which plural rules are defined.","ref":"MyApp.Cldr.Number.Cardinal.html#available_locale_names/0"},{"type":"function","title":"MyApp.Cldr.Number.Cardinal.known_locale_names/0","doc":"The configured locales for which plural rules are defined. Returns the intersection of MyApp.Cldr.known_locale_names/0 and the locales for which Cardinal plural rules are defined. There are many Cldr locales which don't have their own plural rules so this list is the intersection of Cldr 's configured locales and those that have rules.","ref":"MyApp.Cldr.Number.Cardinal.html#known_locale_names/0"},{"type":"function","title":"MyApp.Cldr.Number.Cardinal.plural_rule/3","doc":"Return the plural key for a given number in a given locale Returns which plural key ( :zero , :one , :two , :few , :many or :other ) a given number fits into within the context of a given locale. Note that these key names should not be interpreted literally. For example, the key returned from Cldr.Number.Ordinal.plural_rule(0, &quot;en&quot;) is actually :other , not :zero . This key can then be used to format a number, date, time, unit, list or other content in a plural-sensitive way. Arguments number is any integer , float or Decimal locale is any locale returned by Cldr.Locale.new!/2 or any locale_name returned by MyApp.Cldr.known_locale_names/0 rounding is one of [:down, :up, :ceiling, :floor, :half_even, :half_up, :half_down] . The default is :half_even . Examples iex&gt; MyApp.Cldr.Number.Cardinal . plural_rule 0 , &quot;fr&quot; :one iex&gt; MyApp.Cldr.Number.Cardinal . plural_rule 0 , &quot;en&quot; :other","ref":"MyApp.Cldr.Number.Cardinal.html#plural_rule/3"},{"type":"function","title":"MyApp.Cldr.Number.Cardinal.plural_rules/0","doc":"Returns all the plural rules defined in CLDR.","ref":"MyApp.Cldr.Number.Cardinal.html#plural_rules/0"},{"type":"function","title":"MyApp.Cldr.Number.Cardinal.plural_rules_for/1","doc":"Return the plural rules for a locale. Arguments locale is any locale returned by MyApp.Cldr.Locale.new!/1 or any locale_name returned by MyApp.Cldr.known_locale_names/0 The rules are returned in AST form after parsing.","ref":"MyApp.Cldr.Number.Cardinal.html#plural_rules_for/1"},{"type":"function","title":"MyApp.Cldr.Number.Cardinal.pluralize/3","doc":"Pluralize a number using cardinal plural rules and a substitution map. Arguments number is an integer, float or Decimal locale is any locale returned by MyApp.Cldr.Locale.new!/1 or any locale_name returned by MyApp.Cldr.known_locale_names/0 substitutions is a map that maps plural keys to a string. The valid substitution keys are :zero , :one , :two , :few , :many and :other . See also MyApp.Cldr.Number.Cardinal.Cardinal.plural_rule/3 . Examples iex&gt; MyApp.Cldr.Number.Cardinal . pluralize 1 , &quot;en&quot; , %{ one : &quot;one&quot; } &quot;one&quot; iex&gt; MyApp.Cldr.Number.Cardinal . pluralize 2 , &quot;en&quot; , %{ one : &quot;one&quot; } nil iex&gt; MyApp.Cldr.Number.Cardinal . pluralize 2 , &quot;en&quot; , %{ one : &quot;one&quot; , two : &quot;two&quot; , other : &quot;other&quot; } &quot;other&quot; iex&gt; MyApp.Cldr.Number.Cardinal . pluralize 22 , &quot;en&quot; , %{ one : &quot;one&quot; , two : &quot;two&quot; , other : &quot;other&quot; } &quot;other&quot; iex&gt; MyApp.Cldr.Number.Cardinal . pluralize Decimal . new ( 1 ) , &quot;en&quot; , %{ one : &quot;one&quot; } &quot;one&quot; iex&gt; MyApp.Cldr.Number.Cardinal . pluralize Decimal . new ( 2 ) , &quot;en&quot; , %{ one : &quot;one&quot; } nil iex&gt; MyApp.Cldr.Number.Cardinal . pluralize Decimal . new ( 2 ) , &quot;en&quot; , %{ one : &quot;one&quot; , two : &quot;two&quot; } nil iex&gt; MyApp.Cldr.Number.Cardinal . pluralize 1 .. 10 , &quot;ar&quot; , %{ one : &quot;one&quot; , few : &quot;few&quot; , other : &quot;other&quot; } &quot;few&quot; iex&gt; MyApp.Cldr.Number.Cardinal . pluralize 1 .. 10 , &quot;en&quot; , %{ one : &quot;one&quot; , few : &quot;few&quot; , other : &quot;other&quot; } &quot;other&quot;","ref":"MyApp.Cldr.Number.Cardinal.html#pluralize/3"},{"type":"module","title":"MyApp.Cldr.Number.Ordinal","doc":"Implements ordinal plural rules for numbers.","ref":"MyApp.Cldr.Number.Ordinal.html"},{"type":"function","title":"MyApp.Cldr.Number.Ordinal.available_locale_names/0","doc":"The locale names for which plural rules are defined.","ref":"MyApp.Cldr.Number.Ordinal.html#available_locale_names/0"},{"type":"function","title":"MyApp.Cldr.Number.Ordinal.known_locale_names/0","doc":"The configured locales for which plural rules are defined. Returns the intersection of MyApp.Cldr.known_locale_names/0 and the locales for which Ordinal plural rules are defined. There are many Cldr locales which don't have their own plural rules so this list is the intersection of Cldr 's configured locales and those that have rules.","ref":"MyApp.Cldr.Number.Ordinal.html#known_locale_names/0"},{"type":"function","title":"MyApp.Cldr.Number.Ordinal.plural_rule/3","doc":"Return the plural key for a given number in a given locale Returns which plural key ( :zero , :one , :two , :few , :many or :other ) a given number fits into within the context of a given locale. Note that these key names should not be interpreted literally. For example, the key returned from Cldr.Number.Ordinal.plural_rule(0, &quot;en&quot;) is actually :other , not :zero . This key can then be used to format a number, date, time, unit, list or other content in a plural-sensitive way. Arguments number is any integer , float or Decimal locale is any locale returned by Cldr.Locale.new!/2 or any locale_name returned by MyApp.Cldr.known_locale_names/0 rounding is one of [:down, :up, :ceiling, :floor, :half_even, :half_up, :half_down] . The default is :half_even . Examples iex&gt; MyApp.Cldr.Number.Ordinal . plural_rule 0 , &quot;fr&quot; :other iex&gt; MyApp.Cldr.Number.Ordinal . plural_rule 1 , &quot;en&quot; :one","ref":"MyApp.Cldr.Number.Ordinal.html#plural_rule/3"},{"type":"function","title":"MyApp.Cldr.Number.Ordinal.plural_rules/0","doc":"Returns all the plural rules defined in CLDR.","ref":"MyApp.Cldr.Number.Ordinal.html#plural_rules/0"},{"type":"function","title":"MyApp.Cldr.Number.Ordinal.plural_rules_for/1","doc":"Return the plural rules for a locale. Arguments locale is any locale returned by MyApp.Cldr.Locale.new!/1 or any locale_name returned by MyApp.Cldr.known_locale_names/0 The rules are returned in AST form after parsing.","ref":"MyApp.Cldr.Number.Ordinal.html#plural_rules_for/1"},{"type":"function","title":"MyApp.Cldr.Number.Ordinal.pluralize/3","doc":"Pluralize a number using ordinal plural rules and a substitution map. Arguments number is an integer, float or Decimal or a Range.t{} . When a range, The is that in any usage, the start value is strictly less than the end value, and that no values are negative. Results for any cases that do not meet these criteria are undefined. locale is any locale returned by MyApp.Cldr.Locale.new!/1 or any locale_name returned by MyApp.Cldr.known_locale_names/0 substitutions is a map that maps plural keys to a string. The valid substitution keys are :zero , :one , :two , :few , :many and :other . See also MyApp.Cldr.Number.Ordinal.Ordinal.plural_rule/3 . Examples iex&gt; MyApp.Cldr.Number.Ordinal . pluralize 1 , :en , %{ one : &quot;one&quot; } &quot;one&quot; iex&gt; MyApp.Cldr.Number.Ordinal . pluralize 2 , :en , %{ one : &quot;one&quot; } nil iex&gt; MyApp.Cldr.Number.Ordinal . pluralize 2 , :en , %{ one : &quot;one&quot; , two : &quot;two&quot; } &quot;two&quot; iex&gt; MyApp.Cldr.Number.Ordinal . pluralize 22 , :en , %{ one : &quot;one&quot; , two : &quot;two&quot; , other : &quot;other&quot; } &quot;two&quot; iex&gt; MyApp.Cldr.Number.Ordinal . pluralize Decimal . new ( 1 ) , :en , %{ one : &quot;one&quot; } &quot;one&quot; iex&gt; MyApp.Cldr.Number.Ordinal . pluralize Decimal . new ( 2 ) , :en , %{ one : &quot;one&quot; } nil iex&gt; MyApp.Cldr.Number.Ordinal . pluralize Decimal . new ( 2 ) , :en , %{ one : &quot;one&quot; , two : &quot;two&quot; } &quot;two&quot; iex&gt; MyApp.Cldr.Number.Ordinal . pluralize 1 .. 10 , &quot;ar&quot; , %{ one : &quot;one&quot; , few : &quot;few&quot; , other : &quot;other&quot; } &quot;other&quot; iex&gt; MyApp.Cldr.Number.Ordinal . pluralize 1 .. 10 , &quot;en&quot; , %{ one : &quot;one&quot; , few : &quot;few&quot; , other : &quot;other&quot; } &quot;other&quot;","ref":"MyApp.Cldr.Number.Ordinal.html#pluralize/3"},{"type":"module","title":"MyApp.Cldr.Number.PluralRule.Range","doc":"Implements plural rules for ranges","ref":"MyApp.Cldr.Number.PluralRule.Range.html"},{"type":"function","title":"MyApp.Cldr.Number.PluralRule.Range.plural_rule/3","doc":"Returns a final plural type for a start-of-range plural type, an end-of-range plural type and a locale. Arguments first is a plural type for the start of a range last is a plural type for the end of a range locale is any Cldr.LanguageTag.t or a language name (not locale name) Example iex&gt; MyApp.Cldr.Number.PluralRule.Range . plural_rule :other , :few , &quot;ar&quot; :few","ref":"MyApp.Cldr.Number.PluralRule.Range.html#plural_rule/3"},{"type":"module","title":"MyApp.Gettext","doc":"","ref":"MyApp.Gettext.html"},{"type":"macro","title":"MyApp.Gettext.dgettext/3","doc":"Callback implementation for Gettext.Backend.dgettext/3 .","ref":"MyApp.Gettext.html#dgettext/3"},{"type":"macro","title":"MyApp.Gettext.dgettext_noop/2","doc":"Callback implementation for Gettext.Backend.dgettext_noop/2 .","ref":"MyApp.Gettext.html#dgettext_noop/2"},{"type":"macro","title":"MyApp.Gettext.dngettext/5","doc":"Callback implementation for Gettext.Backend.dngettext/5 .","ref":"MyApp.Gettext.html#dngettext/5"},{"type":"macro","title":"MyApp.Gettext.dngettext_noop/3","doc":"Callback implementation for Gettext.Backend.dngettext_noop/3 .","ref":"MyApp.Gettext.html#dngettext_noop/3"},{"type":"macro","title":"MyApp.Gettext.dpgettext/4","doc":"Callback implementation for Gettext.Backend.dpgettext/4 .","ref":"MyApp.Gettext.html#dpgettext/4"},{"type":"macro","title":"MyApp.Gettext.dpgettext_noop/3","doc":"","ref":"MyApp.Gettext.html#dpgettext_noop/3"},{"type":"macro","title":"MyApp.Gettext.dpngettext/6","doc":"Callback implementation for Gettext.Backend.dpngettext/6 .","ref":"MyApp.Gettext.html#dpngettext/6"},{"type":"macro","title":"MyApp.Gettext.dpngettext_noop/4","doc":"","ref":"MyApp.Gettext.html#dpngettext_noop/4"},{"type":"macro","title":"MyApp.Gettext.gettext/2","doc":"Callback implementation for Gettext.Backend.gettext/2 .","ref":"MyApp.Gettext.html#gettext/2"},{"type":"macro","title":"MyApp.Gettext.gettext_comment/1","doc":"Callback implementation for Gettext.Backend.gettext_comment/1 .","ref":"MyApp.Gettext.html#gettext_comment/1"},{"type":"macro","title":"MyApp.Gettext.gettext_noop/1","doc":"Callback implementation for Gettext.Backend.gettext_noop/1 .","ref":"MyApp.Gettext.html#gettext_noop/1"},{"type":"function","title":"MyApp.Gettext.handle_missing_bindings/2","doc":"Callback implementation for Gettext.Backend.handle_missing_bindings/2 .","ref":"MyApp.Gettext.html#handle_missing_bindings/2"},{"type":"function","title":"MyApp.Gettext.handle_missing_plural_translation/7","doc":"Callback implementation for Gettext.Backend.handle_missing_plural_translation/7 .","ref":"MyApp.Gettext.html#handle_missing_plural_translation/7"},{"type":"function","title":"MyApp.Gettext.handle_missing_translation/5","doc":"Callback implementation for Gettext.Backend.handle_missing_translation/5 .","ref":"MyApp.Gettext.html#handle_missing_translation/5"},{"type":"function","title":"MyApp.Gettext.lgettext/5","doc":"","ref":"MyApp.Gettext.html#lgettext/5"},{"type":"function","title":"MyApp.Gettext.lngettext/7","doc":"","ref":"MyApp.Gettext.html#lngettext/7"},{"type":"macro","title":"MyApp.Gettext.ngettext/4","doc":"Callback implementation for Gettext.Backend.ngettext/4 .","ref":"MyApp.Gettext.html#ngettext/4"},{"type":"macro","title":"MyApp.Gettext.ngettext_noop/2","doc":"Callback implementation for Gettext.Backend.ngettext_noop/2 .","ref":"MyApp.Gettext.html#ngettext_noop/2"},{"type":"macro","title":"MyApp.Gettext.pgettext/3","doc":"Callback implementation for Gettext.Backend.pgettext/3 .","ref":"MyApp.Gettext.html#pgettext/3"},{"type":"macro","title":"MyApp.Gettext.pgettext_noop/2","doc":"","ref":"MyApp.Gettext.html#pgettext_noop/2"},{"type":"macro","title":"MyApp.Gettext.pngettext/5","doc":"Callback implementation for Gettext.Backend.pngettext/5 .","ref":"MyApp.Gettext.html#pngettext/5"},{"type":"macro","title":"MyApp.Gettext.pngettext_noop/3","doc":"","ref":"MyApp.Gettext.html#pngettext_noop/3"},{"type":"module","title":"MyApp.Gettext.Plural","doc":"","ref":"MyApp.Gettext.Plural.html"},{"type":"function","title":"MyApp.Gettext.Plural.nplurals/1","doc":"Returns the number of plural forms for a given locale. locale is either a locale name in the list {:__aliases__, [counter: {MyApp.Gettext.Plural, 1}, line: 4], [:MyApp, :Cldr]}.known_locale_names/0 or a %LanguageTag{} as returned by Cldr.Locale.new/2 Examples iex&gt; MyApp.Gettext.Plural . nplurals ( &quot;pl&quot; ) 4 iex&gt; MyApp.Gettext.Plural . nplurals ( &quot;en&quot; ) 2","ref":"MyApp.Gettext.Plural.html#nplurals/1"},{"type":"function","title":"MyApp.Gettext.Plural.plural/2","doc":"Returns the plural form of a number for a given locale. locale is either a locale name in the list {:__aliases__, [counter: {MyApp.Gettext.Plural, 1}, line: 4], [:MyApp, :Cldr]}.known_locale_names/0 or a %LanguageTag{} as returned by Cldr.Locale.new/2 Examples iex&gt; MyApp.Gettext.Plural . plural ( &quot;pl&quot; , 1 ) 0 iex&gt; MyApp.Gettext.Plural . plural ( &quot;pl&quot; , 2 ) 1 iex&gt; MyApp.Gettext.Plural . plural ( &quot;pl&quot; , 5 ) 2 iex&gt; MyApp.Gettext.Plural . plural ( &quot;pl&quot; , 112 ) 2 iex&gt; MyApp.Gettext.Plural . plural ( &quot;en&quot; , 1 ) 0 iex&gt; MyApp.Gettext.Plural . plural ( &quot;en&quot; , 2 ) 1 iex&gt; MyApp.Gettext.Plural . plural ( &quot;en&quot; , 112 ) 1 iex&gt; MyApp.Gettext.Plural . plural ( &quot;en_GB&quot; , 112 ) 1","ref":"MyApp.Gettext.Plural.html#plural/2"},{"type":"exception","title":"Cldr.AcceptLanguageError","doc":"Exception raised when there no valid language tag in an Accept-Language header.","ref":"Cldr.AcceptLanguageError.html"},{"type":"exception","title":"Cldr.AmbiguousTimezoneError","doc":"Exception raised when the there are more than one timezones for a locale","ref":"Cldr.AmbiguousTimezoneError.html"},{"type":"exception","title":"Cldr.FormatCompileError","doc":"Exception raised when there is an error in the compiling of a number format.","ref":"Cldr.FormatCompileError.html"},{"type":"exception","title":"Cldr.FormatError","doc":"Exception raised when there is an error in the formatting of a number/list/...","ref":"Cldr.FormatError.html"},{"type":"exception","title":"Cldr.InvalidDateFormatType","doc":"Exception raised when there is an invalid date format type.","ref":"Cldr.InvalidDateFormatType.html"},{"type":"exception","title":"Cldr.InvalidDateTimeFormatType","doc":"Exception raised when there is an invalid datetime format type.","ref":"Cldr.InvalidDateTimeFormatType.html"},{"type":"exception","title":"Cldr.InvalidLanguageError","doc":"Exception raised when a language is invalid","ref":"Cldr.InvalidLanguageError.html"},{"type":"exception","title":"Cldr.InvalidLanguageTag","doc":"Exception raised when there is an a parse error in a language tag","ref":"Cldr.InvalidLanguageTag.html"},{"type":"exception","title":"Cldr.InvalidScriptError","doc":"Exception raised when a script is invalid","ref":"Cldr.InvalidScriptError.html"},{"type":"exception","title":"Cldr.InvalidTerritoryError","doc":"Exception raised when a territory is invalid","ref":"Cldr.InvalidTerritoryError.html"},{"type":"exception","title":"Cldr.InvalidTimeFormatType","doc":"Exception raised when there is an invalid time format type.","ref":"Cldr.InvalidTimeFormatType.html"},{"type":"exception","title":"Cldr.InvalidVariantError","doc":"Exception raised when a language variant is invalid","ref":"Cldr.InvalidVariantError.html"},{"type":"exception","title":"Cldr.NoDefaultBackendError","doc":"Exception raised when there is no default backend configured","ref":"Cldr.NoDefaultBackendError.html"},{"type":"exception","title":"Cldr.NoMatchingLocale","doc":"Exception raised when no configured locale matches the provided &quot;Accept-Language&quot; header","ref":"Cldr.NoMatchingLocale.html"},{"type":"exception","title":"Cldr.NoParentError","doc":"Exception raised when the there are more no parent locale","ref":"Cldr.NoParentError.html"},{"type":"exception","title":"Cldr.Rbnf.NotAvailable","doc":"Exception raised when there is no RBNF for a locale.","ref":"Cldr.Rbnf.NotAvailable.html"},{"type":"exception","title":"Cldr.UnknownBackendError","doc":"Exception raised when the backend module is unknown or not a backend module","ref":"Cldr.UnknownBackendError.html"},{"type":"exception","title":"Cldr.UnknownCalendarError","doc":"Exception raised when an attempt is made to use a calendar that is not known. in Cldr .","ref":"Cldr.UnknownCalendarError.html"},{"type":"exception","title":"Cldr.UnknownCurrencyError","doc":"Exception raised when there is an invalid currency code.","ref":"Cldr.UnknownCurrencyError.html"},{"type":"exception","title":"Cldr.UnknownFormatError","doc":"Exception raised when an attempt is made to use a locale that is not configured in Cldr . Cldr.known_locale_names/1 returns the locale names known to Cldr .","ref":"Cldr.UnknownFormatError.html"},{"type":"exception","title":"Cldr.UnknownLocaleError","doc":"Exception raised when an attempt is made to use a locale not configured in Cldr . Cldr.known_locale_names/1 returns the locale names known to Cldr .","ref":"Cldr.UnknownLocaleError.html"},{"type":"exception","title":"Cldr.UnknownMeasurementSystemError","doc":"Exception raised when the measurement system is invalid.","ref":"Cldr.UnknownMeasurementSystemError.html"},{"type":"exception","title":"Cldr.UnknownNumberSystemError","doc":"Exception raised when an attempt is made to use a number system that is not known in Cldr . Cldr.Number.number_system_names/0 returns the number system names known to Cldr .","ref":"Cldr.UnknownNumberSystemError.html"},{"type":"exception","title":"Cldr.UnknownNumberSystemTypeError","doc":"Exception raised when an attempt is made to use a number system type that is not known in Cldr . Cldr.Number.number_system_types/0 returns the number system types known to Cldr .","ref":"Cldr.UnknownNumberSystemTypeError.html"},{"type":"exception","title":"Cldr.UnknownOTPAppError","doc":"Exception raised when the configured OTP app is not known","ref":"Cldr.UnknownOTPAppError.html"},{"type":"exception","title":"Cldr.UnknownPluralRules","doc":"Exception raised when there are no plural rules for a locale or language.","ref":"Cldr.UnknownPluralRules.html"},{"type":"exception","title":"Cldr.UnknownTerritoryError","doc":"Exception raised when there is an invalid territory code.","ref":"Cldr.UnknownTerritoryError.html"},{"type":"exception","title":"Cldr.UnknownUnitError","doc":"Exception raised when an attempt is made to use a unit that is not known. in Cldr .","ref":"Cldr.UnknownUnitError.html"},{"type":"extras","title":"Getting Started with Cldr","doc":"","ref":"readme.html"},{"type":"extras","title":"Getting Started with Cldr - If you use Cldr.Plug.PutLocale","doc":"Please note that as of ex_cldr version 2.29.9, the CLDR-based plugs have been extracted to their own ex_cldr_plugs library. you will need to add that dependency to your application. For example: # in mix.exs def deps do [ { :ex_cldr , &quot;~&gt; 2.37&quot; } , { :ex_cldr_plugs , &quot;~&gt; 1.2&quot; } , ... ] end","ref":"readme.html#if-you-use-cldr-plug-putlocale"},{"type":"extras","title":"Getting Started with Cldr - Introduction","doc":"ex_cldr is an Elixir library for the Unicode Consortium's Common Locale Data Repository (CLDR) . The intentions of CLDR, and this library, is to simplify the locale specific formatting and parsing of numbers, lists, currencies, calendars, units of measure and dates/times. As of April 28th 2023 and ex_cldr Version 2.37.0, ex_cldr is based upon CLDR version 43.0 . The first step is to define a module that will host the desired ex_cldr configuration and the functions that serve as the public API. This module is referred to in this documentation as a backend module. For example: defmodule MyApp.Cldr do @moduledoc &quot;&quot;&quot; Define a backend module that will host our Cldr configuration and public API. Most function calls in Cldr will be calls to functions on this module. &quot;&quot;&quot; use Cldr , locales : [ &quot;en&quot; , &quot;fr&quot; , &quot;zh&quot; , &quot;th&quot; ] , default_locale : &quot;en&quot; end This strategy means that different configurations can be defined and it also means that one Cldr implementation won't interfer with implementations in other, potentially dependent, applications. The functions you are mostly likely to use are: MyApp.Cldr.default_locale/0 MyApp.Cldr.put_locale/1 MyApp.Cldr.get_locale/0 MyApp.Cldr.known_locale_names/0 MyApp.Cldr.Locale.new/1 MyApp.Cldr.validate_locale/1","ref":"readme.html#introduction"},{"type":"extras","title":"Getting Started with Cldr - Use Case","doc":"Use this library if you need to: Support multiple languages and locales in your application Support formatting numbers, dates, times, date-times, units and lists in one language or many Need to access the data maintained in the CLDR repository in a functional manner Parse an Accept-Language http header or a language tag It is highly likely that you will also want to install one or more of the dependent packages that provide localization and formatting for a particular data domain. See Additional Cldr Packages below .","ref":"readme.html#use-case"},{"type":"extras","title":"Getting Started with Cldr - Elixir Version Requirements","doc":"ex_cldr requires Elixir 1.11 or later.","ref":"readme.html#elixir-version-requirements"},{"type":"extras","title":"Getting Started with Cldr - Installation","doc":"Add ex_cldr and the JSON library of your choice as a dependencies to your mix project: defp deps do [ { :ex_cldr , &quot;~&gt; 2.37&quot; } , # Poison or any other compatible json library # that implements `encode!/1` and `decode!/1` # :jason is recommended { :jason , &quot;~&gt; 1.0&quot; } # {:poison, &quot;~&gt; 2.1 or ~&gt; 3.0&quot;} ] end then retrieve ex_cldr and the JSON library from hex : mix deps . get mix deps . compile","ref":"readme.html#installation"},{"type":"extras","title":"Getting Started with Cldr - Additional Cldr Packages","doc":"ex_cldr includes only basic functions to maintain the CLDR data repository in an accessible manner and to manage locale definitions. Additional functionality is available by adding additional packages: Plugs for setting the locale from an HTTP request: ex_cldr_plugs Number formatting: ex_cldr_numbers List formatting: ex_cldr_lists Unit formatting: ex_cldr_units Date/Time/DateTime formatting: ex_cldr_dates_times Route localization for Phoenix: ex_cldr_routes Locale name localisation: ex_cldr_locale_display HTML select helpers: ex_cldr_html Calendars: ex_cldr_calendars Calendar formatting: ex_cldr_calendars_format Printf-like formatting: ex_cldr_print Collation: ex_cldr_collation ICU Message formatting: ex_cldr_messages Territories localization and information: ex_cldr_territories by @Schultzer Languages localization: ex_cldr_languages by @lostkobrakai Each of these packages includes ex_cldr as a dependency so configuring any of these additional packages will automatically install ex_cldr .","ref":"readme.html#additional-cldr-packages"},{"type":"extras","title":"Getting Started with Cldr - Configuration","doc":"Cldr attempts to maximise runtime performance at the expense of additional compile time. Where possible Cldr will create functions to encapsulate data at compile time. To perform these optimizations for all 541 locales known to Cldr wouldn't be an effective use of your time or your computer's. Therefore Cldr requires that you configure the locales you want to use. The preferred way to configure Cldr is to define the configuration in your backend module. This removes any dependency on your mix.exs and therefore simplifies deployment as a release. Backend Module Configuration The preferred configuration method is to define the configuration in the backend module. Using the backend configuration in config.exs is discouraged and will result in a warning at compile time. The configuration keys are the same so the preferred way to achieve the same configuration as defined in the global example is: defmodule MyApp.Cldr do use Cldr , default_locale : &quot;en&quot; , locales : [ &quot;fr&quot; , &quot;en&quot; , &quot;bs&quot; , &quot;si&quot; , &quot;ak&quot; , &quot;th&quot; ] , add_fallback_locales : false , gettext : MyApp.Gettext , data_dir : &quot;./priv/cldr&quot; , otp_app : :my_app , precompile_number_formats : [ &quot;¤¤#,##0.##&quot; ] , precompile_transliterations : [ { :latn , :arab } , { :thai , :latn } ] , providers : [ Cldr.Number ] , generate_docs : true , force_locale_download : false end Otp App Configuration In the backend configuration example above the :otp_app key has been defined. This means that Cldr will look for additional configuration, defined under the key :my_app with the sub-key MyApp.Cldr . For example: # cldr.ex defmodule MyApp.Cldr do use Cldr , otp_app : :my_app , default_locale : &quot;en&quot; , gettext : MyApp.Gettext , json_library : Jason , data_dir : &quot;./priv/cldr&quot; , precompile_number_formats : [ &quot;¤¤#,##0.##&quot; ] , providers : [ Cldr.Number ] end # config/config.exs config :my_app , MyApp.Cldr , # a single locale, for fast compilation in dev / test locales : [ &quot;en&quot; ] # config/production.exs config :my_app , MyApp.Cldr , # these will take a while to compile locales : [ &quot;fr&quot; , &quot;en&quot; , &quot;bs&quot; , &quot;si&quot; , &quot;ak&quot; , &quot;th&quot; ] , precompile_transliterations : [ { :latn , :arab } , { :thai , :latn } ] Multiple backends can be configured under a single :otp_app if required. Global configuration. In config.exs a global configuration can be defined under the :ex_cldr key. Although any valid configuration keys can be used here, only the keys :json_library , :default_locale , :default_backend , :cacertfile , :data_dir , :force_locale_download are considered valid. Other configuration keys may be used to aid migration from Cldr version 1.x but a deprecation message will be printed during compilation. Here's an example of global configuration: config :ex_cldr , default_locale : &quot;en&quot; , default_backend : MyApp.Cldr , json_library : Jason , cacertfile : &quot;path/to/cacertfile&quot; Note that the :json_library key can only be defined at the global level since it is required during compilation before any backend module is compiled. On most platforms other than Windows the :cacertfile will be automatically detected. Any configured :cacertfile will take precedence on all platforms. If configuration beyond the keys :default_locale , :cacertfile or :json_library are defined a deprecation warning is printed at compile time noting that configuration should be moved to a backend module. Configuration Priority When building the consolidated configuration the following priority applies: Consider the global configuration Merge the otp_app configuration over the top of the global configuration Merge the backend module configuration over the top Backend Configuration Keys The configuration keys available for Cldr are: default_locale specifies the default locale to be used for this backend. The default locale in case no other locale has been set is &quot;en-001&quot; . The default locale calculated as follows: If set by the :default_locale key, then this is the priority If no :default_locale key, then a configured Gettext default locale for this backend is chosen If no :default_locale key is specified and no Gettext module is configured, or is configured but has no default set, use Cldr.default_locale/0 which returns either the default locale configurated in mix.exs under the ex_cldr key or then the system default locale will is currently en-001 locales : Defines what locales will be configured in Cldr . Only these locales will be available and an exception Cldr.UnknownLocaleError will be raised if there is an attempt to use an unknown locale. This is the same behaviour as Gettext . Locales are configured as a list of binaries (strings). For convenience it is possible to use wildcard matching of locales which is particulalry helpful when there are many regional variances of a single language locale. For example, there are over 100 regional variants of the &quot;en&quot; locale in CLDR. A wildcard locale is detected by the presence of . , [ , * and + in the locale string. This locale is then matched using the pattern as a regex to match against all available locales. The example below will configure all locales that start with en- and the locale fr . use Cldr , default_locale : &quot;en&quot; , locales : [ &quot;en-*&quot; , &quot;fr&quot; ] There is one additional setting which is :all which will configure all 541 locales. This is highly discouraged since it will take many minutes to compile your project and will consume more memory than you really want. This setting is there to aid in running the test suite. Really, don't use this setting. :add_fallback_locales is a boolean key which when true results in the fallback locales being added for each of the configured locales. The default is false . The reason to set this option to true is that some data such as rules based number formats and subdivision data are inherited from their language roots. For example, the locale en-001 is inherited from the locale en . Locale en-001 does not have any rules based number formats or subdivision data defined for it. However locale en does. Including the fallback locales maximises the opportunity to resolve localised data. :gettext : specifies the name of a Gettext module that informs Cldr to use that module as an additional source of locales you want to configure. Since Gettext uses the Posix locale name format (locales with an '_' in them) and Cldr uses the Unicode format (a '-' as the subtag separator), Cldr will transliterate locale names from Gettext into the Cldr canonical form. For example: use Cldr , default_locale : &quot;en&quot; , gettext : MyApp.Gettext , locales : [ &quot;en-*&quot; , &quot;fr&quot; ] :data_dir : indicates where downloaded locale files will be stored. The default is :code.priv_dir(otp_app) where otp_app is the app defined under the :otp_app configuration key. If that key is not specified then the :ex_cldr app is used. It is recommended that an :otp_app key is specified in your backend module configuration. :precompile_number_formats : provides a means to have user-defined format strings precompiled at application compile time. This has a performance benefit since precompiled formats execute approximately twice as fast as formats that are not precompiled. :precompile_transliterations : defines those transliterations between the digits of two different number systems that will be precompiled. The is a list of 2-tuples where each tuple is of the form {from_number_system, to_number_system} where each number system is expressed as an atom. The available number systems is returned by Cldr.Number.System.systems_with_digits/0 . The default is the empty list [] . :precompile_date_time_formats : provides a means to have user-defined date, time and date time format strings precompiled at application compile time. This has a performance benefit since precompiled formats execute approximately twice as fast as formats that are not precompiled. These formats are used by ex_cldr_date_times . :precompile_interval_formats : provides a means to have user-defined interval format strings precompiled at application compile time. This has a performance benefit since precompiled formats execute approximately twice as fast as formats that are not precompiled. These formats are used by ex_cldr_date_times . :default_currency_format determines whether Cldr.Number.to_string/2 will use :currency or :accounting if no format is specified but a currency is. The default is nil which means that the format will be derived from the locale. :providers : a list of modules that provide Cldr functionality to be compiled into the backend module. See the providers section below. :generate_docs defines whether or not to generate documentation for the modules built as part of the backend. Since these modules represent the public API for ex_cldr , the default is true . Setting this key to false (the atom false , not a falsy value) which prevent the generation of docs for this backend. :suppress_warnings defines whether warnings are logged when a provider module is configured but not available. It also controls whether warnings are logged when a number format is compiled at runtime. Its purpose is to help identify those formats which might best be added to the :precompile_number_formats configuration. The default is false . Warning are not logged when set to true . :force_locale_download determines whether to always download locale files during compilation. Locale data is ex_cldr version dependent. When a new version of ex_cldr is installed, no locales are installed and therefore locales are downloaded at compilation time as required. This ensures that the right version of the locale data is always associated with the right version of ex_cldr . However if locale data is being cached in CI/CD there is some possibility that there can be a version mismatch. Since reproducible builds are important, setting the force_locale_download: true in a backend or in global configuration adds additional certainty. The default setting is false thereby retaining compatibility with existing behaviour. The configuration can also be made dependent on mix environment as shown in this example: defmodule MyApp.Cldr do use Cldr , locales : [ &quot;en&quot; , &quot;fr&quot; ] , default_locale : &quot;en&quot; , force_locale_download : Mix . env ( ) == :prod end Providers The data maintained by CLDR is quite large and not all capabilities are required by all applications. Hence Cldr has additional optional functionality that can be provided through additional hex packages. In order to support compile-time additions to a configured backend , any package can define a provider that will be called at compile time. The currently known providers and their hex package names are: Hex Package Provider Module Comment ex_cldr_numbers Cldr.Number Formatting of numbers, currencies ex_cldr_lists Cldr.List Formatting of lists ex_cldr_units Cldr.Unit Formatting of SI and Imperial units ex_cldr_currency Cldr.Currency Currency definitions and localizations ex_cldr_territories Cldr.Territory Formatting of territory (country) data ex_cldr_languages Cldr.Language Formatting of language information ex_cldr_dates_times Cldr.DateTime Formatting of dates, times &amp; datetimes ex_cldr_locale_display Cldr.LocaleDisplay Localising locale names ex_cldr_routes Cldr.Route Localized routes and route helpers ex_money Money Operations on and formatting of a money type ex_messages Cldr.Message Formatting of ICU-formatted messages Any library author can create a provider module by exposing a function called cldr_backend_provider/1 that takes a Cldr.Config struct as a single parameter. The function should return an AST that is inserted into the backend module being compiled. Providers are configured on each backend module under the :providers key. It must be a list of provider modules. For example: defmodule MyApp.Cldr do use Cldr , locales : [ &quot;en&quot; , &quot;zh&quot; ] , default_locale : &quot;en&quot; , providers : [ Cldr.Number , Cldr.List ] end If :providers is nil (the default), Cldr will attempt to configure all of the providers described above if they have been installed as deps . If you don't wish to invoke any providers, use the empty list [] .","ref":"readme.html#configuration"},{"type":"extras","title":"Getting Started with Cldr - Migrating from Cldr 1.x","doc":"Create a backend module by following the configuration instructions Delete any duplicated global configuration in any config.exs files. Only the keys :default_locale and :json_library are supported in the global configuration Update any plugs to configure the desired backend Adjust any API calls from Cldr.some_function to MyApp.Cldr.some_function . Or better still, alias your backend module where required. ie. alias MyApp.Cldr, as: Cldr","ref":"readme.html#migrating-from-cldr-1-x"},{"type":"extras","title":"Getting Started with Cldr - Downloading Locales","doc":"Cldr can be installed from either github or from hex . If installed from github then all 571 locales are installed when the repo is cloned into your application deps. If installed from hex then only the locales &quot;en&quot;, &quot;en-001&quot; and &quot;und&quot; are installed. When you configure additional locales these will be downloaded during application compilation.","ref":"readme.html#downloading-locales"},{"type":"extras","title":"Getting Started with Cldr - Localizing Numbers","doc":"The Cldr.Number module implemented in the ex_cldr_numbers package provides number formatting. The public API for number formatting is MyApp.Cldr.Number.to_string/2 . Some examples: iex&gt; MyApp.Cldr.Number . to_string 12345 &quot;12,345&quot; iex&gt; MyApp.Cldr.Number . to_string 12345 , locale : &quot;fr&quot; &quot;12 345&quot; iex&gt; MyApp.Cldr.Number . to_string 12345 , locale : &quot;fr&quot; , currency : &quot;USD&quot; &quot;12 345,00 $US&quot; iex&gt; MyApp.Cldr.Number . to_string 12345 , format : &quot;#E0&quot; &quot;1.2345E4&quot; iex ( &gt; MyApp.Cldr.Number . to_string 1234 , format : :roman &quot;MCCXXXIV&quot; iex&gt; MyApp.Cldr.Number . to_string 1234 , format : :ordinal &quot;1,234th&quot; iex&gt; MyApp.Cldr.Number . to_string 1234 , format : :spellout &quot;one thousand two hundred thirty-four&quot; See h MyApp.Cldr.Number and h MyApp.Cldr.Number.to_string in iex for further information.","ref":"readme.html#localizing-numbers"},{"type":"extras","title":"Getting Started with Cldr - Localizing Lists","doc":"The Cldr.List module provides list formatting and is implemented in the ex_cldr_lists package. The public API for list formatting is Cldr.List.to_string/2 . Some examples: iex&gt; MyApp.Cldr.List . to_string ( [ &quot;a&quot; , &quot;b&quot; , &quot;c&quot; ] , locale : &quot;en&quot; ) &quot;a, b, and c&quot; iex&gt; MyApp.Cldr.List . to_string ( [ &quot;a&quot; , &quot;b&quot; , &quot;c&quot; ] , locale : &quot;en&quot; , format : :unit_narrow ) &quot;a b c&quot; iex&gt; MyApp.Cldr.List . to_string ( [ &quot;a&quot; , &quot;b&quot; , &quot;c&quot; ] , locale : &quot;fr&quot; ) &quot;a, b et c&quot; See h MyApp.Cldr.List and h MyApp.Cldr.List.to_string in iex for further information.","ref":"readme.html#localizing-lists"},{"type":"extras","title":"Getting Started with Cldr - Localizing Units","doc":"The Cldr.Unit module provides unit localization and is implemented in the ex_cldr_units package. The public API for unit localization is Cldr.Unit.to_string/3 . Some examples: iex&gt; MyApp.Cldr.Unit . to_string 123 , :gallon &quot;123 gallons&quot; iex&gt; MyApp.Cldr.Unit . to_string 1234 , :gallon , format : :long &quot;1 thousand gallons&quot; iex&gt; MyApp.Cldr.Unit . to_string 1234 , :gallon , format : :short &quot;1K gallons&quot; iex&gt; MyApp.Cldr.Unit . to_string 1234 , :megahertz &quot;1,234 megahertz&quot; iex&gt; MyApp.Cldr.Unit . available_units [ :acre , :acre_foot , :ampere , :arc_minute , :arc_second , :astronomical_unit , :bit , :bushel , :byte , :calorie , :carat , :celsius , :centiliter , :centimeter , :century , :cubic_centimeter , :cubic_foot , :cubic_inch , :cubic_kilometer , :cubic_meter , :cubic_mile , :cubic_yard , :cup , :cup_metric , :day , :deciliter , :decimeter , :degree , :fahrenheit , :fathom , :fluid_ounce , :foodcalorie , :foot , :furlong , :g_force , :gallon , :gallon_imperial , :generic , :gigabit , :gigabyte , :gigahertz , :gigawatt , :gram , :hectare , :hectoliter , :hectopascal , :hertz , :horsepower , :hour , :inch , ... ] See h MyApp.Cldr.Unit and h MyApp.Cldr.Unit.to_string in iex for further information.","ref":"readme.html#localizing-units"},{"type":"extras","title":"Getting Started with Cldr - Localizing Dates","doc":"Formatting of relative dates and date times is supported in the Cldr.DateTime.Relative module implemented in the ex_cldr_dates_times package. The public API is MyApp.Cldr.DateTime.to_string/2 and MyApp.Cldr.DateTime.Relative.to_string/2 . Some examples: iex&gt; MyApp.Cldr.Date . to_string Date . utc_today ( ) { :ok , &quot;Aug 18, 2017&quot; } iex&gt; MyApp.Cldr.Time . to_string Time . utc_now { :ok , &quot;11:38:55 AM&quot; } iex&gt; MyApp.Cldr.DateTime . to_string DateTime . utc_now { :ok , &quot;Aug 18, 2017, 11:39:08 AM&quot; } iex&gt; MyApp.Cldr.DateTime.Relative . to_string 1 , unit : :day , format : :narrow { :ok , &quot;tomorrow&quot; } iex&gt; MyApp.Cldr.DateTime.Relative . to_string ( 1 , unit : :day , locale : &quot;fr&quot; ) &quot;demain&quot; iex&gt; MyApp.Cldr.DateTime.Relative . to_string ( 1 , unit : :day , format : :narrow ) &quot;tomorrow&quot; iex&gt; MyApp.Cldr.DateTime.Relative . to_string ( 1234 , unit : :year ) &quot;in 1,234 years&quot; iex&gt; MyApp.Cldr.DateTime.Relative . to_string ( 1234 , unit : :year , locale : &quot;fr&quot; ) &quot;dans 1 234 ans&quot;","ref":"readme.html#localizing-dates"},{"type":"extras","title":"Getting Started with Cldr - Gettext Pluralization","doc":"gettext allows for user-defined plural forms modules to be configured for a gettext backend . To define a plural forms module that uses CLDR plural rules create a new module and then use Cldr.Gettext.Plural . For example: defmodule MyApp.Gettext.Plural do use Cldr.Gettext.Plural , cldr_backend : MyApp.Cldr end This module can then be used in the configuration of a gettext backend. For example: defmodule MyApp.Gettext do use Gettext , plural_forms : MyApp.Gettext.Plural end Note that MyApp.Gettext.Plural does not guarantee to return the same plural index as Gettext 's own pluralization engine which can introduce some compatibility issues if you plan to mix plural engines. See Cldr.Gettext.Plural for more information.","ref":"readme.html#gettext-pluralization"},{"type":"extras","title":"Getting Started with Cldr - About Language Tags","doc":"Note that ex_cldr defines locale strings according to the IETF standard as defined in RFC5646 . ex_cldr also implements the u extension as defined in RFC6067 and the t extension defined in RFC6497 . This is also the standard used by W3C . The IETF standard is slightly different to the ISO/IEC 15897 standard used by Posix-based systems; primarily in that ISO 15897 uses a &quot;_&quot; separator whereas IETF and W3C use &quot;-&quot;. Locale string are case insensitive but there are common conventions: Language codes are lower-cased Territory codes are upper-cased Script names are capital-cased All other subtags are lower-cased Sigil_l As of ex_cldr version 2.23.0, a sigil is available to simplify creating t:Cldr.LanguageTag structs. Usage is: iex&gt; import Cldr.LanguageTag.Sigil Cldr.LanguageTag.Sigil # Returns a locale that is valid and known to # the default backend module iex&gt; ~l(en-US) # Cldr.LanguageTag &lt; en - US [ validated ] &gt; # Same, but specifying the backend module # MyApp.Cldr specifically iex&gt; ~l(en-US|MyApp.Cldr) # Cldr.LanguageTag &lt; en - US [ validated ] &gt; # The `u` flag will parse and validate # the language tag but it may not be known # as a configured locale iex&gt; ~l(zh)u # Cldr.LanguageTag &lt; zh [ canonical ] &gt; # Language tags can convey a lot more information # than might be initially expected! iex&gt; ~l(en-u-ca-ethiopic-cu-aud-sd-gbsct-t-d0-lower-k0-extended-m0-ungegn-x-ux) # Cldr.LanguageTag &lt; en - t - d0 - lower - k0 - extended - m0 - ungegn - u - ca - ethiopic - cu - aud - sd - gbsct - x - ux [ validated ] &gt; Locale extensions Unicode defines the U extension which support defining the requested treatment of CLDR data formats. For example, a locale name can configure the requested: calendar to be used for dates collation currency currency format number system first day of the week 12-hour or 24-hour time time zone and many other items For example, the following locale name will request the use of the timezone Australia/Sydney , and request the use of accounting format when formatting currencies: iex&gt; MyApp.Cldr . validate_locale &quot;en-AU-u-tz-ausyd-cf-account&quot; { :ok , % Cldr.LanguageTag { canonical_locale_name : &quot;en-Latn-AU&quot; , cldr_locale_name : &quot;en-AU&quot; , extensions : %{ } , gettext_locale_name : &quot;en&quot; , language : &quot;en&quot; , language_subtags : [ ] , language_variants : nil , locale : % Cldr.LanguageTag.U { cf : :account , timezone : &quot;Australia/Sydney&quot; } , private_use : [ ] , rbnf_locale_name : &quot;en&quot; , requested_locale_name : &quot;en-AU&quot; , script : :Latn , territory : :AU , transform : %{ } } } The implementation of these extensions is governed by each library in the ex_cldr family. As of January 2020, ex_cldr_numbers version 2.10 implements the following U extension keys: cf (currency format) cu (currency) nu (number system) Other libraries in the family will progressively implement other extension keys. Notes A language code is an ISO-3166 language code. Potentially one or more modifiers separated by - (dash), not a _ . (underscore). If you configure a Gettext module then Cldr will transliterate Gettext 's _ into - for compatibility. Typically the modifier is a territory code. This is commonly a two-letter uppercase combination. For example pt-PT is the locale referring to Portuguese as used in Portugal. In ex_cldr a locale name is always a binary and never an atom . Internally a locale is parsed and stored as a t:Cldr.LanguageTag struct. The locales known to ex_cldr can be retrieved by Cldr.known_locale_names/1 to get the locales known to this configuration of ex_cldr and Cldr.all_locale_names/0 to get the locales available in the CLDR data repository.","ref":"readme.html#about-language-tags"},{"type":"extras","title":"Getting Started with Cldr - Developing ex_cldr","doc":"See the file DEVELOPMENT.md in the github repository. Testing Tests cover the full ~700 locales defined in CLDR. Since Cldr attempts to maximize the work done at compile time in order to minimize runtime execution, the compilation phase for tests is several minutes. Tests are run on Elixir 1.11 and later. ex_cldr is not supported on Elixir versions before 1.11.","ref":"readme.html#developing-ex_cldr"},{"type":"extras","title":"License","doc":"Copyright 2018-2020 Kip Cole Licensed under the Apache License, Version 2.0 (the &quot;License&quot;); you may not use this file except in compliance with the License. You may obtain a copy of the License at http :// www . apache . org / licenses / LICENSE - 2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.","ref":"license.html"},{"type":"extras","title":"Changelog","doc":"","ref":"changelog.html"},{"type":"extras","title":"Changelog - Cldr v2.37.0","doc":"This is the changelog for Cldr v2.37.0 released on April 28th, 2023. For older changelogs please consult the release tag on GitHub Note that ex_cldr version 2.33.0 and later are supported on Elixir 1.11 and later only. Bug Fixes Fixes Cldr.Locale.parent/1 to use :und as the ultimate parent rather than the default locale. This brings closer conformance to the CLDR specification . Enhancements Upgrade to CLDR 43 data. Locale data is now versioned. If a locale file is found but if has no version (data prior to this release) or a version that does not match, the appropriate locale file is downloaded. This ensures locale files and ex_cldr are kept in sync. Closes #188. Changes Cldr.version/0 to return the version of CLDR data as a Version.t/0 . This is then used to check the version of the locale data and forcing a download if the locale data is out of date for this release of ex_cldr . Adds Cldr.Locale.script_direction_from_locale/1 and MyApp.Cldr.Locale.script_direction_from_locale/1 to return :ltr (for left-to-right scripts) or :rtl (for right-to-left scripts). Closes #196. Thanks to @Doerge for the suggestion. Adds Cldr.Validity.Script.unicode_script_to_subtag/1 as public, undocumented function. This function is required by ex_cldr_person_names and may be documented in a future release. It maps between a unicode script name (like that returned by Unicode.script/1 in the unicode library) to the appropriate subtag used by CLDR. Unit data is now kept as Decimal not Ratio so :ratio is no longer a dependency here, or in ex_cldr_units .","ref":"changelog.html#cldr-v2-37-0"},{"type":"extras","title":"Changelog - Cldr v2.36.0","doc":"This is the changelog for Cldr v2.36.0 released on March 13th, 2023. For older changelogs please consult the release tag on GitHub Note that ex_cldr version 2.33.0 and later are supported on Elixir 1.11 and later only. Note that ex_cldr version 2.36.0 data for interval formats is keyed differently than that of previous releases. The bug fix noted below means that this version of ex_cldr is only compatible with ex_cldr_dates_times version 2.13.3 and later. Only ex_cldr_dates_times is affected, other ex_cldr libraries are insensitive to this change. Bug Fixes Fixes the date time interval format keys. In previous releases, the locale ingestion process would treat keys like :Hm as being the same as :hm and as a result only the lower case version would be saved. This means that locales that rely upon 0..23 or 1..24 hour formats could not be formatted correctly. Fixes the mix cldr.download.iso_currency to use the Cldr.Http.get/2 function to download the data. Doing so ensures that peer verification happens and no error log message is emitted.","ref":"changelog.html#cldr-v2-36-0"},{"type":"extras","title":"Changelog - Cldr v2.35.1","doc":"This is the changelog for Cldr v2.35.1 released on March 7th, 2023. For older changelogs please consult the release tag on GitHub Note that ex_cldr version 2.33.0 and later are supported on Elixir 1.11 and later only. Bug Fixes Fix bug that prevented setting :default_currency_format that slipped into the release (tests added).","ref":"changelog.html#cldr-v2-35-1"},{"type":"extras","title":"Changelog - Cldr v2.35.0","doc":"This is the changelog for Cldr v2.35.0 released on March 7th, 2023. For older changelogs please consult the release tag on GitHub Note that ex_cldr version 2.33.0 and later are supported on Elixir 1.11 and later only. Bug Fixes Deprecates :supress_warnings backend configuration option in favour of the correctly spelt :suppress_warnings . Enhancements Add :default_currency_format option to a backend configuration. The value must be either :currency , :accounting or nil (the default). This option is used by ex_cldr_numbers from version 2.30.0 onwards. If nil the format will be derived from the locale. No longer IO.warn/2 when Cldr.Number and Cldr.Currency are both configured as providers. A console note is still issued but it will not raise a compiler warning.","ref":"changelog.html#cldr-v2-35-0"},{"type":"extras","title":"Changelog - Cldr v2.34.2","doc":"This is the changelog for Cldr v2.34.2 released on February 25th, 2023. For older changelogs please consult the release tag on GitHub Note that ex_cldr version 2.33.0 and later are supported on Elixir 1.11 and later only. Bug Fixes Fix compatibility for CLDR-based Gettext plural backends for Gettext versions &gt;= 0.22. Notify if Cldr.Currency backend provider is configured when Cldr.Number is already configured. Cldr.Number provider already configures Cldr.Currency so a compiler warning is generated if it is explicitly configured. Thanks for @lawik for the report. Closes #194.","ref":"changelog.html#cldr-v2-34-2"},{"type":"extras","title":"Changelog - Cldr v2.34.1","doc":"This is the changelog for Cldr v2.34.1 released on January 25th, 2023. For older changelogs please consult the release tag on GitHub Note that ex_cldr version 2.33.0 and later are supported on Elixir 1.11 and later only. Bug Fixes Removes the dependencies castore and certifi since they are not required by ex_cldr (they are optional dependencies of the dependent ex_cldr_utils ). Thanks to @maennchen for the PR but deleting the dependency definitions here seems more appropriate. Closes #191.","ref":"changelog.html#cldr-v2-34-1"},{"type":"extras","title":"Changelog - Cldr v2.34.0","doc":"This is the changelog for Cldr v2.34.0 released on October 19th, 2022. For older changelogs please consult the release tag on GitHub Note that ex_cldr version 2.33.0 and later are supported on Elixir 1.11 and later only. Enhancements Encapsulates CLDR 42 data. Unless otherwise noted, all the changes are reflected in ex_cldr libraries and functions.","ref":"changelog.html#cldr-v2-34-0"},{"type":"extras","title":"Changelog - Cldr v2.33.2","doc":"This is the changelog for Cldr v2.33.2 released on August 28th, 2022. For older changelogs please consult the release tag on GitHub Note that ex_cldr version 2.33.0 and later are supported on Elixir 1.11 and later only. Bug Fixes Fixes a bug in Cldr.LanguageTag.Sigil.sigil_l/2 . With the changes in metadata structure for Elixir 14 a pattern match was failing. The pattern is now fixed and is backwards compatible with earlier Elixir versions.","ref":"changelog.html#cldr-v2-33-2"},{"type":"extras","title":"Changelog - Cldr v2.33.1","doc":"This is the changelog for Cldr v2.33.1 released on August 20th, 2022. For older changelogs please consult the release tag on GitHub Note that ex_cldr version 2.33.0 and later are supported on Elixir 1.11 and later only. Enhancements Now delegates locale installation to Cldr.Http.get/2 in the cldr_utils library so that we can centralise request handling and provide an &quot;unsafe TLS&quot; option for downloading to support resolution of #184 .","ref":"changelog.html#cldr-v2-33-1"},{"type":"extras","title":"Changelog - Cldr v2.33.0","doc":"This is the changelog for Cldr v2.33.0 released on July 31st, 2022. For older changelogs please consult the release tag on GitHub Note that ex_cldr version 2.33.0 and later are supported on Elixir 1.11 and later only. Enhancements Removes warnings for Elixir 1.14. As a result ex_cldr now supported Elixir 1.11 and later only (support for Elixir 1.10 has been discontinued). Allow either ratio 2.x or ratio 3.x depdendencies to be configured. This library is only used during the development of ex_cldr and is not normally used by library consumers. However ex_cldr_units does use ratio so this flexibility helps downstream maintenance, especially when ratio is updated to avoid Elixir 1.14 deprecation warnings.","ref":"changelog.html#cldr-v2-33-0"},{"type":"extras","title":"Changelog - Cldr v2.32.1","doc":"This is the changelog for Cldr v2.32.1 released on July 26th, 2022. For older changelogs please consult the release tag on GitHub Bug Fixes Don't use IO.warn/2 when compiling a backend and a known Gettext locale can't be matched to a Cldr locale. IO.warn/2 will cause errors if the compilation setting warnings_as_errors: true is set. Instead, these messages will be output as a &quot;note&quot; that does not trigger warnings. In addition the error message has been improved to make clear that although the Gettext locale has no Cldr equivalent, it will still be matched at runtime. See the conversation at https://elixirforum.com/t/bridging-locale-name-differences-between-ex-cldr-gettext . Thanks to @lenards for the report.","ref":"changelog.html#cldr-v2-32-1"},{"type":"extras","title":"Changelog - Cldr v2.32.0","doc":"This is the changelog for Cldr v2.32.0 released on July 23rd, 2022. For older changelogs please consult the release tag on GitHub Bug Fixes Fix Cldr.with_locale/{2, 3} to source the current locale from the backend of the supplied new locale. This reduces the chances of an exception resulting from a non-existent default backend and a default locale that is not set. Enhancements Add with_locale/2 to Cldr backend modules. This ultimately delegates to Cldr.with_locale/{2, 3}","ref":"changelog.html#cldr-v2-32-0"},{"type":"extras","title":"Changelog - Cldr v2.31.0","doc":"This is the changelog for Cldr v2.31.0 released on July 6th, 2022. For older changelogs please consult the release tag on GitHub Enhancements Adds Cldr.Locale.script_from_locale/{1, 2} and Cldr.default_script/0 .","ref":"changelog.html#cldr-v2-31-0"},{"type":"extras","title":"Changelog - Cldr v2.30.0","doc":"This is the changelog for Cldr v2.30.0 released on June 5th, 2022. For older changelogs please consult the release tag on GitHub Enhancements Adds a backend module for AcceptLanguage which defines MyApp.Cldr.AcceptLanguage.parse/1 and MyApp.Cldr.AcceptLanguage.best_match/1","ref":"changelog.html#cldr-v2-30-0"},{"type":"extras","title":"Changelog - Cldr v2.29.0","doc":"This is the changelog for Cldr v2.29.0 released on May 10th, 2022. For older changelogs please consult the release tag on GitHub Migration The plugs Cldr.Plug.SetLocale , Cldr.Plug.AcceptLanguage and Cldr.Plug.PutSession have been extracted to their own library, ex_cldr_plugs . Therefore adding {:ex_cldr_plugs, &quot;~&gt; 1.0&quot;} to the deps of any application using these plugs is required. Bug Fixes Fixes resolving the RBNF locale name for locales that inherit the RBNF locale from a parent. This is true for at least the &quot;nb&quot; locale which in previous releases had its own RBNF locale data but now inherits from &quot;no&quot;. Thanks to @juanperi for the report. Closes #175 .","ref":"changelog.html#cldr-v2-29-0"},{"type":"extras","title":"Changelog - Cldr v2.28.0","doc":"This is the changelog for Cldr v2.28.0 released on April 6th, 2022. For older changelogs please consult the release tag on GitHub Enhancements Update CLDR to release 41 . This is minor CLDR release adding en-MV , hi-Latn and ks-Deva locales and continuing data improvements on unit grammar. Changes to locales in this release can be found on the locale change page.","ref":"changelog.html#cldr-v2-28-0"},{"type":"extras","title":"Changelog - Cldr v2.27.1","doc":"This is the changelog for Cldr v2.27.1 released on March 8th, 2022. For older changelogs please consult the release tag on GitHub Bug Fixes Don't depend on CLDR production data being available at compile time in the hex package (since it won't be available at all!). Eggregious error inserted in release 2.27.0. Thanks to @dkln for the report. Closes #170.","ref":"changelog.html#cldr-v2-27-1"},{"type":"extras","title":"Changelog - Cldr v2.27.0","doc":"This is the changelog for Cldr v2.27.0 released on March 8th, 2022. For older changelogs please consult the release tag on GitHub Bug Fixes Remove spurious Cldr.Trans module. The new ex_cldr_trans provides this capability. Enhancements Add :host to the list of places that Cldr.Plug.SetLocale can look for to derive a locale for a request. Add Cldr.Locale.fallback_locale_names!/1 to return the locale fallback chain or raise an execption. Add Cldr.with_locale/2 to execute a function with the process locale set to a given locale. The current locale is put back in place after the function executes. Add Cldr.Locale.is_locale_name/1 guard. This is an area that needs some cleanup since we have Cldr.is_locale_name/1 that permits atoms and strings since it is used to guard functions that might use Cldr.validate_locale/2 . Therefore this is most useful for functions that take user input. Cldr.Locale.is_locale_name/1 that permits only atom locale names since this the canonical form.","ref":"changelog.html#cldr-v2-27-0"},{"type":"extras","title":"Changelog - Cldr v2.26.3","doc":"This is the changelog for Cldr v2.26.3 released on February 24th, 2022. For older changelogs please consult the release tag on GitHub Bug Fixes Fix spec of Cldr.put_locale/2 . Thanks to @alappe for the report. Closes #167.","ref":"changelog.html#cldr-v2-26-3"},{"type":"extras","title":"Changelog - Cldr v2.26.2","doc":"This is the changelog for Cldr v2.26.2 released on February 22nd, 2022. For older changelogs please consult the release tag on GitHub Bug Fixes Fix Cldr.Locale.canonical_language_tag/3 for cases when the :add_likely_subtags is false and the locale name is known .","ref":"changelog.html#cldr-v2-26-2"},{"type":"extras","title":"Changelog - Cldr v2.26.1","doc":"This is the changelog for Cldr v2.26.1 released on February 21st, 2022. For older changelogs please consult the release tag on GitHub Bug Fixes Fix Cldr.locale_and_backend_from/2 for atom locales. Since this is a private API there should be no upstream issues with dependent libraries.","ref":"changelog.html#cldr-v2-26-1"},{"type":"extras","title":"Changelog - Cldr v2.26.0","doc":"This is the changelog for Cldr v2.26.0 released on February 21st, 2022. For older changelogs please consult the release tag on GitHub LanguageTag structure changes Cldr.LanguageTag.t has been revised with the :cldr_locale_name and :rbnf_locale_name now being atoms rather than binaries. This is unlikely to affect client code. The primary benefit, apart from a slightly improved memory space, is the easier integration planned with the trans library. Bug Fixes Fix setting the default backend with Cldr.put_default_backend/1 which wasn't actually being set. Fix Config.message_formats to default to an empty map, not an empty list. Fix Cldr.Locale.parents/1 to return an {:ok, list} tuple on success rather than a bare list. Fix &lt;backend&gt;.Cldr.Number.{Cardinal, Ordinal, Spellout}.pluralize/3 for non-integer Decimal numbers. Enhancements Add &lt;backend&gt;.Trans module to support closer integration with the trans for database translations. Add Cldr.Locale.fallback_locales/1 to return the list of recursively created parent locales, including the provided locale. This can be used to support resolving translations from a system that might be sparsely populated. Add Cldr.Locale.fallback_locale_names/1 that returns the :cldr_locale_name component of the locales returned by Cldr.Locale.fallback_locales/1 . Adds Cldr.Locale.locale_from_territory/{1,2} to derive a &quot;best fit&quot; locale for a given territory. Also adds &lt;backend&gt;.Locale.locale_from_territory/1 . Adds Cldr.Locale.locale_from_host/{2, 3} to derive a &quot;best fit&quot; locale for a given host name. Also adds &lt;backend&gt;.Locale.locale_from_host/2 . Adds Cldr.Locale.territory_from_host/1 to return the territory for a given host name. Also adds &lt;backend&gt;.Locale.territory_from_host/1 . Adds Cldr.Locale.consider_as_tlds/0 to return a list of valid territory suffixes that are considered as generic TLDs instead. See https://developers.google.com/search/docs/advanced/crawling/managing-multi-regional-sites . Adds Cldr.Locale.languages_for_territories/0 to return a mapping of territories to that territory's most spoken language. Adds Cldr.put_gettext_locale/1 that sets the gettext locale for a given t:Cldr.LanguageTag . Adds Cldr.TestHelper module in test/suport to provide testing helpers. Initially provides with_no_default_backend/1 function.","ref":"changelog.html#cldr-v2-26-0"},{"type":"extras","title":"Changelog - Cldr v2.25.0","doc":"This is the changelog for Cldr v2.25.0 released on December 16th, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Fixes configuring locales when the default locale is in posix form (ie like en_GB ) as apposed to BCP47 form (ie en-GB ). In fixing this bug, forming the normalised list of configured locales is now also standarised. Thanks to @gazzer82 for the report. Closes #165. Enhancements Implement Cldr.Gettext.Plural allowing the creation of gettext plural forms modules.","ref":"changelog.html#cldr-v2-25-0"},{"type":"extras","title":"Changelog - Cldr v2.24.2","doc":"This is the changelog for Cldr v2.24.2 released on December 5th, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Obviate compiler warning for Code.can_await_module_compilation?/0 on Elixir versions where the function does not exist. Thanks to @DaTrader for the report. Enhancements Apply @external_resource for each configured locale in backend modules.","ref":"changelog.html#cldr-v2-24-2"},{"type":"extras","title":"Changelog - Cldr v2.24.1","doc":"This is the changelog for Cldr v2.24.1 released on November 1st, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Fix compilation performance regression when compiling ex_cldr on Elixir 1.13. ex_cldr has relied upon a private API in Elixir to detect when compilation is in progress and to then cache locale files. This improves compilation performance when many locales are configured by up to 6x. However the private API has changed in Elixir 1.13 and there is now a public API as well (hooray!). Thanks very much to @josevalim for the support as always, and for the PR that fixed the issue.","ref":"changelog.html#cldr-v2-24-1"},{"type":"extras","title":"Changelog - Cldr v2.24.0","doc":"This is the changelog for Cldr v2.24.0 released on October 27th, 2021. For older changelogs please consult the release tag on GitHub Enhancements Updated to CLDR 40 data. In addition, the canonical format of some data has changed; for example subdivisions are now atoms, not strings. This change is primarily of interest to authors writing libraries that use the raw underlying locale data. Bug Fixes Fixes an issue with the locale loader which was incorrectly atomizing date part keys in date/time formats and conversely incorrectly stringifying the number system in the same formats. Cldr.validate_territory_subdivision/1 was case sensitive and didn't correctly handle atoms and binaries. Required to support ex_cldr_territories properly. Correctly atomize the keys for the locale display names &quot;language&quot; types. Cldr.Plug.PutSession now uses the locale key :canonical_locale_name to serialize to the session. Previously it was using :cldr_locale_name which does not include any of the extension information. Extension information encodes user preferences and is required to properly support localisation. Cldr.known_territories/1 no longer includes reserved, deprecated, special use or private use territory codes. Deprecations Deprecated Cldr.Config.known_locale_names/1 in favour of Cldr.Locale.Loader.known_locale_names/1 . Deprecated Cldr.Config.known_rbnf_locale_names/1 in favour of Cldr.Locale.Loader.known_rbnf_locale_names/1 . Deprecated Cldr.Config.get_locale/2 in favour of Cldr.Locale.Loader.get_locale/2 . Deprecated the :put_session? option in Cldr.Plug.SetLocale . Use the plug Cldr.Plug.PutSession instead.","ref":"changelog.html#cldr-v2-24-0"},{"type":"extras","title":"Changelog - Cldr v2.24.0-rc.6","doc":"This is the changelog for Cldr v2.24.0-rc.6 released on October 25th, 2021. For older changelogs please consult the release tag on GitHub This is expected to be the last RC before final release on October 27th. Deprecations Deprecated Cldr.Config.known_locale_names/1 in favour of Cldr.Locale.Loader.known_locale_names/1 Deprecated Cldr.Config.known_rbnf_locale_names/1 in favour of Cldr.Locale.Loader.known_rbnf_locale_names/1","ref":"changelog.html#cldr-v2-24-0-rc-6"},{"type":"extras","title":"Changelog - Cldr v2.24.0-rc.5","doc":"This is the changelog for Cldr v2.24.0-rc.5 released on October 23rd, 2021. For older changelogs please consult the release tag on GitHub Deprecations Deprecated Cldr.Config.get_locale/2 in favour of Cldr.Locale.Loader.get_locale/2 .","ref":"changelog.html#cldr-v2-24-0-rc-5"},{"type":"extras","title":"Changelog - Cldr v2.24.0-rc.4","doc":"This is the changelog for Cldr v2.24.0-rc.4 released on October 21st, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Fixes an issue with the locale loader which was incorrectly atomizing date part keys in date/time formats and conversely incorrectly stringifying the number system in the same formats.","ref":"changelog.html#cldr-v2-24-0-rc-4"},{"type":"extras","title":"Changelog - Cldr v2.24.0-rc.3","doc":"This is the changelog for Cldr v2.24.0-rc.3 released on October 18th, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Cldr.validate_territory_subdivision/1 was case sensitive and didn't correctly handle atoms and binaries. Now fixed. Required to support ex_cldr_territories properly.","ref":"changelog.html#cldr-v2-24-0-rc-3"},{"type":"extras","title":"Changelog - Cldr v2.24.0-rc.2","doc":"This is the changelog for Cldr v2.24.0-rc.2 released on October 18th, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Correctly atomize the keys for the locale display names &quot;language&quot; types.","ref":"changelog.html#cldr-v2-24-0-rc-2"},{"type":"extras","title":"Changelog - Cldr v2.24.0-rc.1","doc":"This is the changelog for Cldr v2.24.0-rc.1 released on October 18th, 2021. For older changelogs please consult the release tag on GitHub Enhancements This release updates the CLDR 40 data to the latest pre-release (it's likely the final release data). In addition, the canonical format of some data has changed; for example subdivisions are now atoms, not strings.","ref":"changelog.html#cldr-v2-24-0-rc-1"},{"type":"extras","title":"Changelog - Cldr v2.24.0-rc.0","doc":"This is the changelog for Cldr v2.24.0-rc.0 released on October 3rd, 2021. For older changelogs please consult the release tag on GitHub There has been a significant amount of refactoring of the code that packages the locale files and the code that loads a locale. This has a very minor performance improvement at compile time but the major benefit is for maintainability. Bug Fixes Cldr.Plug.PutSession now uses the locale key :canonical_locale_name to serialize to the session. Previously it was using :cldr_locale_name which does not include any of the extension information. Extension information encodes user preferences and is required to properly support localisation. Cldr.known_territories/1 no longer includes reserved, deprecated, special use or private use territory codes. Enhancements Updates to CLDR release 40 Soft Deprecations Deprecated the :put_session? option in Cldr.Plug.SetLocale . Use the plug Cldr.Plug.PutSession instead.","ref":"changelog.html#cldr-v2-24-0-rc-0"},{"type":"extras","title":"Changelog - Cldr v2.23.2","doc":"This is the changelog for Cldr v2.23.2 released on September 8th, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Remove telemetry as a dependency. It is not required by ex_cldr . Thanks for the report from @benregn. Closes #154. Integerize all the numeric keys in calendars, including the 60 days of the Chinese calendar cycle and the 239 Japanese eras. Change from use Mix.Config to import Config for configuration. This has been the standard since Elixir 1.9 and since only Elixir 1.10 is supported, the update can be made.","ref":"changelog.html#cldr-v2-23-2"},{"type":"extras","title":"Changelog - Cldr v2.23.1","doc":"This is the changelog for Cldr v2.23.1 released on August 20th, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Fix doc errors. Thanks to @maennchen for the report. Doc errors in other ex_cldr packages are also updated. Closes #149.","ref":"changelog.html#cldr-v2-23-1"},{"type":"extras","title":"Changelog - Cldr v2.23.0","doc":"This is the changelog for Cldr v2.23.0 released on July 1st, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Corrects the formation of a canonical language tag. In previous releases, the script tag was always included as part of the canonical locale name. For example, en-US would become en-Latn-US because Latn is defined as a likely subtag of en . However TR35 specifies that if the script is the only script specified for this language then it should be omitted from the canonical name. Fixing this conformance is also a prerequisite for generating local display names. Fixes Cldr.Locale.normalize_locale_name/1 to correctly case all keys in lower case except script (capital case) and region (upper case). It will now also process arbitrary locale names. A language tag can have more than one variant and this was not correctly implemented. As a result, the t:Cldr.LanguageTag struct field variant is renamed variants and is now a list with a default of [] rather than nil . Fix a race condition which could return incorrect results for a backend known_gettext_locale_names/0 Cldr.validate_locale/2 will now return an error if the territory for a locale is unknown to CLDR. Note that Cldr.Locale.new/1,2 checks only if the territory is valid - not if it is known to CLDR. Locale inheritance no longer includes the &quot;root&quot; locale. In alignment with BCP 47 , the &quot;root&quot; locale is now longer a valid locale. Parsing a locale name &quot;root&quot; is still valid but it will return the &quot;und&quot; language instead. While parsing is still correct, it remains a locale that is not valid for use in ex_cldr . The &quot;root&quot; locale is used only for a limited set of rules-based number formats. Correct territory containment chain for the territory US . Correctly parses and validates the -t- extension of a language tag. Fixes inspecting a language tag that has a -t- extension and/or a private use ( -x- ) extension. Enhancements Add Cldr.DisplayName protocol definition to return a localised string representation of CLDR-based structs such as t:Cldr.LanguageTag , t:Cldr.Unit and t:Cldr.Currency Cldr.Locale.new/1,2 now passes all ~1600 validation tests for parsing and forming the canonical locale name. This is a prerequisite to implementing the Locale Display Algorithm in ex_cldr_locale_display . Cldr.locale_and_backend_from/1 now supports a map of options as the argument. Cldr.validate_territory/1 now correctly substitutes for known aliases. For example MyApp.Cldr.validate_locale(&quot;en-UK&quot;) will correctly return en-GB . Implement the String.Chars protocol to support Kernel.to_string/1 for t:Cldr.LanguageTag structs. Implement the Inspect protocol to support inspect/2 for t:Cldr.LanguageTag structs. Add Cldr.LanguageTag.sigil_l/2 to simplify creating t:Cldr.LanguageTag structs. Add Cldr.validate_script/1 to normalize and validate a script code (which is now in atom format as its canonical form) Pre-compiled language tags (which are stored in priv/cldr/language_tags.ebin ) are now cached during compilation resulting in a minor performance improvement in compile times. Pre-generate the rfc5646 parser which improves overall compile times. As a result the nimble_parsec dependency is marked as optional since it is no long required by library consumers.","ref":"changelog.html#cldr-v2-23-0"},{"type":"extras","title":"Changelog - Cldr v2.22.1","doc":"This is the changelog for Cldr v2.22.1 released on May 20th, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Cldr.Number.PluralRule.plural_type/2 correctly returns a plural type when no backend is provided, no default backend is configured and the locale is a t:Cldr.LanguageTag Cldr.validate_locale/1 doesn't raise if there is no default backend configured and the locale is a t:Cldr.LanguageTag","ref":"changelog.html#cldr-v2-22-1"},{"type":"extras","title":"Changelog - Cldr v2.22.0","doc":"This is the changelog for Cldr v2.22.0 released on May 20th, 2021. For older changelogs please consult the release tag on GitHub Soft deprecation The plug Cldr.Plug.SetSession was introduced in ex_cldr version 2.21.0. However the convention in Phoenix and Plug is put , not set . The plug is renamed to Cldr.Plug.PutSession . Cldr.Plug.SetSession is still available but will emit a deprecation notice and will delegatge to Cldr.Plug.PutSession. Apologies to all for the sloppy release review process. Bug Fixes Fix typespec of Cldr.AcceptLanguage.best_match/2. Thanks to @adriankumpf. Enhancements Make log level for &quot;no match&quot; errors in Cldr.Plug.AcceptLanguage configurable.","ref":"changelog.html#cldr-v2-22-0"},{"type":"extras","title":"Changelog - Cldr v2.21.0","doc":"This is the changelog for Cldr v2.21.0 released on May 17th, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Correctly pluralize numbers where the plural rule has an explicit case for the given number. When pluralizing numbers, plural rules will return a value such as :one , :two , :few , :many which is used as a key into a map of substitutions. However it is also possible to have substitutions based upon the explicit value of a number, rather than its plural type. Previously this last rule was not being applied but now is. For the purposes of pluralization, 1.0 and 1 are considered the same - plural rules use the integer representation so a float is cast to an integer when they are both equal according to == . Correctly pluralize Decimal numbers (in addition to integer and float) Enhancements Add --force-locale-download option to mix cldr.install.locales . Plug.SetLocale default keys for locale discovery from an HTTP request are now expanded to be [:session, :accept_language, :query, :path] . The :session_key option to Cldr.Plug.SetLocale is deprecated. A well-known session key is required in order to support setting the locale from the session passed to mount/3 for liveview applications. The session key is available as Cldr.Plug.SetLocale.session_key/0 Adds Cldr.Plug.SetSession that will copy the cldr locale name from the conn and put it in the session. This simplifies the lifecycle of a typical HTTP request and ensures that the locale is readily available in liveviews as well.","ref":"changelog.html#cldr-v2-21-0"},{"type":"extras","title":"Changelog - Cldr v2.20.0","doc":"This is the changelog for Cldr v2.20.0 released on April 8th, 2021. For older changelogs please consult the release tag on GitHub Enhancements Updates to CLDR version 39 data. Add Cldr.Locale.parent/1 to return the parent locale according. This is not exactly the same as the CLDR locale inheritance rules Add Cldr.Locale.parents/2 to return a list of parents up to and including the root locale. It is a recursive use of Cldr.Locale.parent/1 . Add locale display name data to the locale files. This data can be used to format a locale for UI usage. Add subdivision translations to the locale files. This data can be used to format subdivision names for UI usage. Thanks to @mskv. Closes #144. Add grammatical features to the repository. This data is used in ex_cldr_units . See also Cldr.Config.grammatical_features/0 . Add grammatical gender to the repository. This data is used in ex_cldr_units . See also Cldr.Config.grammatical_gender/0 . Make Cldr.Locale.first_match/2 a public function. This function is useful for other CLDR-based libraries to help resolve the files of localised content in CLDR. Add :add_fallback_locales to the backend configuration. When true , the fallback locales of the configured backend locales is also added to the configuration. The default is false and therefore by default there is no change to behaviour from previous releases. Setting this option to true enables means that data that is stored in parent locales rather than child locales can be processed. This applies particularly to rules-based number formats and subdivision data. These data aren't stored in all locales - generally they are stored in the base language locale. Add Cldr.Config.fallback_chain/1 which takes a locale name and returns a list of locales from which this locale inherits up to but not including the root locale. Add Cldr.Config.fallback/1 which takes a locale name and returns the direct parent of the locale name. Rename alias key subdivisionAlias to subdivision Fix Cldr.Substitution.substitute/2 when the template has no substitutions. Thanks to @jarrodmoldrich. Closes ex_cldr_units #20 .","ref":"changelog.html#cldr-v2-20-0"},{"type":"extras","title":"Changelog - Cldr v2.20.0-rc.3","doc":"This is the changelog for Cldr v2.20.0-rc.3 released on April 7th, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Fix Cldr.Substitution.substitute/2 when the template has no substitutions. Thanks to @jarrodmoldrich. Closes ex_cldr_units #20 .","ref":"changelog.html#cldr-v2-20-0-rc-3"},{"type":"extras","title":"Changelog - Cldr v2.20.0-rc.2","doc":"This is the changelog for Cldr v2.20.0-rc.2 released on March 22nd, 2021. For older changelogs please consult the release tag on GitHub Enhancements Add :add_fallback_locales to the backend configuration. When true , the fallback locales of the configured backend locales is also added to the configuration. The default is false and therefore by default there is no change to behaviour from previous releases. Setting this option to true enables means that data that is stored in parent locales rather than child locales can be processed. This applies particularly to rules-based number formats and subdivision data. These data aren't stored in all locales - generally they are stored in the base language locale. Add Cldr.Config.fallback_chain/1 which takes a locale name and returns a list of locales from which this locale inherits up to but not including the root locale. Add Cldr.Config.fallback/1 which takes a locale name and returns the direct parent of the locale name. Rename alias key subdivisionAlias to subdivision","ref":"changelog.html#cldr-v2-20-0-rc-2"},{"type":"extras","title":"Changelog - Cldr v2.20.0-rc.1","doc":"This is the changelog for Cldr v2.20.0-rc.1 released on March 22nd, 2021. For older changelogs please consult the release tag on GitHub Enhancements Make Cldr.Locale.first_match/2 a public function. This function is useful for other CLDR-based libraries to help resolve the files of localised content in CLDR.","ref":"changelog.html#cldr-v2-20-0-rc-1"},{"type":"extras","title":"Changelog - Cldr v2.20.0-rc.0","doc":"This is the changelog for Cldr v2.20.0-rc.0 released on March 19th, 2021. For older changelogs please consult the release tag on GitHub Enhancements Updates to CLDR version 39 data. Add Cldr.Locale.parent/1 to return the parent locale according. This is not exactly the same as the CLDR locale inheritance rules Add Cldr.Locale.parents/2 to return a list of parents up to and including the root locale. It is a recursive use of Cldr.Locale.parent/1 . Add locale display name data to the locale files. This data can be used to format a locale for UI usage. Add subdivision translations to the locale files. This data can be used to format subdivision names for UI usage. Thanks to @mskv. Closes #144. Add grammatical features to the repository. This data is used in ex_cldr_units . See also Cldr.Config.grammatical_features/0 . Add grammatical gender to the repository. This data is used in ex_cldr_units . See also Cldr.Config.grammatical_gender/0 .","ref":"changelog.html#cldr-v2-20-0-rc-0"},{"type":"extras","title":"Changelog - Cldr v2.19.1","doc":"This is the changelog for Cldr v2.19.1 released on April 7th. For older changelogs please consult the release tag on GitHub Enhancements Fix Cldr.Substitution.substitute/2 when the template has no substitutions. Thanks to @jarrodmoldrich. Closes ex_cldr_units #20 .","ref":"changelog.html#cldr-v2-19-1"},{"type":"extras","title":"Changelog - Cldr v2.19.0","doc":"This is the changelog for Cldr v2.19.0 released on February 6th, 2021. For older changelogs please consult the release tag on GitHub Breaking change A parsed language tag would previously turn the tz parameter of the u extension into a timezone ID. For example, the language tag en-AU-u-tz-ausyd would decode ausyd into Australia/Sydney . From this release, parsing no longer decodes the tz parameter since doing so means that to_string/1 does not work correctly. Use Cldr.Locale.timezone_from_locale/1 instead. Enhancements Updates to CLDR 38.1 Includes the display name and where available the gender for units in the locale data to support generating UI elements in the upcoming version 3.4.0 of ex_cldr_units Add Cldr.Locale.timezone_from_locale/{1,2} to extract a timezone ID from a language tag Add option :format to Cldr.ellipsis/2 . This option is either :word or :sentence . :sentence is the default. Using the locale en as an example, the differences in formatting are: # Default style: :sentence iex&gt; Cldr . ellipsis &quot;And furthermore&quot; &quot;And furthermore…&quot; iex&gt; Cldr . ellipsis [ &quot;And furthermore&quot; , &quot;there is much to be done&quot; ] , locale : &quot;ja&quot; &quot;And furthermore…there is much to be done&quot; # With style: :word iex&gt; Cldr . ellipsis &quot;And furthermore&quot; , style : :word &quot;And furthermore …&quot; iex&gt; Cldr . ellipsis [ &quot;And furthermore&quot; , &quot;there is much to be done&quot; ] , locale : &quot;ja&quot; , format : :word &quot;And furthermore … there is much to be done&quot;","ref":"changelog.html#cldr-v2-19-0"},{"type":"extras","title":"Changelog - Cldr v2.18.2","doc":"This is the changelog for Cldr v2.18.2 released on November 9th, 2020. For older changelogs please consult the release tag on GitHub Enhancements Add Cldr.Locale.territory_from_locale/1 for string language tags","ref":"changelog.html#cldr-v2-18-2"},{"type":"extras","title":"Changelog - Cldr v2.18.1","doc":"This is the changelog for Cldr v2.18.1 released on November 7th, 2020. For older changelogs please consult the release tag on GitHub Enhancements Add &lt;backend&gt;.Locale.territory_from_locale/1 Bug Fixes Fixes Cldr.LanguageTag.to_string/1 when the u extenion is empty. Closes #140. Thanks to @Zurga.","ref":"changelog.html#cldr-v2-18-1"},{"type":"extras","title":"Changelog - Cldr v2.18.0","doc":"This is the changelog for Cldr v2.18.0 released on November 1st, 2020. For older changelogs please consult the release tag on GitHub Enhancements Update to CLDR 38 Removed the mix cldr.compile mix task (it was deprecated several releases ago) Removed the mix cldr.download.core_data mix task since the current development process does not require it. The script ldml2json now rebuilds to tools on each run and instead of hardcoded environment variables it uses existing ones if set and only applies defaults if required. This is applicable only to ex_cldr developers and maintainers. Warn on duplicate providers being configured for a backend and then ignore the duplicates. Omit stacktrace when warning about use of the global configuration Deprecate Cldr.default_backend/0 in favour of Cldr.default_backend!/0 which more clearly expresses that the function will raise if no default backend is configured. Changes the behaviour of Cldr.put_locale/{1, 2} . In previous releases the intent was that a process would store a locale for a given backend. Logically however, it is more appropriate to store a locale on a per-process basis, not per backend per process. The backend is an important asset, but only insofaras it hosts locale-specific content. Therefore in this release, Cldr.put_locale/{1, 2} always stores the locale on a per-process basis and there is only one locale, not one specialised per backend. This also simplifies Cldr.get_locale/0 which now returns the process's locale or the default locale. Support plural categories of &quot;compact decimals&quot;. These are represented as {number, formatting_exponent} . See TR35 for more information. This notation is only supported for Cldr.Number.PluralRule.plural_type/2 . In CLDR version 38 only the locale &quot;fr&quot; includes rules that differ for some compact formats. For example: # For all locales except &quot;fr&quot; the plural type is the same # for all exponents iex&gt; Cldr.Number.PluralRule . plural_type { 1234567 , 3 } , locale : &quot;en&quot; :other iex&gt; Cldr.Number.PluralRule . plural_type { 1234567 , 6 } , locale : &quot;en&quot; :other # For &quot;fr&quot;, compact formats pluralize differently in some cases iex&gt; Cldr.Number.PluralRule . plural_type { 1234567 , 3 } , locale : &quot;fr&quot; :other iex&gt; Cldr.Number.PluralRule . plural_type { 1234567 , 6 } , locale : &quot;fr&quot; :many","ref":"changelog.html#cldr-v2-18-0"},{"type":"extras","title":"Changelog - Cldr v2.17.2","doc":"This is the changelog for Cldr v2.17.2 released on September 30th, 2020. For older changelogs please consult the release tag on GitHub Bug Fixes When configuring a Cldr backend, warn then omit any Gettext locales configured that aren't actually available in CLDR. Thanks to @mikl. Closes #138.","ref":"changelog.html#cldr-v2-17-2"},{"type":"extras","title":"Changelog - Cldr v2.17.1","doc":"This is the changelog for Cldr v2.17.1 released on September 26th, 2020. For older changelogs please consult the release tag on GitHub Bug Fixes Significantly improve the performance of Cldr.default_locale/0 . In previously releases, the default locale was being parsed on each access. In this release it is parsed once and cached in the application environment. This improves performance by about 40x. Thanks to @Phillipp who brought this to attention in Elixir Forum","ref":"changelog.html#cldr-v2-17-1"},{"type":"extras","title":"Changelog - Cldr v2.17.0","doc":"This is the changelog for Cldr v2.17.0 released on September 8th, 2020. For older changelogs please consult the release tag on GitHub Enhancements Support Decimal version ~&gt; 1.6 and ~&gt; 2.0 Bug Fixes Corrects Cldr.Plug.SetLocale testing for body parameters. Previous version of Plug would parse body parameters for an HTTP get verb which is not standard behaviour. The test now uses the HTTP put verb where body parameters are expected to be parsed. Corrects internal links to the readme.","ref":"changelog.html#cldr-v2-17-0"},{"type":"extras","title":"Changelog - Cldr v2.16.2","doc":"This is the changelog for Cldr v2.16.2 released on August 29th, 2020. For older changelogs please consult the release tag on GitHub Bug Fixes Fix compiler warning for Elixir 1.11 when calling a remote function that is based upon a module name that is a variable.","ref":"changelog.html#cldr-v2-16-2"},{"type":"extras","title":"Changelog - Cldr v2.16.1","doc":"This is the changelog for Cldr v2.16.1 released on June 7th, 2020. For older changelogs please consult the release tag on GitHub Bug Fixes Do not send Connection: close header when downloading locales. Do not convert charlist data from :httpc before saving it as a locale file. Fixes an issue whereby the saved locale file is shorter than expected due to an extraneous use of :erlang.list_to_binary/1 which is not UTF8 friendly. Thanks to @halostatue for the patience and persistence working this issue through on a weekend. Fixes #137.","ref":"changelog.html#cldr-v2-16-1"},{"type":"extras","title":"Changelog - Cldr v2.16.1-rc.0","doc":"This is the changelog for Cldr v2.16.1-rc.0 released on June 7th, 2020. For older changelogs please consult the release tag on GitHub Bug Fixes Do not send Connection: close header when downloading locales. Do not convert charlist data from :httpc before saving it as a locale file. Probably fixes an issue whereby the saved locale file is shorter than expected.","ref":"changelog.html#cldr-v2-16-1-rc-0"},{"type":"extras","title":"Changelog - Cldr v2.16.0","doc":"This is the changelog for Cldr v2.16.0 released on June 6th, 2020. For older changelogs please consult the release tag on GitHub Enhancements Add configuration key :force_locale_download for backend and the global configuration. Locale data is ex_cldr version dependent. When a new version of ex_cldr is installed, no locales are installed and therefore locales are downloaded at compilation time as required. This ensures that the right version of the locale data is always associated with the right version of ex_cldr . However: If locale data is being cached in CI/CD there is some possibility that there can be a version mismatch. Since reproducible builds are important, using the force_locale_download: true in a backend or in global configuration adds additional certainty. The default setting is false thereby retaining compatibility with existing behaviour. The configuration can also be made dependent on mix environment as shown in this example: defmodule MyApp.Cldr do use Cldr , locales : [ &quot;en&quot; , &quot;fr&quot; ] , default_locale : &quot;en&quot; , force_locale_download : Mix . env ( ) == :prod Bug Fixes Validate configured locales in a backend case insensitively and with either BCP 47 or Poxix (&quot;-&quot; or &quot;_&quot;) separators.","ref":"changelog.html#cldr-v2-16-0"},{"type":"extras","title":"Changelog - Cldr v2.15.0","doc":"This is the changelog for Cldr v2.15.0 released on May 27th, 2020. For older changelogs please consult the release tag on GitHub Starting with ex_cldr the development process now requires the CLDR repository be cloned to the development machine; that the CLDR json data is generated on that machine and the shell variable CLDR_PRODUCTION_DATA must be set to the directory where the generated json data is stored. For more information on the development process for ex_cldr consult DEVELOPMENT.md This change is relevant only to the developers of ex_cldr . It is not applicable to users of the library. Enhancements Adds data to support lenient parsing of dates and numbers","ref":"changelog.html#cldr-v2-15-0"},{"type":"extras","title":"Changelog - Cldr v2.14.1","doc":"This is the changelog for Cldr v2.14.1 released on May 15th, 2020. For older changelogs please consult the release tag on GitHub Bug Fixes Fix compilation order for backends configured in Cldr.Plug.SetLocale . Thanks to @syfgkjasdkn. Closes #135.","ref":"changelog.html#cldr-v2-14-1"},{"type":"extras","title":"Changelog - Cldr v2.14.0","doc":"This is the changelog for Cldr v2.14.0 released on May 2nd, 2020. For older changelogs please consult the release tag on GitHub The primary purpose of this release is to support the new data for units that standardize a means for conversion. In addition, some data file names are changed to be more consistent in naming. Summary Updates the data source to CLDR release 37 . Require that a certificate trust store be configured in order to download locales. A system trust store will be automatically detected in many situations. In other cases configuring castore or certifi will be automatically detected. A specific trust store can be configured under the :cacertfile key of the :ex_cldr configuration in config.exs . Note that on Windows either castore , certifi or a configured trust store will be required. Add Cldr.put_default_locale/{1, 2} to set the system-wide default locale. The removes the need to configure a default locale in config.exs in keeping with modern Elixir app configuration strategies. Adds the Cldr.Chars protocol and the Cldr.to_string/1 function intended to be a drop-in replacement for Kernel.to_string/1 to make it easier to develop localised applications. Add the new data Units introduced in CLDR version 37 . This data is used in an updated ex_cldr_units package. The plugs Cldr.Plug.AcceptLanguage and Cldr.Plug.SetLocale no longer require a backend be configured. The Cldr.default_backend/0 will be used if no specific backend is configured. Add territory subdivisions. The are a geographic level below territory and typically represent states/provinces of a country. In some cases large cities or counties are also known. Add calendar preferences. Cldr.Config.calendar_preferences/0 returns the map of territory to the desired calendar list in descending order or preference. Add &quot;yue&quot; locale now that the data is complete in CLDR 37. There are now 566 locales up from 541 in CLDR 36. See the release notes for further information. Breaking changes (that you should not notice) Although these are breaking changes, they are changes that affect functions in Cldr.Config which is considered a private module and therefore client applications are not expected to be impacted. Minimal supported version of Elixir is 1.6 (it was 1.5) Adds Cldr.LanguageTag.U to formalise the structure of the BCP47 U extension. This changes the data format of a LanguageTag that has a U extension. Additionally, most fields of this struct are now atoms, not binaries. Adds Cldr.LanguageTag.T to formalise the structure of the BCP47 T extension. This changes the data format of a LanguageTag that has a T extension. Rename Cldr.Config.calendar_data/0 to Cldr.Config.calendars/0 Rename Cldr.Config.territory_info/0 to Cldr.Config.territories/0 Rename Cldr.Config.territory_info/1 to Cldr.Config.territory/1 Rename Cldr.Config.week_data/0 to Cldr.Config.weeks/0 Rename Cldr.Config.territory_containment/0 to Cldr.Config.territory_containers/0 Remove priv/cldr/measurement_system_preferences.json . This data is returned in Cldr.Config.territories/0 Use canonical measurement system names throughout. This changes some data returned by Cldr.Config.territory/0 and Cldr.Config.measurement_system_preferences/0 Rename priv/cldr/week_data.json to priv/cldr/weeks.json Rename priv/cldr/calendar_data.json to priv/cldr/calendars.json Rename priv/cldr/territory_info.json to priv/cldr/territories.json Bug Fixes Correct the preferred measurement system for temperature in some territories (including the US) Enhancements Require that a certificate trust store be configured in order to download locales Add the Cldr.Chars protocol which defines to_string/1 and it invoked from Cldr.to_string/1 . It is intended as a drop-in replacement for Kernel.to_string/1 excepting that it produces localised output. Then intent is to continue making it easier for developers to build localised applications. The plug Cldr.Plug.AcceptLanguage no longer requires that a backend be configured. The backend returned by Cldr.default_backend/0 will be used by default. The plug Cldr.Plug.SetLocale no longer requires that a backend be configured. The backend returned by Cldr.default_backend/0 will be used by default. t:Cldr.LanguageTag.t now includes a :backend field which is populated during parsing. This allows the implementation of the Cldr.Chars protocol. CLDR has introduced unit conversion data. This data is now packaged as Cldr.Config.units/0 which is used for ex_cldr_units version 3.0 Unit Preferences now consistently use underscore in names and values instead of dashes. Add Cldr.validate_backend/1 to validate if a module is a CLDR backend module Add Cldr.validate_measurement_system/1 to validate a measurement system name Add Cldr.Config.measurement_systems/0 to return a map of known measurement systems Add Cldr.Config.time_preferences/0 to return a map of time preferences for a given locale or territory. This data is used in ex_cldr_dates_times from version 2.4 Add Cldr.Config.territory_containment/0 that returns a map of territories to a list of lists of the territories in which it is contained. A territory may be contained by more than one list of containers. For example, :GB is contained like this: [[:&quot;154&quot;, :&quot;150&quot;, :&quot;001&quot;], [:UN], [:EU]] . Add Cldr.known_territory_subdivisons/0 to return a map of regions and subdivisions and their children Add Cldr.known_territory_subdivision_containment/0 to return a map of subdivisions and their parents Add priv/cldr/units.json which contains the new unit data and conversion information from CLDR 37 Add priv/cldr/measurement_systems.json Add Cldr.validate_backend/1 to confirm a backend modules existence and that it includes use Cldr Add Cldr.Locale.territory_from_locale/1 to determine the territory to be used for localization. Add Cldr.Config.calendar_preferences/0 Add Cldr.the_world/0 that returns the territory code for the world which is :001","ref":"changelog.html#cldr-v2-14-0"},{"type":"extras","title":"Changelog - Cldr v2.13.0","doc":"This is the changelog for Cldr v2.13.0 released on January 19th, 2020. For older changelogs please consult the release tag on GitHub Enhancements Removes the runtime dependency on Jason since the RFC5646 parser is now inlined. Closes #99 Adds Cldr.Timezone to support timezone mapping for language tags using the tz key of the u extension to the Unicode locale identifier When parsing a locale with a u extension containing a cf (currency format) key, the key is transformed to the standard :currency or :accounting atoms rather than being left as strings.","ref":"changelog.html#cldr-v2-13-0"},{"type":"extras","title":"Changelog - Cldr v2.12.1","doc":"This is the changelog for Cldr v2.12.1 released on January 14th, 2020. For older changelogs please consult the release tag on GitHub Bug Fixes Remove two lingering dialyzer errors-that-aren't-really-errors so its passes cleanly.","ref":"changelog.html#cldr-v2-12-1"},{"type":"extras","title":"Changelog - Cldr v2.12.0","doc":"This is the changelog for Cldr v2.12.0 released on January 2nd, 2020. For older changelogs please consult the release tag on GitHub Enhancements Remove use of Code.ensure_compiled?/1 since its deprecated in Elixir 1.10. A new function Cldr.Config.ensure_compiled?/1 is introduced but marked as @doc false . Adds mix cldr.download.plural_ranges to automate the downloading, extracting and saving of pluralRanges.xml from CLDR. Update copyright dates in LICENSE.md","ref":"changelog.html#cldr-v2-12-0"},{"type":"extras","title":"Changelog - Cldr v2.11.1","doc":"This is the changelog for Cldr v2.11.1 released on October 20th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Validate session-based locale in Cldr.Plug.SetLocale . Closes #131. Thanks for @Ray-Wang.","ref":"changelog.html#cldr-v2-11-1"},{"type":"extras","title":"Changelog - Cldr v2.11.0","doc":"This is the changelog for Cldr v2.11.0 released on October 10th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Update to CLDR data version 36.0.0.","ref":"changelog.html#cldr-v2-11-0"},{"type":"extras","title":"Changelog - Cldr v2.10.2","doc":"This is the changelog for Cldr v2.10.2 released on September 7th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Use Keyword.get_lazy/3 when retrieving Cldr.default_backend/0 to avoid exceptions when no default backend is configured. Cldr.Number.PluralRule.plural_type/2 has become Cldr.Number.PluralRule.plural_type/3 to better align with other functions that typically use argument, backend, options as their parameters. No user code change is expected as the function heads remain compatible.","ref":"changelog.html#cldr-v2-10-2"},{"type":"extras","title":"Changelog - Cldr v2.10.1","doc":"This is the changelog for Cldr v2.10.1 released on August 25th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Fix error in the generation of unit preference data","ref":"changelog.html#cldr-v2-10-1"},{"type":"extras","title":"Changelog - Cldr v2.10.0","doc":"This is the changelog for Cldr v2.10.0 released on August August 25th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Adds unit preference data. This data is used by ex_cldr_units version 2.6 and later to allow localization of units into the preferred units for a given locale or territory.","ref":"changelog.html#cldr-v2-10-0"},{"type":"extras","title":"Changelog - Cldr v2.9.0","doc":"This is the changelog for Cldr v2.9.0 released on August August 24th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Includes the compound unit fields from units in the generated locale data. This enables formatting of compound units, like the &quot;per&quot; form which is used when there is no predefined unit style. This functionality is enabled in ex_cldr_units version 2.6. Add Cldr.quote/3 and MyApp.Cldr.quote/2 that add locale-specific quotation marks around a string. The locale data files are updated to include this information. Add Cldr.ellipsis/3 and MyApp.Cldr.ellipsis/2 that add locale-specific ellipsis' to a string. The locale data files are updated to include this information. Add Cldr.Config.measurement_system/0 that returns a mapping between a territory and a measurement system (ie does a territory/country use the metric, US or UK system)","ref":"changelog.html#cldr-v2-9-0"},{"type":"extras","title":"Changelog - Cldr v2.8.1","doc":"This is the changelog for Cldr v2.8.1 released on August 23rd, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Fix the @spec for Cldr.Substitution.substitute/2","ref":"changelog.html#cldr-v2-8-1"},{"type":"extras","title":"Changelog - Cldr v2.8.0","doc":"This is the changelog for Cldr v2.8.0 released on August 21st, 2019. For older changelogs please consult the release tag on GitHub Enhancements Adds Cldr.validate_plural_type/1 which will validate if a plural type is one those returned by Cldr.Number.PluralRule.known_plural_types/0 which is also added. These functions are added to support message formatting in the forthcoming ex_cldr_messages package. Adds Cldr.Number.PluralRule.plural_type/2 which returns the plural type for a number. Adds message_formats backend configuration key. This is used by ex_cldr_messages to define custom formats for messages. Bug Fixes Add @spec to parser combinators to remove dialyzer warnings. Ensure that you are using nimble_parsec version 0.5.1 or later if running dialyzer checks.","ref":"changelog.html#cldr-v2-8-0"},{"type":"extras","title":"Changelog - Cldr v2.7.2","doc":"This is the changelog for Cldr v2.7.2 released on June 14th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Fixes a bug whereby a Gettext backend module may not be compiled at the time that the Cldr backend is being compiled. This can cause compilation errors and may cause the wrong assembly of configured locales. Closes #124. Thanks very much to @erikreedstrom and @epilgrim. Fixes a bug whereby a Cldr backend may not be recognised during compilation of Cldr.Plug.SetLocale . Similar issue to #124. Thanks for @AdrianRibao for the report.","ref":"changelog.html#cldr-v2-7-2"},{"type":"extras","title":"Changelog - Cldr v2.7.1","doc":"This is the changelog for Cldr v2.7.1 released on June 2nd, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Fix Cldr.known_number_systems/0 by removing the call to Config.known_number_systems/0 which decodes json on each call and use Cldr.known_number_systems/0 which does not.","ref":"changelog.html#cldr-v2-7-1"},{"type":"extras","title":"Changelog - Cldr v2.7.0","doc":"This is the changelog for Cldr v2.7.0 released on April 22nd, 2019. For older changelogs please consult the release tag on GitHub Enhancements Updates to CLDR version 35.1.0 which is primarily related to the change of Japanese era with the ascension of a new emperor on April 1st.","ref":"changelog.html#cldr-v2-7-0"},{"type":"extras","title":"Changelog - Cldr v2.6.2","doc":"This is the changelog for Cldr v2.6.2 released on April 16th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Adds Cldr.flag/1 that returns a binary unicode grapheme representing a flag for a given territory The parameters provided to Cldr.Plug.SetLocale.init/1 are now conformed more precisely based upon the provided options. This ensures that the keys :cldr and :gettext are set from other options if they are not provided directly. Bug Fixes Cldr.Plug.SetLocale.init/1 would raise an exception if no :gettext key was specified. This is now corrected.","ref":"changelog.html#cldr-v2-6-2"},{"type":"extras","title":"Changelog - Cldr v2.6.1","doc":"This is the changelog for Cldr v2.6.1 released on April 13th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Correctly resolves the :data_dir param for a backend module. Thanks to @erikreedstrom for the report. Closes #123. Raises if a backend module configures an :otp_app that is not known","ref":"changelog.html#cldr-v2-6-1"},{"type":"extras","title":"Changelog - Cldr v2.6.0","doc":"This is the changelog for Cldr v2.6.0 released on March 28th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Updates to CLDR version 35.0.0 released on March 27th 2019. There is one unresolved issue in this implementation related to plural rules for the locale &quot;kw&quot; (Cornish). The plural rule definition for :other in the repository is: &quot;pluralRule-count-other&quot; : &quot; @integer 4~19, 100, 1000000, … @decimal 0.1~0.9, 1.1~1.7, 10.0, 100.0, 1000.0 100000.0 1000000.0, …&quot; , However in rules testing, the values 1000.0 , 10000.0 and 100000.0 are resolving to category :two rather than :other . Until this is resolved, these data points are removed from the test data.","ref":"changelog.html#cldr-v2-6-0"},{"type":"extras","title":"Changelog - Cldr v2.5.0","doc":"This is the changelog for Cldr v2.5.0 released on March 23rd, 2019. For older changelogs please consult the release tag on GitHub Enhancements Adds the global :ex_cldr configuration key :default_backend . Adds Cldr.default_backend/0 which will return the configured default backend or will raise an exception if not is configured. Where appropriate, Cldr.* will now use Cldr.default_backend() as a default parameter.","ref":"changelog.html#cldr-v2-5-0"},{"type":"extras","title":"Changelog - Cldr v2.4.3","doc":"This is the changelog for Cldr v2.4.3 released on March 20th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Fix Cldr.validate_locale/1 @spec error and remove spurious @dialyzer directives","ref":"changelog.html#cldr-v2-4-3"},{"type":"extras","title":"Changelog - Cldr v2.4.2","doc":"This is the changelog for Cldr v2.4.2 released on March 15th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Exclude Cldr.Currency from the list of known providers so that it won't be compiled twice when working with ex_cldr_numbers .","ref":"changelog.html#cldr-v2-4-2"},{"type":"extras","title":"Changelog - Cldr v2.4.1","doc":"This is the changelog for Cldr v2.4.1 released on March 14th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Makes generation of documentation for backend modules optional. This is implemented by the :generate_docs option to the backend configuration. The default is true . For example: defmodule MyApp.Cldr do use Cldr , default_locale : &quot;en-001&quot; , locales : [ &quot;en&quot; , &quot;ja&quot; ] , gettext : MyApp.Gettext , generate_docs : false end","ref":"changelog.html#cldr-v2-4-1"},{"type":"extras","title":"Changelog - Cldr v2.4.0","doc":"This is the changelog for Cldr v2.4.0 released on March 10th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Minor restructuring of the locale files. Calendar map keys are harmonised to have the same names and meanings. This would not normally be user visible but a change in data format suggests a minor version bump to easy version management. Restructure the data returned by Cldr.Config.week_info/0 to also encode week days as numbers in the range 1..7 where 1 is Monday.","ref":"changelog.html#cldr-v2-4-0"},{"type":"extras","title":"Changelog - Cldr v2.3.2","doc":"This is the changelog for Cldr v2.3.2 released on March 8th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Does a better job of detecting a required JSON library and raising at compile time if no such library can be found. In order of priority the search for a JSON library is: the key :json_library under the application key :ex_cldr a configured Phoenix json_library a configured Ecto json_library Jason if configured Poison if configured","ref":"changelog.html#cldr-v2-3-2"},{"type":"extras","title":"Changelog - Cldr v2.3.1","doc":"This is the changelog for Cldr v2.3.1 released on March 6th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Fix dialyzer errors. In some cases, notably related to nimble_parsec , errors are generated that need to be fixed in a dependency. These errors are added to the .dialyzer_ignore_warnings file for now.","ref":"changelog.html#cldr-v2-3-1"},{"type":"extras","title":"Changelog - Cldr v2.3.0","doc":"This is the changelog for Cldr v2.3.0 released on March 4th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Adds Cldr.LanguageTag.to_string/1 which converts a Cldr.LanguageTag{} into a language tag string. This is useful when creating a collator that is based upon libicu since that collator will apply the configuration specified by the u extension in the language tag. For example: iex&gt; { :ok , locale } = Cldr . validate_locale &quot;en-US-u-co-phonebk-nu-arab&quot; , MyApp.Cldr iex&gt; Cldr.LanguageTag . to_string ( locale ) &quot;en-Latn-US-u-ca-phonebk-nu-arab&quot; Bug Fixes Fix a bug when parsing some locale strings which have extensions. An extension may have a list of &quot;keyword-type&quot; pairs or simply &quot;keyword&quot;. Parsing was failing when only the &quot;keyword&quot; form was used. For example the following used to fail, but is now parsed correctly: iex&gt; { :ok , locale } = Cldr . validate_locale &quot;en-US-u-co-ca&quot; , MyApp.Cldr { :ok , % Cldr.LanguageTag { canonical_locale_name : &quot;en-Latn-US&quot; , cldr_locale_name : &quot;en&quot; , extensions : %{ } , gettext_locale_name : nil , language : &quot;en&quot; , language_subtags : [ ] , language_variant : nil , locale : %{ calendar : &quot;gregory&quot; , collation : &quot;standard&quot; } , private_use : [ ] , rbnf_locale_name : &quot;en&quot; , requested_locale_name : &quot;en-US&quot; , script : &quot;Latn&quot; , territory : &quot;US&quot; , transform : %{ } } } Fix a race condition when starting up the compile-time locale cache","ref":"changelog.html#cldr-v2-3-0"},{"type":"extras","title":"Changelog - Cldr v2.2.7","doc":"This is the changelog for Cldr v2.2.7 released on February 23rd, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Correctly validates locales that are not pre-compiled into a backend. At compile time, all configured locales are generated from the CLDR data. However not all valid locales can be predefined - especially those that have variants, subtags or extensions or use a different casing to the canonical form. For example, the following would fail in prior releases even though it is perfectly valid since language tags are defined to be case insensitive: iex&gt; MyApp.Cldr . validate_locale &quot;en-au&quot; { :error , { Cldr.UnknownLocaleError , &quot;The locale \\&quot; en-au \\&quot; is not known.&quot; } } Similarly, it is expected that both the POSIX and IEEE formats of a language tag are acceptable, meaning that a - or _ should be acceptable. Again, in prior releases this would result in an error: iex&gt; MyApp.Cldr . validate_locale &quot;en_AU&quot; { :error , { Cldr.UnknownLocaleError , &quot;The locale \\&quot; en_AU \\&quot; is not known.&quot; } } Lastly, when using locale extensions, subtags or variants the validation would fail: MyApp.Cldr . validate_locale &quot;en-u-ca-buddhist&quot; { :error , { Cldr.UnknownLocaleError , &quot;The locale \\&quot; en_AU \\&quot; is not known.&quot; } } Each of these examples now correctly validates: iex&gt; TestBackend.Cldr . validate_locale &quot;en-au&quot; { :ok , % Cldr.LanguageTag { canonical_locale_name : &quot;en-Latn-AU&quot; , cldr_locale_name : &quot;en-AU&quot; , extensions : %{ } , gettext_locale_name : &quot;en&quot; , language : &quot;en&quot; , language_subtags : [ ] , language_variant : nil , locale : %{ } , private_use : [ ] , rbnf_locale_name : &quot;en&quot; , requested_locale_name : &quot;en-AU&quot; , script : &quot;Latn&quot; , territory : &quot;AU&quot; , transform : %{ } } } iex&gt; TestBackend.Cldr . validate_locale &quot;en_au&quot; { :ok , % Cldr.LanguageTag { canonical_locale_name : &quot;en-Latn-AU&quot; , cldr_locale_name : &quot;en-AU&quot; , extensions : %{ } , gettext_locale_name : &quot;en&quot; , language : &quot;en&quot; , language_subtags : [ ] , language_variant : nil , locale : %{ } , private_use : [ ] , rbnf_locale_name : &quot;en&quot; , requested_locale_name : &quot;en-AU&quot; , script : &quot;Latn&quot; , territory : &quot;AU&quot; , transform : %{ } } } iex&gt; TestBackend.Cldr . validate_locale &quot;en-u-ca-buddhist&quot; { :ok , % Cldr.LanguageTag { canonical_locale_name : &quot;en-Latn-US&quot; , cldr_locale_name : &quot;en&quot; , extensions : %{ } , gettext_locale_name : &quot;en&quot; , language : &quot;en&quot; , language_subtags : [ ] , language_variant : nil , locale : %{ calendar : :buddhist } , private_use : [ ] , rbnf_locale_name : &quot;en&quot; , requested_locale_name : &quot;en&quot; , script : &quot;Latn&quot; , territory : &quot;US&quot; , transform : %{ } } }","ref":"changelog.html#cldr-v2-2-7"},{"type":"extras","title":"Changelog - Cldr v2.2.6","doc":"This is the changelog for Cldr v2.2.6 released on February 23rd, 2019. For older changelogs please consult the release tag on GitHub Enhancements Adds Cldr.Config.territory_currency_data/0 that maps a territory code (like &quot;US&quot;) to a list of currencies reflecting the historic and current usage of currencies in that territory.","ref":"changelog.html#cldr-v2-2-6"},{"type":"extras","title":"Changelog - Cldr v2.2.5","doc":"This is the changelog for Cldr v2.2.5 released on February 18th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Remove most dialyzer errors Fix documentation syntax errors Fix regex for parsing currency names into currency strings","ref":"changelog.html#cldr-v2-2-5"},{"type":"extras","title":"Changelog - Cldr v2.2.4","doc":"This is the changelog for Cldr v2.2.4 released on February 10th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Ensure the global default locale (currently &quot;en-001&quot;) is always configured Enhancements Log a warning if a CLDR provider module could not be found","ref":"changelog.html#cldr-v2-2-4"},{"type":"extras","title":"Changelog - Cldr v2.2.3","doc":"This is the changelog for Cldr v2.2.3 released on February 9th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Fix parsing of currency names that have date ranges or annotations within them like &quot;US dollar (next day)&quot; and &quot;Afghan afghani (1927–2002)&quot;","ref":"changelog.html#cldr-v2-2-3"},{"type":"extras","title":"Changelog - Cldr v2.2.2","doc":"This is the changelog for Cldr v2.2.2 released on February 9th, 2019. For older changelogs please consult the release tag on GitHub Enhancements add Cldr.Config.currencies_for/2 to return a map of the currency definition for a locale","ref":"changelog.html#cldr-v2-2-2"},{"type":"extras","title":"Changelog - Cldr v2.2.1","doc":"This is the changelog for Cldr v2.2.1 released on January 30th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Correctly add the gettext locale to the language tag returned by &lt;backend&gt;.default_locale and Cldr.default_locale/2 . Thanks to @erikreedstrom. Closes #106. Enhancements Added a section on migrating from Cldr 1.x to 2.x.","ref":"changelog.html#cldr-v2-2-1"},{"type":"extras","title":"Changelog - Cldr v2.2.0","doc":"This is the changelog for Cldr v2.2.0 released on December 23nd, 2018. For older changelogs please consult the release tag on GitHub Enhancements Bump nimble_parsec to version 0.5 which has some breaking changes from 0.4 that affects the language tag parser. Use IO.warn/1 for compiler warnings related to global configuration and Cldr providers configuration for a backend.","ref":"changelog.html#cldr-v2-2-0"},{"type":"extras","title":"Changelog - Cldr v2.1.0","doc":"This is the changelog for Cldr v2.1.0 released on December 1st, 2018. For older changelogs please consult the release tag on GitHub Bug Fixes Don't issue a bogus global config deprecation warning. Enhancements Revises the Cldr provider strategy - again. Rather than try to auto-discover available provider modules and configuring them automatically they are now configured under the :provider key. The readme contains further information on configuring providers. For example: defmodule MyApp.Cldr do use Cldr , locales : [ &quot;en&quot; , &quot;zh&quot; ] , default_locale : &quot;en&quot; , providers : [ Cldr.Number , Cldr.List ] end The default behaviour is the same as Cldr 2.0 in that all known cldr providers are configured.","ref":"changelog.html#cldr-v2-1-0"},{"type":"extras","title":"Changelog - Cldr v2.0.4","doc":"This is the changelog for Cldr v2.0.4 released on November 26th, 2018. For older changelogs please consult the release tag on GitHub Bug fixes Dependency plugin check was using Mix.Project.in_project/3 which actually changes directory which during compilation is a bad thing (since compilation is in parallel and within a single Unix process). The plugin dependency list is now static. Thanks to @robotvert. Closes #93.","ref":"changelog.html#cldr-v2-0-4"},{"type":"extras","title":"Changelog - Cldr v2.0.3","doc":"This is the changelog for Cldr v2.0.3 released on November 25th, 2018. For older changelogs please consult the release tag on GitHub Bug fixes Check for a json library existence as early as possible in the compile cycle since it is required during compilation of Cldr .","ref":"changelog.html#cldr-v2-0-3"},{"type":"extras","title":"Changelog - Cldr v2.0.2","doc":"This is the changelog for Cldr v2.0.2 released on November 24th, 2018. For older changelogs please consult the release tag on GitHub Enhancements Move minimal Decimal version to 1.5 Bug fixes Cldr.Substitution.substitute/2 now conforms to its documentation and substitutes a list of terms into a list format","ref":"changelog.html#cldr-v2-0-2"},{"type":"extras","title":"Changelog - Cldr v2.0.1","doc":"This is the changelog for Cldr v2.0.1 released on November 22, 2018. For older changelogs please consult the release tag on GitHub Bug fixes Fixes a bug whereby a backend configured with locales, but no default locale (and no global configuration), would crash during compilation","ref":"changelog.html#cldr-v2-0-1"},{"type":"extras","title":"Changelog - Cldr v2.0.0","doc":"This is the changelog for Cldr v2.0.0 released on November 22, 2018. For older changelogs please consult the release tag on GitHub Enhancements See also Breaking Changes below. Transforms the regex's for currency spacing to be compatible with the elixir regex engine. This supports improved conformance for currency formatting in ex_cldr_numbers Removes the need for Phoenix as a dependency in tests. Thanks to @lostkobrakai. Closes #84. Print deprecation message if the global config is used for more than :json_library and :default_locale Align Cldr/get_locale/1/0 and Cldr.put_locale/2/1 with Gettext. See Cldr.get_locale/1 , Cldr.get_locale/0 , Cldr.put_locale/2 and Cldr.put_locale/1 Improve performance of Cldr.Gettext.Plural and align its return better with Gettext Add the 'miscellaneous' number formats to the locale definition files. This allows formatting of &quot;at least&quot;, &quot;approximately&quot;, &quot;at most&quot; and &quot;range&quot;. These formats will be used in ex_cldr_numbers . Purpose of the changes Version 2.0 of Cldr is focused on re-architecting the module structure to more closely follow the model set by Phoenix, Ecto, Gettext and others that also rely on generating a public API at compile time. In Cldr version 1.x, the compile functions were all hosted within the ex_cldr package itself which has created several challenges: Only one configuration was possible per installation Dependency compilation order couldn't be determined which meant that when Gettext was configured a second, forced, compilation phase was required whenever the configuration changed Code in the ex_cldr _build directory would be modified when the configuration changed New structure and configuration In line with the recommended strategy for configurable library applications, Cldr now requires a backend module be defined that hosts the configuration and public API. This is similar to the strategy used by Gettext , Ecto , Phoenix and others. These backend modules are defined like this: defmodule MyApp.Cldr do use Cldr , locales : [ &quot;en&quot; , &quot;zh&quot; ] end For further information on configuration, consult the readme . Migrating from Cldr 1.x to Cldr version 2.x Although the api structure is the same in both releases, the move to a backend module hosting configuration and the public API requires changes in applications using Cldr version 1.x. The steps to migrate are: Change the dependency in mix.exs to {:ex_cldr, &quot;~&gt; 2.0&quot;} Define a backend module to host the configuration and public API. It is recommended that the module be named MyApp.Cldr since this will ease migration through module aliasing. Change calls to Cldr.function_name to MyApp.Cldr.function_name . The easiest way to do this is to alias the backend module. For example: defmodule MyApp.SomeModule do # alias the backend module so that calls to Cldr functions still work alias MyApp.Cldr def some_function do IO . puts Cldr . known_locale_names end end Breaking Changes Configuration has changed to focus on the backend module, then otp app, then global config. All applications are required to define a backend module. The Public API moves to a configured backend module. Functions previous called on Cldr should be called on MyApp.Cldr . The ~L sigil has been removed. The public api functions support either a locale name (like &quot;en&quot;) or a language tag. Cldr.Plug.AcceptLanguage and Cldr.Plug.SetLocale need to have a config key :cldr to specify the Cldr backend to be used. The Mix compiler :cldr is obsolete. It still exists so configuration doesn't break but its no a :noop . It should be removed from your configuration. Cldr.Config.get_locale/1 now takes a config or backend parameter and has become Cldr.Config.get_locale/2 . Cldr.get_current_locale/0 is renamed to Cldr.get_locale/0 to better align with Gettext Cldr.put_current_locale/1 is renamed to Cldr.put_locale/1 to better align with Gettext","ref":"changelog.html#cldr-v2-0-0"}]